/****************************************************************************
** Meta object code from reading C++ file 'dbusmenu.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/dbus/dbusmenu/dbusmenu.hpp"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbusmenu.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs4dbus8dbusmenu12DBusMenuItemE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::dbus::dbusmenu::DBusMenuItem::qt_create_metaobjectdata<qt_meta_tag_ZN2qs4dbus8dbusmenu12DBusMenuItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::dbus::dbusmenu::DBusMenuItem",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "DBusMenus can only be acquired from a DBusMenuHandle",
        "layoutUpdated",
        "",
        "sendOpened",
        "sendClosed",
        "sendTriggered",
        "updateLayout",
        "menuHandle",
        "qs::dbus::dbusmenu::DBusMenu*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'layoutUpdated'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sendOpened'
        QtMocHelpers::SlotData<void() const>(9, 8, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sendClosed'
        QtMocHelpers::SlotData<void() const>(10, 8, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sendTriggered'
        QtMocHelpers::SlotData<void() const>(11, 8, QMC::AccessPrivate, QMetaType::Void),
        // Method 'updateLayout'
        QtMocHelpers::MethodData<void() const>(12, 8, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'menuHandle'
        QtMocHelpers::PropertyData<qs::dbus::dbusmenu::DBusMenu*>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DBusMenuItem, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject qs::dbus::dbusmenu::DBusMenuItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QsMenuEntry::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs4dbus8dbusmenu12DBusMenuItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs4dbus8dbusmenu12DBusMenuItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs4dbus8dbusmenu12DBusMenuItemE_t>.metaTypes,
    nullptr
} };

void qs::dbus::dbusmenu::DBusMenuItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBusMenuItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->layoutUpdated(); break;
        case 1: _t->sendOpened(); break;
        case 2: _t->sendClosed(); break;
        case 3: _t->sendTriggered(); break;
        case 4: _t->updateLayout(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DBusMenuItem::*)()>(_a, &DBusMenuItem::layoutUpdated, 0))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< qs::dbus::dbusmenu::DBusMenu* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qs::dbus::dbusmenu::DBusMenu**>(_v) = _t->menuHandle(); break;
        default: break;
        }
    }
}

const QMetaObject *qs::dbus::dbusmenu::DBusMenuItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::dbus::dbusmenu::DBusMenuItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs4dbus8dbusmenu12DBusMenuItemE_t>.strings))
        return static_cast<void*>(this);
    return QsMenuEntry::qt_metacast(_clname);
}

int qs::dbus::dbusmenu::DBusMenuItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QsMenuEntry::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void qs::dbus::dbusmenu::DBusMenuItem::layoutUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN2qs4dbus8dbusmenu8DBusMenuE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::dbus::dbusmenu::DBusMenu::qt_create_metaobjectdata<qt_meta_tag_ZN2qs4dbus8dbusmenu8DBusMenuE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::dbus::dbusmenu::DBusMenu",
        "QML.Element",
        "DBusMenuHandle",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Menu handles cannot be directly created",
        "iconThemePathChanged",
        "",
        "onLayoutUpdated",
        "revision",
        "parent",
        "onItemPropertiesUpdated",
        "DBusMenuItemPropertiesList",
        "updatedProps",
        "DBusMenuItemPropertyNamesList",
        "removedProps",
        "menu",
        "qs::dbus::dbusmenu::DBusMenuItem*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'iconThemePathChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onLayoutUpdated'
        QtMocHelpers::SlotData<void(quint32, qint32)>(9, 8, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 10 }, { QMetaType::Int, 11 },
        }}),
        // Slot 'onItemPropertiesUpdated'
        QtMocHelpers::SlotData<void(const DBusMenuItemPropertiesList &, const DBusMenuItemPropertyNamesList &)>(12, 8, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { 0x80000000 | 15, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'menu'
        QtMocHelpers::PropertyData<qs::dbus::dbusmenu::DBusMenuItem*>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DBusMenu, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject qs::dbus::dbusmenu::DBusMenu::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs4dbus8dbusmenu8DBusMenuE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs4dbus8dbusmenu8DBusMenuE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs4dbus8dbusmenu8DBusMenuE_t>.metaTypes,
    nullptr
} };

void qs::dbus::dbusmenu::DBusMenu::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBusMenu *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->iconThemePathChanged(); break;
        case 1: _t->onLayoutUpdated((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint32>>(_a[2]))); break;
        case 2: _t->onItemPropertiesUpdated((*reinterpret_cast<std::add_pointer_t<DBusMenuItemPropertiesList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<DBusMenuItemPropertyNamesList>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DBusMenuItemPropertiesList >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DBusMenuItemPropertyNamesList >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DBusMenu::*)()>(_a, &DBusMenu::iconThemePathChanged, 0))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< qs::dbus::dbusmenu::DBusMenuItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qs::dbus::dbusmenu::DBusMenuItem**>(_v) = _t->menu(); break;
        default: break;
        }
    }
}

const QMetaObject *qs::dbus::dbusmenu::DBusMenu::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::dbus::dbusmenu::DBusMenu::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs4dbus8dbusmenu8DBusMenuE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::dbus::dbusmenu::DBusMenu::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void qs::dbus::dbusmenu::DBusMenu::iconThemePathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
