/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Notifications.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "dbus_notifications.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class DBusNotificationServer
 */

DBusNotificationServer::DBusNotificationServer(qs::service::notifications::NotificationServer *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

DBusNotificationServer::~DBusNotificationServer()
{
    // destructor
}

void DBusNotificationServer::CloseNotification(uint id)
{
    // handle method call org.freedesktop.Notifications.CloseNotification
    parent()->CloseNotification(id);
}

QStringList DBusNotificationServer::GetCapabilities()
{
    // handle method call org.freedesktop.Notifications.GetCapabilities
    return parent()->GetCapabilities();
}

QString DBusNotificationServer::GetServerInformation(QString &vendor, QString &version, QString &specVersion)
{
    // handle method call org.freedesktop.Notifications.GetServerInformation
    return parent()->GetServerInformation(vendor, version, specVersion);
}

uint DBusNotificationServer::Notify(const QString &appName, uint replacesId, const QString &appIcon, const QString &summary, const QString &body, const QStringList &actions, const QVariantMap &hints, int expireTimeout)
{
    // handle method call org.freedesktop.Notifications.Notify
    return parent()->Notify(appName, replacesId, appIcon, summary, body, actions, hints, expireTimeout);
}


#include "moc_dbus_notifications.cpp"
