/****************************************************************************
** Meta object code from reading C++ file 'handle.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/wayland/toplevel_management/handle.hpp"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'handle.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs7wayland19toplevel_management4impl14ToplevelHandleE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::wayland::toplevel_management::impl::ToplevelHandle::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7wayland19toplevel_management4impl14ToplevelHandleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::wayland::toplevel_management::impl::ToplevelHandle",
        "ready",
        "",
        "closed",
        "appIdChanged",
        "titleChanged",
        "parentChanged",
        "activatedChanged",
        "maximizedChanged",
        "minimizedChanged",
        "fullscreenChanged",
        "onParentClosed",
        "onRectWindowDestroyed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ready'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'closed'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'appIdChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'parentChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activatedChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maximizedChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minimizedChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fullscreenChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onParentClosed'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onRectWindowDestroyed'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ToplevelHandle, qt_meta_tag_ZN2qs7wayland19toplevel_management4impl14ToplevelHandleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qs::wayland::toplevel_management::impl::ToplevelHandle::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland19toplevel_management4impl14ToplevelHandleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland19toplevel_management4impl14ToplevelHandleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7wayland19toplevel_management4impl14ToplevelHandleE_t>.metaTypes,
    nullptr
} };

void qs::wayland::toplevel_management::impl::ToplevelHandle::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ToplevelHandle *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ready(); break;
        case 1: _t->closed(); break;
        case 2: _t->appIdChanged(); break;
        case 3: _t->titleChanged(); break;
        case 4: _t->parentChanged(); break;
        case 5: _t->activatedChanged(); break;
        case 6: _t->maximizedChanged(); break;
        case 7: _t->minimizedChanged(); break;
        case 8: _t->fullscreenChanged(); break;
        case 9: _t->onParentClosed(); break;
        case 10: _t->onRectWindowDestroyed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ToplevelHandle::*)()>(_a, &ToplevelHandle::ready, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToplevelHandle::*)()>(_a, &ToplevelHandle::closed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToplevelHandle::*)()>(_a, &ToplevelHandle::appIdChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToplevelHandle::*)()>(_a, &ToplevelHandle::titleChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToplevelHandle::*)()>(_a, &ToplevelHandle::parentChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToplevelHandle::*)()>(_a, &ToplevelHandle::activatedChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToplevelHandle::*)()>(_a, &ToplevelHandle::maximizedChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToplevelHandle::*)()>(_a, &ToplevelHandle::minimizedChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToplevelHandle::*)()>(_a, &ToplevelHandle::fullscreenChanged, 8))
            return;
    }
}

const QMetaObject *qs::wayland::toplevel_management::impl::ToplevelHandle::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::wayland::toplevel_management::impl::ToplevelHandle::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland19toplevel_management4impl14ToplevelHandleE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::zwlr_foreign_toplevel_handle_v1"))
        return static_cast< QtWayland::zwlr_foreign_toplevel_handle_v1*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::wayland::toplevel_management::impl::ToplevelHandle::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void qs::wayland::toplevel_management::impl::ToplevelHandle::ready()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void qs::wayland::toplevel_management::impl::ToplevelHandle::closed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void qs::wayland::toplevel_management::impl::ToplevelHandle::appIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void qs::wayland::toplevel_management::impl::ToplevelHandle::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void qs::wayland::toplevel_management::impl::ToplevelHandle::parentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void qs::wayland::toplevel_management::impl::ToplevelHandle::activatedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void qs::wayland::toplevel_management::impl::ToplevelHandle::maximizedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void qs::wayland::toplevel_management::impl::ToplevelHandle::minimizedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void qs::wayland::toplevel_management::impl::ToplevelHandle::fullscreenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
