/****************************************************************************
** Meta object code from reading C++ file 'defaults.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/services/pipewire/defaults.hpp"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'defaults.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs7service8pipewire16PwDefaultTrackerE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::service::pipewire::PwDefaultTracker::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7service8pipewire16PwDefaultTrackerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::service::pipewire::PwDefaultTracker",
        "defaultSinkChanged",
        "",
        "defaultSinkNameChanged",
        "defaultSourceChanged",
        "defaultSourceNameChanged",
        "defaultConfiguredSinkChanged",
        "defaultConfiguredSinkNameChanged",
        "defaultConfiguredSourceChanged",
        "defaultConfiguredSourceNameChanged",
        "onMetadataAdded",
        "PwMetadata*",
        "metadata",
        "onMetadataProperty",
        "const char*",
        "key",
        "type",
        "value",
        "onNodeAdded",
        "PwNode*",
        "node",
        "onDefaultSinkDestroyed",
        "onDefaultSourceDestroyed",
        "onDefaultConfiguredSinkDestroyed",
        "onDefaultConfiguredSourceDestroyed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'defaultSinkChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultSinkNameChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultSourceChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultSourceNameChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultConfiguredSinkChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultConfiguredSinkNameChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultConfiguredSourceChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultConfiguredSourceNameChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onMetadataAdded'
        QtMocHelpers::SlotData<void(PwMetadata *)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'onMetadataProperty'
        QtMocHelpers::SlotData<void(const char *, const char *, const char *)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { 0x80000000 | 14, 16 }, { 0x80000000 | 14, 17 },
        }}),
        // Slot 'onNodeAdded'
        QtMocHelpers::SlotData<void(PwNode *)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'onDefaultSinkDestroyed'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDefaultSourceDestroyed'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDefaultConfiguredSinkDestroyed'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDefaultConfiguredSourceDestroyed'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PwDefaultTracker, qt_meta_tag_ZN2qs7service8pipewire16PwDefaultTrackerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qs::service::pipewire::PwDefaultTracker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service8pipewire16PwDefaultTrackerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service8pipewire16PwDefaultTrackerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7service8pipewire16PwDefaultTrackerE_t>.metaTypes,
    nullptr
} };

void qs::service::pipewire::PwDefaultTracker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PwDefaultTracker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->defaultSinkChanged(); break;
        case 1: _t->defaultSinkNameChanged(); break;
        case 2: _t->defaultSourceChanged(); break;
        case 3: _t->defaultSourceNameChanged(); break;
        case 4: _t->defaultConfiguredSinkChanged(); break;
        case 5: _t->defaultConfiguredSinkNameChanged(); break;
        case 6: _t->defaultConfiguredSourceChanged(); break;
        case 7: _t->defaultConfiguredSourceNameChanged(); break;
        case 8: _t->onMetadataAdded((*reinterpret_cast<std::add_pointer_t<PwMetadata*>>(_a[1]))); break;
        case 9: _t->onMetadataProperty((*reinterpret_cast<std::add_pointer_t<const char*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const char*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<const char*>>(_a[3]))); break;
        case 10: _t->onNodeAdded((*reinterpret_cast<std::add_pointer_t<PwNode*>>(_a[1]))); break;
        case 11: _t->onDefaultSinkDestroyed(); break;
        case 12: _t->onDefaultSourceDestroyed(); break;
        case 13: _t->onDefaultConfiguredSinkDestroyed(); break;
        case 14: _t->onDefaultConfiguredSourceDestroyed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PwDefaultTracker::*)()>(_a, &PwDefaultTracker::defaultSinkChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PwDefaultTracker::*)()>(_a, &PwDefaultTracker::defaultSinkNameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PwDefaultTracker::*)()>(_a, &PwDefaultTracker::defaultSourceChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PwDefaultTracker::*)()>(_a, &PwDefaultTracker::defaultSourceNameChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PwDefaultTracker::*)()>(_a, &PwDefaultTracker::defaultConfiguredSinkChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PwDefaultTracker::*)()>(_a, &PwDefaultTracker::defaultConfiguredSinkNameChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PwDefaultTracker::*)()>(_a, &PwDefaultTracker::defaultConfiguredSourceChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PwDefaultTracker::*)()>(_a, &PwDefaultTracker::defaultConfiguredSourceNameChanged, 7))
            return;
    }
}

const QMetaObject *qs::service::pipewire::PwDefaultTracker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::service::pipewire::PwDefaultTracker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service8pipewire16PwDefaultTrackerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::service::pipewire::PwDefaultTracker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void qs::service::pipewire::PwDefaultTracker::defaultSinkChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void qs::service::pipewire::PwDefaultTracker::defaultSinkNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void qs::service::pipewire::PwDefaultTracker::defaultSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void qs::service::pipewire::PwDefaultTracker::defaultSourceNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void qs::service::pipewire::PwDefaultTracker::defaultConfiguredSinkChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void qs::service::pipewire::PwDefaultTracker::defaultConfiguredSinkNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void qs::service::pipewire::PwDefaultTracker::defaultConfiguredSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void qs::service::pipewire::PwDefaultTracker::defaultConfiguredSourceNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
