/****************************************************************************
** Meta object code from reading C++ file 'device.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../src/bluetooth/device.hpp"
#include <QtCore/qmetatype.h>
#include <QtCore/QProperty>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'device.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs9bluetooth20BluetoothDeviceStateE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::bluetooth::BluetoothDeviceState::qt_create_metaobjectdata<qt_meta_tag_ZN2qs9bluetooth20BluetoothDeviceStateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::bluetooth::BluetoothDeviceState",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "toString",
        "",
        "BluetoothDeviceState::Enum",
        "state",
        "Enum",
        "Disconnected",
        "Connected",
        "Disconnecting",
        "Connecting"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'toString'
        QtMocHelpers::MethodData<QString(BluetoothDeviceState::Enum)>(5, 6, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 7, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Enum'
        QtMocHelpers::EnumData<enum Enum>(9, 9, QMC::EnumFlags{}).add({
            {   10, Enum::Disconnected },
            {   11, Enum::Connected },
            {   12, Enum::Disconnecting },
            {   13, Enum::Connecting },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<BluetoothDeviceState, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject qs::bluetooth::BluetoothDeviceState::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs9bluetooth20BluetoothDeviceStateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs9bluetooth20BluetoothDeviceStateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs9bluetooth20BluetoothDeviceStateE_t>.metaTypes,
    nullptr
} };

void qs::bluetooth::BluetoothDeviceState::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BluetoothDeviceState *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->toString((*reinterpret_cast<std::add_pointer_t<BluetoothDeviceState::Enum>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *qs::bluetooth::BluetoothDeviceState::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::bluetooth::BluetoothDeviceState::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs9bluetooth20BluetoothDeviceStateE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::bluetooth::BluetoothDeviceState::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN2qs9bluetooth15BluetoothDeviceE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::bluetooth::BluetoothDevice::qt_create_metaobjectdata<qt_meta_tag_ZN2qs9bluetooth15BluetoothDeviceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::bluetooth::BluetoothDevice",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "addressChanged",
        "deviceNameChanged",
        "nameChanged",
        "connectedChanged",
        "stateChanged",
        "pairedChanged",
        "bondedChanged",
        "pairingChanged",
        "trustedChanged",
        "blockedChanged",
        "wakeAllowedChanged",
        "iconChanged",
        "batteryAvailableChanged",
        "batteryChanged",
        "adapterChanged",
        "connect",
        "disconnect",
        "pair",
        "cancelPair",
        "forget",
        "address",
        "name",
        "deviceName",
        "icon",
        "state",
        "BluetoothDeviceState::Enum",
        "connected",
        "paired",
        "bonded",
        "pairing",
        "trusted",
        "blocked",
        "wakeAllowed",
        "batteryAvailable",
        "battery",
        "adapter",
        "BluetoothAdapter*",
        "dbusPath"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'addressChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'deviceNameChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'connectedChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pairedChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bondedChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pairingChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trustedChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blockedChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wakeAllowedChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iconChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'batteryAvailableChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'batteryChanged'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'adapterChanged'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'connect'
        QtMocHelpers::MethodData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'disconnect'
        QtMocHelpers::MethodData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'pair'
        QtMocHelpers::MethodData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'cancelPair'
        QtMocHelpers::MethodData<void()>(25, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'forget'
        QtMocHelpers::MethodData<void()>(26, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'address'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Bindable, 0),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'deviceName'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Bindable, 1),
        // property 'icon'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Bindable, 11),
        // property 'state'
        QtMocHelpers::PropertyData<BluetoothDeviceState::Enum>(31, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Bindable, 4),
        // property 'connected'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'paired'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 5),
        // property 'bonded'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 6),
        // property 'pairing'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags, 7),
        // property 'trusted'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'blocked'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'wakeAllowed'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'batteryAvailable'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags, 12),
        // property 'battery'
        QtMocHelpers::PropertyData<qreal>(41, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Bindable, 13),
        // property 'adapter'
        QtMocHelpers::PropertyData<BluetoothAdapter*>(42, 0x80000000 | 43, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 14),
        // property 'dbusPath'
        QtMocHelpers::PropertyData<QString>(44, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<BluetoothDevice, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN2qs9bluetooth15BluetoothDeviceE[] = {
    QMetaObject::SuperData::link<qs::bluetooth::BluetoothDeviceState::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject qs::bluetooth::BluetoothDevice::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs9bluetooth15BluetoothDeviceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs9bluetooth15BluetoothDeviceE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN2qs9bluetooth15BluetoothDeviceE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs9bluetooth15BluetoothDeviceE_t>.metaTypes,
    nullptr
} };

void qs::bluetooth::BluetoothDevice::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BluetoothDevice *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->addressChanged(); break;
        case 1: _t->deviceNameChanged(); break;
        case 2: _t->nameChanged(); break;
        case 3: _t->connectedChanged(); break;
        case 4: _t->stateChanged(); break;
        case 5: _t->pairedChanged(); break;
        case 6: _t->bondedChanged(); break;
        case 7: _t->pairingChanged(); break;
        case 8: _t->trustedChanged(); break;
        case 9: _t->blockedChanged(); break;
        case 10: _t->wakeAllowedChanged(); break;
        case 11: _t->iconChanged(); break;
        case 12: _t->batteryAvailableChanged(); break;
        case 13: _t->batteryChanged(); break;
        case 14: _t->adapterChanged(); break;
        case 15: _t->connect(); break;
        case 16: _t->disconnect(); break;
        case 17: _t->pair(); break;
        case 18: _t->cancelPair(); break;
        case 19: _t->forget(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BluetoothDevice::*)()>(_a, &BluetoothDevice::addressChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDevice::*)()>(_a, &BluetoothDevice::deviceNameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDevice::*)()>(_a, &BluetoothDevice::nameChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDevice::*)()>(_a, &BluetoothDevice::connectedChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDevice::*)()>(_a, &BluetoothDevice::stateChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDevice::*)()>(_a, &BluetoothDevice::pairedChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDevice::*)()>(_a, &BluetoothDevice::bondedChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDevice::*)()>(_a, &BluetoothDevice::pairingChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDevice::*)()>(_a, &BluetoothDevice::trustedChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDevice::*)()>(_a, &BluetoothDevice::blockedChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDevice::*)()>(_a, &BluetoothDevice::wakeAllowedChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDevice::*)()>(_a, &BluetoothDevice::iconChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDevice::*)()>(_a, &BluetoothDevice::batteryAvailableChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDevice::*)()>(_a, &BluetoothDevice::batteryChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothDevice::*)()>(_a, &BluetoothDevice::adapterChanged, 14))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->bindableAddress().value(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->bindableDeviceName().value(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->bindableIcon().value(); break;
        case 4: *reinterpret_cast<BluetoothDeviceState::Enum*>(_v) = _t->bindableState().value(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->connected(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->bindablePaired().value(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->bindableBonded().value(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->pairing(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->trusted(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->blocked(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->wakeAllowed(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->batteryAvailable(); break;
        case 13: *reinterpret_cast<qreal*>(_v) = _t->bindableBattery().value(); break;
        case 14: *reinterpret_cast<BluetoothAdapter**>(_v) = _t->adapter(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->path(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setConnected(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setTrusted(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setBlocked(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setWakeAllowed(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::BindableProperty) {
        switch (_id) {
        case 0: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableAddress(); break;
        case 2: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableDeviceName(); break;
        case 3: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableIcon(); break;
        case 4: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableState(); break;
        case 6: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindablePaired(); break;
        case 7: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableBonded(); break;
        case 13: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableBattery(); break;
        default: break;
        }
    }
}

const QMetaObject *qs::bluetooth::BluetoothDevice::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::bluetooth::BluetoothDevice::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs9bluetooth15BluetoothDeviceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::bluetooth::BluetoothDevice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void qs::bluetooth::BluetoothDevice::addressChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void qs::bluetooth::BluetoothDevice::deviceNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void qs::bluetooth::BluetoothDevice::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void qs::bluetooth::BluetoothDevice::connectedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void qs::bluetooth::BluetoothDevice::stateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void qs::bluetooth::BluetoothDevice::pairedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void qs::bluetooth::BluetoothDevice::bondedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void qs::bluetooth::BluetoothDevice::pairingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void qs::bluetooth::BluetoothDevice::trustedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void qs::bluetooth::BluetoothDevice::blockedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void qs::bluetooth::BluetoothDevice::wakeAllowedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void qs::bluetooth::BluetoothDevice::iconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void qs::bluetooth::BluetoothDevice::batteryAvailableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void qs::bluetooth::BluetoothDevice::batteryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void qs::bluetooth::BluetoothDevice::adapterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}
QT_WARNING_POP
