/****************************************************************************
** Meta object code from reading C++ file 'controller.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../src/x11/i3/ipc/controller.hpp"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'controller.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs2i33ipc15I3IpcControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::i3::ipc::I3IpcController::qt_create_metaobjectdata<qt_meta_tag_ZN2qs2i33ipc15I3IpcControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::i3::ipc::I3IpcController",
        "focusedWorkspaceChanged",
        "",
        "focusedMonitorChanged",
        "onFocusedMonitorDestroyed",
        "onEvent",
        "I3IpcEvent*",
        "event",
        "onConnected"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'focusedWorkspaceChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusedMonitorChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onFocusedMonitorDestroyed'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onEvent'
        QtMocHelpers::SlotData<void(I3IpcEvent *)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'onConnected'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<I3IpcController, qt_meta_tag_ZN2qs2i33ipc15I3IpcControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qs::i3::ipc::I3IpcController::staticMetaObject = { {
    QMetaObject::SuperData::link<I3Ipc::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs2i33ipc15I3IpcControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs2i33ipc15I3IpcControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs2i33ipc15I3IpcControllerE_t>.metaTypes,
    nullptr
} };

void qs::i3::ipc::I3IpcController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<I3IpcController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->focusedWorkspaceChanged(); break;
        case 1: _t->focusedMonitorChanged(); break;
        case 2: _t->onFocusedMonitorDestroyed(); break;
        case 3: _t->onEvent((*reinterpret_cast<std::add_pointer_t<I3IpcEvent*>>(_a[1]))); break;
        case 4: _t->onConnected(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< I3IpcEvent* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (I3IpcController::*)()>(_a, &I3IpcController::focusedWorkspaceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (I3IpcController::*)()>(_a, &I3IpcController::focusedMonitorChanged, 1))
            return;
    }
}

const QMetaObject *qs::i3::ipc::I3IpcController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::i3::ipc::I3IpcController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs2i33ipc15I3IpcControllerE_t>.strings))
        return static_cast<void*>(this);
    return I3Ipc::qt_metacast(_clname);
}

int qs::i3::ipc::I3IpcController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = I3Ipc::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void qs::i3::ipc::I3IpcController::focusedWorkspaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void qs::i3::ipc::I3IpcController::focusedMonitorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
