/****************************************************************************
** Meta object code from reading C++ file 'panel_window.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../src/x11/panel_window.hpp"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'panel_window.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17XPanelEventFilterE_t {};
} // unnamed namespace

template <> constexpr inline auto XPanelEventFilter::qt_create_metaobjectdata<qt_meta_tag_ZN17XPanelEventFilterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "XPanelEventFilter",
        "surfaceCreated",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'surfaceCreated'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<XPanelEventFilter, qt_meta_tag_ZN17XPanelEventFilterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject XPanelEventFilter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17XPanelEventFilterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17XPanelEventFilterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17XPanelEventFilterE_t>.metaTypes,
    nullptr
} };

void XPanelEventFilter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XPanelEventFilter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->surfaceCreated(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (XPanelEventFilter::*)()>(_a, &XPanelEventFilter::surfaceCreated, 0))
            return;
    }
}

const QMetaObject *XPanelEventFilter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XPanelEventFilter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17XPanelEventFilterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int XPanelEventFilter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void XPanelEventFilter::surfaceCreated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN12XPanelWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto XPanelWindow::qt_create_metaobjectdata<qt_meta_tag_ZN12XPanelWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "XPanelWindow",
        "QML.Element",
        "auto",
        "anchorsChanged",
        "",
        "exclusiveZoneChanged",
        "exclusionModeChanged",
        "marginsChanged",
        "aboveWindowsChanged",
        "focusableChanged",
        "xInit",
        "updatePanelStack",
        "updateDimensionsSlot",
        "onScreenVirtualGeometryChanged",
        "anchors",
        "Anchors",
        "exclusiveZone",
        "exclusionMode",
        "ExclusionMode::Enum",
        "margins",
        "Margins",
        "aboveWindows",
        "focusable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'anchorsChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'exclusiveZoneChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'exclusionModeChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'marginsChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'aboveWindowsChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusableChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'xInit'
        QtMocHelpers::SlotData<void()>(10, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updatePanelStack'
        QtMocHelpers::SlotData<void()>(11, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateDimensionsSlot'
        QtMocHelpers::SlotData<void()>(12, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onScreenVirtualGeometryChanged'
        QtMocHelpers::SlotData<void()>(13, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'anchors'
        QtMocHelpers::PropertyData<Anchors>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'exclusiveZone'
        QtMocHelpers::PropertyData<qint32>(16, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'exclusionMode'
        QtMocHelpers::PropertyData<ExclusionMode::Enum>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'margins'
        QtMocHelpers::PropertyData<Margins>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'aboveWindows'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'focusable'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<XPanelWindow, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN12XPanelWindowE[] = {
    QMetaObject::SuperData::link<ExclusionMode::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject XPanelWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<ProxyWindowBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12XPanelWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12XPanelWindowE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN12XPanelWindowE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12XPanelWindowE_t>.metaTypes,
    nullptr
} };

void XPanelWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XPanelWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->anchorsChanged(); break;
        case 1: _t->exclusiveZoneChanged(); break;
        case 2: _t->exclusionModeChanged(); break;
        case 3: _t->marginsChanged(); break;
        case 4: _t->aboveWindowsChanged(); break;
        case 5: _t->focusableChanged(); break;
        case 6: _t->xInit(); break;
        case 7: _t->updatePanelStack(); break;
        case 8: _t->updateDimensionsSlot(); break;
        case 9: _t->onScreenVirtualGeometryChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (XPanelWindow::*)()>(_a, &XPanelWindow::anchorsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (XPanelWindow::*)()>(_a, &XPanelWindow::exclusiveZoneChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (XPanelWindow::*)()>(_a, &XPanelWindow::exclusionModeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (XPanelWindow::*)()>(_a, &XPanelWindow::marginsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (XPanelWindow::*)()>(_a, &XPanelWindow::aboveWindowsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (XPanelWindow::*)()>(_a, &XPanelWindow::focusableChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Anchors*>(_v) = _t->anchors(); break;
        case 1: *reinterpret_cast<qint32*>(_v) = _t->exclusiveZone(); break;
        case 2: *reinterpret_cast<ExclusionMode::Enum*>(_v) = _t->exclusionMode(); break;
        case 3: *reinterpret_cast<Margins*>(_v) = _t->margins(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->aboveWindows(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->focusable(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAnchors(*reinterpret_cast<Anchors*>(_v)); break;
        case 1: _t->setExclusiveZone(*reinterpret_cast<qint32*>(_v)); break;
        case 2: _t->setExclusionMode(*reinterpret_cast<ExclusionMode::Enum*>(_v)); break;
        case 3: _t->setMargins(*reinterpret_cast<Margins*>(_v)); break;
        case 4: _t->setAboveWindows(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setFocusable(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *XPanelWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XPanelWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12XPanelWindowE_t>.strings))
        return static_cast<void*>(this);
    return ProxyWindowBase::qt_metacast(_clname);
}

int XPanelWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ProxyWindowBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void XPanelWindow::anchorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void XPanelWindow::exclusiveZoneChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void XPanelWindow::exclusionModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void XPanelWindow::marginsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void XPanelWindow::aboveWindowsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void XPanelWindow::focusableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
namespace {
struct qt_meta_tag_ZN15XPanelInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto XPanelInterface::qt_create_metaobjectdata<qt_meta_tag_ZN15XPanelInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "XPanelInterface"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<XPanelInterface, qt_meta_tag_ZN15XPanelInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject XPanelInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<PanelWindowInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15XPanelInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15XPanelInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15XPanelInterfaceE_t>.metaTypes,
    nullptr
} };

void XPanelInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XPanelInterface *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *XPanelInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XPanelInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15XPanelInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return PanelWindowInterface::qt_metacast(_clname);
}

int XPanelInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PanelWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
