/****************************************************************************
** Meta object code from reading C++ file 'wifi.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../src/network/wifi.hpp"
#include <QtCore/qmetatype.h>
#include <QtCore/QProperty>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'wifi.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs7network11WifiNetworkE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::network::WifiNetwork::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7network11WifiNetworkE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::network::WifiNetwork",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "WifiNetwork can only be acquired through WifiDevice",
        "requestConnectWithPsk",
        "",
        "psk",
        "signalStrengthChanged",
        "securityChanged",
        "connectWithPsk",
        "signalStrength",
        "security",
        "WifiSecurityType::Enum"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestConnectWithPsk'
        QtMocHelpers::SignalData<void(QString)>(7, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'signalStrengthChanged'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'securityChanged'
        QtMocHelpers::SignalData<void()>(11, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'connectWithPsk'
        QtMocHelpers::MethodData<void(const QString &)>(12, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'signalStrength'
        QtMocHelpers::PropertyData<qreal>(13, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Bindable, 1),
        // property 'security'
        QtMocHelpers::PropertyData<WifiSecurityType::Enum>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Bindable, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<WifiNetwork, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN2qs7network11WifiNetworkE[] = {
    QMetaObject::SuperData::link<qs::network::WifiSecurityType::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject qs::network::WifiNetwork::staticMetaObject = { {
    QMetaObject::SuperData::link<Network::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network11WifiNetworkE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network11WifiNetworkE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN2qs7network11WifiNetworkE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7network11WifiNetworkE_t>.metaTypes,
    nullptr
} };

void qs::network::WifiNetwork::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WifiNetwork *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestConnectWithPsk((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->signalStrengthChanged(); break;
        case 2: _t->securityChanged(); break;
        case 3: _t->connectWithPsk((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WifiNetwork::*)(QString )>(_a, &WifiNetwork::requestConnectWithPsk, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WifiNetwork::*)()>(_a, &WifiNetwork::signalStrengthChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WifiNetwork::*)()>(_a, &WifiNetwork::securityChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qreal*>(_v) = _t->bindableSignalStrength().value(); break;
        case 1: *reinterpret_cast<WifiSecurityType::Enum*>(_v) = _t->bindableSecurity().value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::BindableProperty) {
        switch (_id) {
        case 0: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableSignalStrength(); break;
        case 1: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableSecurity(); break;
        default: break;
        }
    }
}

const QMetaObject *qs::network::WifiNetwork::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::network::WifiNetwork::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network11WifiNetworkE_t>.strings))
        return static_cast<void*>(this);
    return Network::qt_metacast(_clname);
}

int qs::network::WifiNetwork::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Network::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void qs::network::WifiNetwork::requestConnectWithPsk(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void qs::network::WifiNetwork::signalStrengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void qs::network::WifiNetwork::securityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
namespace {
struct qt_meta_tag_ZN2qs7network10WifiDeviceE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::network::WifiDevice::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7network10WifiDeviceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::network::WifiDevice",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "modeChanged",
        "scannerEnabledChanged",
        "enabled",
        "scannerEnabled",
        "mode",
        "WifiDeviceMode::Enum"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'modeChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scannerEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'scannerEnabled'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Bindable, 1),
        // property 'mode'
        QtMocHelpers::PropertyData<WifiDeviceMode::Enum>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Bindable, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<WifiDevice, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN2qs7network10WifiDeviceE[] = {
    QMetaObject::SuperData::link<qs::network::WifiDeviceMode::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject qs::network::WifiDevice::staticMetaObject = { {
    QMetaObject::SuperData::link<NetworkDevice::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network10WifiDeviceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network10WifiDeviceE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN2qs7network10WifiDeviceE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7network10WifiDeviceE_t>.metaTypes,
    nullptr
} };

void qs::network::WifiDevice::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WifiDevice *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->modeChanged(); break;
        case 1: _t->scannerEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WifiDevice::*)()>(_a, &WifiDevice::modeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WifiDevice::*)(bool )>(_a, &WifiDevice::scannerEnabledChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->scannerEnabled(); break;
        case 1: *reinterpret_cast<WifiDeviceMode::Enum*>(_v) = _t->bindableMode().value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setScannerEnabled(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::BindableProperty) {
        switch (_id) {
        case 0: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableScannerEnabled(); break;
        case 1: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableMode(); break;
        default: break;
        }
    }
}

const QMetaObject *qs::network::WifiDevice::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::network::WifiDevice::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network10WifiDeviceE_t>.strings))
        return static_cast<void*>(this);
    return NetworkDevice::qt_metacast(_clname);
}

int qs::network::WifiDevice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetworkDevice::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void qs::network::WifiDevice::modeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void qs::network::WifiDevice::scannerEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
