/****************************************************************************
** Meta object code from reading C++ file 'network.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/network/nm/network.hpp"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'network.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs7network9NMNetworkE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::network::NMNetwork::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7network9NMNetworkE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::network::NMNetwork",
        "requestDisconnect",
        "",
        "requestActivateConnection",
        "settingsPath",
        "requestAddAndActivateConnection",
        "NMSettingsMap",
        "settingsMap",
        "specificObject",
        "settingsAdded",
        "NMSettings*",
        "settings",
        "settingsRemoved",
        "stateChanged",
        "NMConnectionState::Enum",
        "state",
        "knownChanged",
        "known",
        "reasonChanged",
        "NMConnectionStateReason::Enum",
        "reason",
        "deviceFailReasonChanged",
        "NMDeviceStateReason::Enum",
        "referenceSettingsChanged",
        "visibilityChanged",
        "visible"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestDisconnect'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestActivateConnection'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'requestAddAndActivateConnection'
        QtMocHelpers::SignalData<void(const NMSettingsMap &, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'settingsAdded'
        QtMocHelpers::SignalData<void(NMSettings *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'settingsRemoved'
        QtMocHelpers::SignalData<void(NMSettings *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void(NMConnectionState::Enum)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Signal 'knownChanged'
        QtMocHelpers::SignalData<void(bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Signal 'reasonChanged'
        QtMocHelpers::SignalData<void(NMConnectionStateReason::Enum)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'deviceFailReasonChanged'
        QtMocHelpers::SignalData<void(NMDeviceStateReason::Enum)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 20 },
        }}),
        // Signal 'referenceSettingsChanged'
        QtMocHelpers::SignalData<void(NMSettings *)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'visibilityChanged'
        QtMocHelpers::SignalData<void(bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NMNetwork, qt_meta_tag_ZN2qs7network9NMNetworkE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qs::network::NMNetwork::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network9NMNetworkE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network9NMNetworkE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7network9NMNetworkE_t>.metaTypes,
    nullptr
} };

void qs::network::NMNetwork::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NMNetwork *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestDisconnect(); break;
        case 1: _t->requestActivateConnection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->requestAddAndActivateConnection((*reinterpret_cast<std::add_pointer_t<NMSettingsMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->settingsAdded((*reinterpret_cast<std::add_pointer_t<NMSettings*>>(_a[1]))); break;
        case 4: _t->settingsRemoved((*reinterpret_cast<std::add_pointer_t<NMSettings*>>(_a[1]))); break;
        case 5: _t->stateChanged((*reinterpret_cast<std::add_pointer_t<NMConnectionState::Enum>>(_a[1]))); break;
        case 6: _t->knownChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->reasonChanged((*reinterpret_cast<std::add_pointer_t<NMConnectionStateReason::Enum>>(_a[1]))); break;
        case 8: _t->deviceFailReasonChanged((*reinterpret_cast<std::add_pointer_t<NMDeviceStateReason::Enum>>(_a[1]))); break;
        case 9: _t->referenceSettingsChanged((*reinterpret_cast<std::add_pointer_t<NMSettings*>>(_a[1]))); break;
        case 10: _t->visibilityChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< NMSettings* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< NMSettings* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< NMSettings* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NMNetwork::*)()>(_a, &NMNetwork::requestDisconnect, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMNetwork::*)(const QString & )>(_a, &NMNetwork::requestActivateConnection, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMNetwork::*)(const NMSettingsMap & , const QString & )>(_a, &NMNetwork::requestAddAndActivateConnection, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMNetwork::*)(NMSettings * )>(_a, &NMNetwork::settingsAdded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMNetwork::*)(NMSettings * )>(_a, &NMNetwork::settingsRemoved, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMNetwork::*)(NMConnectionState::Enum )>(_a, &NMNetwork::stateChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMNetwork::*)(bool )>(_a, &NMNetwork::knownChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMNetwork::*)(NMConnectionStateReason::Enum )>(_a, &NMNetwork::reasonChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMNetwork::*)(NMDeviceStateReason::Enum )>(_a, &NMNetwork::deviceFailReasonChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMNetwork::*)(NMSettings * )>(_a, &NMNetwork::referenceSettingsChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMNetwork::*)(bool )>(_a, &NMNetwork::visibilityChanged, 10))
            return;
    }
}

const QMetaObject *qs::network::NMNetwork::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::network::NMNetwork::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network9NMNetworkE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::network::NMNetwork::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void qs::network::NMNetwork::requestDisconnect()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void qs::network::NMNetwork::requestActivateConnection(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void qs::network::NMNetwork::requestAddAndActivateConnection(const NMSettingsMap & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void qs::network::NMNetwork::settingsAdded(NMSettings * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void qs::network::NMNetwork::settingsRemoved(NMSettings * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void qs::network::NMNetwork::stateChanged(NMConnectionState::Enum _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void qs::network::NMNetwork::knownChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void qs::network::NMNetwork::reasonChanged(NMConnectionStateReason::Enum _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void qs::network::NMNetwork::deviceFailReasonChanged(NMDeviceStateReason::Enum _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void qs::network::NMNetwork::referenceSettingsChanged(NMSettings * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void qs::network::NMNetwork::visibilityChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN2qs7network16NMGenericNetworkE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::network::NMGenericNetwork::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7network16NMGenericNetworkE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::network::NMGenericNetwork"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NMGenericNetwork, qt_meta_tag_ZN2qs7network16NMGenericNetworkE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qs::network::NMGenericNetwork::staticMetaObject = { {
    QMetaObject::SuperData::link<NMNetwork::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network16NMGenericNetworkE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network16NMGenericNetworkE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7network16NMGenericNetworkE_t>.metaTypes,
    nullptr
} };

void qs::network::NMGenericNetwork::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NMGenericNetwork *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *qs::network::NMGenericNetwork::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::network::NMGenericNetwork::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network16NMGenericNetworkE_t>.strings))
        return static_cast<void*>(this);
    return NMNetwork::qt_metacast(_clname);
}

int qs::network::NMGenericNetwork::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NMNetwork::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN2qs7network17NMWirelessNetworkE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::network::NMWirelessNetwork::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7network17NMWirelessNetworkE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::network::NMWirelessNetwork",
        "disappeared",
        "",
        "signalStrengthChanged",
        "signal",
        "securityChanged",
        "WifiSecurityType::Enum",
        "security",
        "activeApPathChanged",
        "path",
        "referenceApChanged",
        "NMAccessPoint*",
        "ap",
        "capabilitiesChanged",
        "NMWirelessCapabilities::Enum",
        "caps",
        "apRemoved"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'disappeared'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalStrengthChanged'
        QtMocHelpers::SignalData<void(quint8)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UChar, 4 },
        }}),
        // Signal 'securityChanged'
        QtMocHelpers::SignalData<void(WifiSecurityType::Enum)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'activeApPathChanged'
        QtMocHelpers::SignalData<void(QString)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'referenceApChanged'
        QtMocHelpers::SignalData<void(NMAccessPoint *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'capabilitiesChanged'
        QtMocHelpers::SignalData<void(NMWirelessCapabilities::Enum)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Signal 'apRemoved'
        QtMocHelpers::SignalData<void(NMAccessPoint *)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NMWirelessNetwork, qt_meta_tag_ZN2qs7network17NMWirelessNetworkE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qs::network::NMWirelessNetwork::staticMetaObject = { {
    QMetaObject::SuperData::link<NMNetwork::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network17NMWirelessNetworkE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network17NMWirelessNetworkE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7network17NMWirelessNetworkE_t>.metaTypes,
    nullptr
} };

void qs::network::NMWirelessNetwork::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NMWirelessNetwork *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->disappeared(); break;
        case 1: _t->signalStrengthChanged((*reinterpret_cast<std::add_pointer_t<quint8>>(_a[1]))); break;
        case 2: _t->securityChanged((*reinterpret_cast<std::add_pointer_t<WifiSecurityType::Enum>>(_a[1]))); break;
        case 3: _t->activeApPathChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->referenceApChanged((*reinterpret_cast<std::add_pointer_t<NMAccessPoint*>>(_a[1]))); break;
        case 5: _t->capabilitiesChanged((*reinterpret_cast<std::add_pointer_t<NMWirelessCapabilities::Enum>>(_a[1]))); break;
        case 6: _t->apRemoved((*reinterpret_cast<std::add_pointer_t<NMAccessPoint*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< NMAccessPoint* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< NMAccessPoint* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NMWirelessNetwork::*)()>(_a, &NMWirelessNetwork::disappeared, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMWirelessNetwork::*)(quint8 )>(_a, &NMWirelessNetwork::signalStrengthChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMWirelessNetwork::*)(WifiSecurityType::Enum )>(_a, &NMWirelessNetwork::securityChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMWirelessNetwork::*)(QString )>(_a, &NMWirelessNetwork::activeApPathChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMWirelessNetwork::*)(NMAccessPoint * )>(_a, &NMWirelessNetwork::referenceApChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMWirelessNetwork::*)(NMWirelessCapabilities::Enum )>(_a, &NMWirelessNetwork::capabilitiesChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMWirelessNetwork::*)(NMAccessPoint * )>(_a, &NMWirelessNetwork::apRemoved, 6))
            return;
    }
}

const QMetaObject *qs::network::NMWirelessNetwork::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::network::NMWirelessNetwork::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network17NMWirelessNetworkE_t>.strings))
        return static_cast<void*>(this);
    return NMNetwork::qt_metacast(_clname);
}

int qs::network::NMWirelessNetwork::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NMNetwork::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void qs::network::NMWirelessNetwork::disappeared()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void qs::network::NMWirelessNetwork::signalStrengthChanged(quint8 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void qs::network::NMWirelessNetwork::securityChanged(WifiSecurityType::Enum _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void qs::network::NMWirelessNetwork::activeApPathChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void qs::network::NMWirelessNetwork::referenceApChanged(NMAccessPoint * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void qs::network::NMWirelessNetwork::capabilitiesChanged(NMWirelessCapabilities::Enum _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void qs::network::NMWirelessNetwork::apRemoved(NMAccessPoint * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
