// This file was generated by qtwaylandscanner
// source file is ext-workspace-v1.xml

#ifndef QT_WAYLAND_EXT_WORKSPACE_V1
#define QT_WAYLAND_EXT_WORKSPACE_V1

#include "wayland-ext-workspace-v1-client-protocol.h"
#include <QByteArray>
#include <QString>

struct wl_registry;

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {
    class  ext_workspace_manager_v1
    {
    public:
        ext_workspace_manager_v1(struct ::wl_registry *registry, uint32_t id, int version);
        ext_workspace_manager_v1(struct ::ext_workspace_manager_v1 *object);
        ext_workspace_manager_v1();

        virtual ~ext_workspace_manager_v1();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::ext_workspace_manager_v1 *object);

        struct ::ext_workspace_manager_v1 *object() { return m_ext_workspace_manager_v1; }
        const struct ::ext_workspace_manager_v1 *object() const { return m_ext_workspace_manager_v1; }
        static ext_workspace_manager_v1 *fromObject(struct ::ext_workspace_manager_v1 *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        void commit();
        void stop();

    protected:
        virtual void ext_workspace_manager_v1_workspace_group(struct ::ext_workspace_group_handle_v1 *workspace_group);
        virtual void ext_workspace_manager_v1_workspace(struct ::ext_workspace_handle_v1 *workspace);
        virtual void ext_workspace_manager_v1_done();
        virtual void ext_workspace_manager_v1_finished();

    private:
        void init_listener();
        static const struct ext_workspace_manager_v1_listener m_ext_workspace_manager_v1_listener;
        static void handle_workspace_group(
            void *data,
            struct ::ext_workspace_manager_v1 *object,
            struct ::ext_workspace_group_handle_v1 *workspace_group);
        static void handle_workspace(
            void *data,
            struct ::ext_workspace_manager_v1 *object,
            struct ::ext_workspace_handle_v1 *workspace);
        static void handle_done(
            void *data,
            struct ::ext_workspace_manager_v1 *object);
        static void handle_finished(
            void *data,
            struct ::ext_workspace_manager_v1 *object);
        struct ::ext_workspace_manager_v1 *m_ext_workspace_manager_v1;
    };

    class  ext_workspace_group_handle_v1
    {
    public:
        ext_workspace_group_handle_v1(struct ::wl_registry *registry, uint32_t id, int version);
        ext_workspace_group_handle_v1(struct ::ext_workspace_group_handle_v1 *object);
        ext_workspace_group_handle_v1();

        virtual ~ext_workspace_group_handle_v1();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::ext_workspace_group_handle_v1 *object);

        struct ::ext_workspace_group_handle_v1 *object() { return m_ext_workspace_group_handle_v1; }
        const struct ::ext_workspace_group_handle_v1 *object() const { return m_ext_workspace_group_handle_v1; }
        static ext_workspace_group_handle_v1 *fromObject(struct ::ext_workspace_group_handle_v1 *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        enum group_capabilities {
            group_capabilities_create_workspace = 1, // create_workspace request is available
        };

        void create_workspace(const QString &workspace);
        void destroy();

    protected:
        virtual void ext_workspace_group_handle_v1_capabilities(uint32_t capabilities);
        virtual void ext_workspace_group_handle_v1_output_enter(struct ::wl_output *output);
        virtual void ext_workspace_group_handle_v1_output_leave(struct ::wl_output *output);
        virtual void ext_workspace_group_handle_v1_workspace_enter(struct ::ext_workspace_handle_v1 *workspace);
        virtual void ext_workspace_group_handle_v1_workspace_leave(struct ::ext_workspace_handle_v1 *workspace);
        virtual void ext_workspace_group_handle_v1_removed();

    private:
        void init_listener();
        static const struct ext_workspace_group_handle_v1_listener m_ext_workspace_group_handle_v1_listener;
        static void handle_capabilities(
            void *data,
            struct ::ext_workspace_group_handle_v1 *object,
            uint32_t capabilities);
        static void handle_output_enter(
            void *data,
            struct ::ext_workspace_group_handle_v1 *object,
            struct ::wl_output *output);
        static void handle_output_leave(
            void *data,
            struct ::ext_workspace_group_handle_v1 *object,
            struct ::wl_output *output);
        static void handle_workspace_enter(
            void *data,
            struct ::ext_workspace_group_handle_v1 *object,
            struct ::ext_workspace_handle_v1 *workspace);
        static void handle_workspace_leave(
            void *data,
            struct ::ext_workspace_group_handle_v1 *object,
            struct ::ext_workspace_handle_v1 *workspace);
        static void handle_removed(
            void *data,
            struct ::ext_workspace_group_handle_v1 *object);
        struct ::ext_workspace_group_handle_v1 *m_ext_workspace_group_handle_v1;
    };

    class  ext_workspace_handle_v1
    {
    public:
        ext_workspace_handle_v1(struct ::wl_registry *registry, uint32_t id, int version);
        ext_workspace_handle_v1(struct ::ext_workspace_handle_v1 *object);
        ext_workspace_handle_v1();

        virtual ~ext_workspace_handle_v1();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::ext_workspace_handle_v1 *object);

        struct ::ext_workspace_handle_v1 *object() { return m_ext_workspace_handle_v1; }
        const struct ::ext_workspace_handle_v1 *object() const { return m_ext_workspace_handle_v1; }
        static ext_workspace_handle_v1 *fromObject(struct ::ext_workspace_handle_v1 *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        enum state {
            state_active = 1, // the workspace is active
            state_urgent = 2, // the workspace requests attention
            state_hidden = 4,
        };

        enum workspace_capabilities {
            workspace_capabilities_activate = 1, // activate request is available
            workspace_capabilities_deactivate = 2, // deactivate request is available
            workspace_capabilities_remove = 4, // remove request is available
            workspace_capabilities_assign = 8, // assign request is available
        };

        void destroy();
        void activate();
        void deactivate();
        void assign(struct ::ext_workspace_group_handle_v1 *workspace_group);
        void remove();

    protected:
        virtual void ext_workspace_handle_v1_id(const QString &id);
        virtual void ext_workspace_handle_v1_name(const QString &name);
        virtual void ext_workspace_handle_v1_coordinates(wl_array *coordinates);
        virtual void ext_workspace_handle_v1_state(uint32_t state);
        virtual void ext_workspace_handle_v1_capabilities(uint32_t capabilities);
        virtual void ext_workspace_handle_v1_removed();

    private:
        void init_listener();
        static const struct ext_workspace_handle_v1_listener m_ext_workspace_handle_v1_listener;
        static void handle_id(
            void *data,
            struct ::ext_workspace_handle_v1 *object,
            const char *id);
        static void handle_name(
            void *data,
            struct ::ext_workspace_handle_v1 *object,
            const char *name);
        static void handle_coordinates(
            void *data,
            struct ::ext_workspace_handle_v1 *object,
            wl_array *coordinates);
        static void handle_state(
            void *data,
            struct ::ext_workspace_handle_v1 *object,
            uint32_t state);
        static void handle_capabilities(
            void *data,
            struct ::ext_workspace_handle_v1 *object,
            uint32_t capabilities);
        static void handle_removed(
            void *data,
            struct ::ext_workspace_handle_v1 *object);
        struct ::ext_workspace_handle_v1 *m_ext_workspace_handle_v1;
    };
}

QT_WARNING_POP
QT_END_NAMESPACE

#endif
