/****************************************************************************
** Meta object code from reading C++ file 'ext_workspace.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/wayland/windowmanager/ext_workspace.hpp"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ext_workspace.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs7wayland9workspace16WorkspaceManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::wayland::workspace::WorkspaceManager::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7wayland9workspace16WorkspaceManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::wayland::workspace::WorkspaceManager",
        "serverCommit",
        "",
        "workspaceCreated",
        "Workspace*",
        "workspace",
        "workspaceDestroyed",
        "groupCreated",
        "WorkspaceGroup*",
        "group",
        "groupDestroyed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'serverCommit'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'workspaceCreated'
        QtMocHelpers::SignalData<void(Workspace *)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'workspaceDestroyed'
        QtMocHelpers::SignalData<void(Workspace *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'groupCreated'
        QtMocHelpers::SignalData<void(WorkspaceGroup *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'groupDestroyed'
        QtMocHelpers::SignalData<void(WorkspaceGroup *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WorkspaceManager, qt_meta_tag_ZN2qs7wayland9workspace16WorkspaceManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qs::wayland::workspace::WorkspaceManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandClientExtensionTemplate<WorkspaceManager>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland9workspace16WorkspaceManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland9workspace16WorkspaceManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7wayland9workspace16WorkspaceManagerE_t>.metaTypes,
    nullptr
} };

void qs::wayland::workspace::WorkspaceManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WorkspaceManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->serverCommit(); break;
        case 1: _t->workspaceCreated((*reinterpret_cast<std::add_pointer_t<Workspace*>>(_a[1]))); break;
        case 2: _t->workspaceDestroyed((*reinterpret_cast<std::add_pointer_t<Workspace*>>(_a[1]))); break;
        case 3: _t->groupCreated((*reinterpret_cast<std::add_pointer_t<WorkspaceGroup*>>(_a[1]))); break;
        case 4: _t->groupDestroyed((*reinterpret_cast<std::add_pointer_t<WorkspaceGroup*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WorkspaceManager::*)()>(_a, &WorkspaceManager::serverCommit, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorkspaceManager::*)(Workspace * )>(_a, &WorkspaceManager::workspaceCreated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorkspaceManager::*)(Workspace * )>(_a, &WorkspaceManager::workspaceDestroyed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorkspaceManager::*)(WorkspaceGroup * )>(_a, &WorkspaceManager::groupCreated, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorkspaceManager::*)(WorkspaceGroup * )>(_a, &WorkspaceManager::groupDestroyed, 4))
            return;
    }
}

const QMetaObject *qs::wayland::workspace::WorkspaceManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::wayland::workspace::WorkspaceManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland9workspace16WorkspaceManagerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::ext_workspace_manager_v1"))
        return static_cast< QtWayland::ext_workspace_manager_v1*>(this);
    return QWaylandClientExtensionTemplate<WorkspaceManager>::qt_metacast(_clname);
}

int qs::wayland::workspace::WorkspaceManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandClientExtensionTemplate<WorkspaceManager>::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void qs::wayland::workspace::WorkspaceManager::serverCommit()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void qs::wayland::workspace::WorkspaceManager::workspaceCreated(Workspace * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void qs::wayland::workspace::WorkspaceManager::workspaceDestroyed(Workspace * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void qs::wayland::workspace::WorkspaceManager::groupCreated(WorkspaceGroup * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void qs::wayland::workspace::WorkspaceManager::groupDestroyed(WorkspaceGroup * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
