/****************************************************************************
** Meta object code from reading C++ file 'adapter.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../src/bluetooth/adapter.hpp"
#include <QtCore/qmetatype.h>
#include <QtCore/QProperty>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'adapter.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs9bluetooth21BluetoothAdapterStateE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::bluetooth::BluetoothAdapterState::qt_create_metaobjectdata<qt_meta_tag_ZN2qs9bluetooth21BluetoothAdapterStateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::bluetooth::BluetoothAdapterState",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "toString",
        "",
        "BluetoothAdapterState::Enum",
        "state",
        "Enum",
        "Disabled",
        "Enabled",
        "Enabling",
        "Disabling",
        "Blocked"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'toString'
        QtMocHelpers::MethodData<QString(BluetoothAdapterState::Enum)>(5, 6, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 7, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Enum'
        QtMocHelpers::EnumData<enum Enum>(9, 9, QMC::EnumFlags{}).add({
            {   10, Enum::Disabled },
            {   11, Enum::Enabled },
            {   12, Enum::Enabling },
            {   13, Enum::Disabling },
            {   14, Enum::Blocked },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<BluetoothAdapterState, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject qs::bluetooth::BluetoothAdapterState::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs9bluetooth21BluetoothAdapterStateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs9bluetooth21BluetoothAdapterStateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs9bluetooth21BluetoothAdapterStateE_t>.metaTypes,
    nullptr
} };

void qs::bluetooth::BluetoothAdapterState::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BluetoothAdapterState *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->toString((*reinterpret_cast<std::add_pointer_t<BluetoothAdapterState::Enum>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *qs::bluetooth::BluetoothAdapterState::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::bluetooth::BluetoothAdapterState::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs9bluetooth21BluetoothAdapterStateE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::bluetooth::BluetoothAdapterState::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN2qs9bluetooth16BluetoothAdapterE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::bluetooth::BluetoothAdapter::qt_create_metaobjectdata<qt_meta_tag_ZN2qs9bluetooth16BluetoothAdapterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::bluetooth::BluetoothAdapter",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "nameChanged",
        "enabledChanged",
        "stateChanged",
        "discoverableChanged",
        "discoverableTimeoutChanged",
        "discoveringChanged",
        "pairableChanged",
        "pairableTimeoutChanged",
        "name",
        "enabled",
        "state",
        "BluetoothAdapterState::Enum",
        "discoverable",
        "discoverableTimeout",
        "discovering",
        "pairable",
        "pairableTimeout",
        "devices",
        "UntypedObjectModel*",
        "adapterId",
        "dbusPath"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'discoverableChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'discoverableTimeoutChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'discoveringChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pairableChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pairableTimeoutChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Bindable, 0),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'state'
        QtMocHelpers::PropertyData<BluetoothAdapterState::Enum>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Bindable, 2),
        // property 'discoverable'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'discoverableTimeout'
        QtMocHelpers::PropertyData<quint32>(20, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'discovering'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'pairable'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'pairableTimeout'
        QtMocHelpers::PropertyData<quint32>(23, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'devices'
        QtMocHelpers::PropertyData<UntypedObjectModel*>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'adapterId'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dbusPath'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<BluetoothAdapter, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN2qs9bluetooth16BluetoothAdapterE[] = {
    QMetaObject::SuperData::link<qs::bluetooth::BluetoothAdapterState::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject qs::bluetooth::BluetoothAdapter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs9bluetooth16BluetoothAdapterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs9bluetooth16BluetoothAdapterE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN2qs9bluetooth16BluetoothAdapterE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs9bluetooth16BluetoothAdapterE_t>.metaTypes,
    nullptr
} };

void qs::bluetooth::BluetoothAdapter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BluetoothAdapter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nameChanged(); break;
        case 1: _t->enabledChanged(); break;
        case 2: _t->stateChanged(); break;
        case 3: _t->discoverableChanged(); break;
        case 4: _t->discoverableTimeoutChanged(); break;
        case 5: _t->discoveringChanged(); break;
        case 6: _t->pairableChanged(); break;
        case 7: _t->pairableTimeoutChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BluetoothAdapter::*)()>(_a, &BluetoothAdapter::nameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothAdapter::*)()>(_a, &BluetoothAdapter::enabledChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothAdapter::*)()>(_a, &BluetoothAdapter::stateChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothAdapter::*)()>(_a, &BluetoothAdapter::discoverableChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothAdapter::*)()>(_a, &BluetoothAdapter::discoverableTimeoutChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothAdapter::*)()>(_a, &BluetoothAdapter::discoveringChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothAdapter::*)()>(_a, &BluetoothAdapter::pairableChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothAdapter::*)()>(_a, &BluetoothAdapter::pairableTimeoutChanged, 7))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 8:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< UntypedObjectModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->bindableName().value(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 2: *reinterpret_cast<BluetoothAdapterState::Enum*>(_v) = _t->bindableState().value(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->discoverable(); break;
        case 4: *reinterpret_cast<quint32*>(_v) = _t->discoverableTimeout(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->discovering(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->pairable(); break;
        case 7: *reinterpret_cast<quint32*>(_v) = _t->pairableTimeout(); break;
        case 8: *reinterpret_cast<UntypedObjectModel**>(_v) = _t->devices(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->adapterId(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->path(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setDiscoverable(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setDiscoverableTimeout(*reinterpret_cast<quint32*>(_v)); break;
        case 5: _t->setDiscovering(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setPairable(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setPairableTimeout(*reinterpret_cast<quint32*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::BindableProperty) {
        switch (_id) {
        case 0: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableName(); break;
        case 2: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableState(); break;
        default: break;
        }
    }
}

const QMetaObject *qs::bluetooth::BluetoothAdapter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::bluetooth::BluetoothAdapter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs9bluetooth16BluetoothAdapterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::bluetooth::BluetoothAdapter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void qs::bluetooth::BluetoothAdapter::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void qs::bluetooth::BluetoothAdapter::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void qs::bluetooth::BluetoothAdapter::stateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void qs::bluetooth::BluetoothAdapter::discoverableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void qs::bluetooth::BluetoothAdapter::discoverableTimeoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void qs::bluetooth::BluetoothAdapter::discoveringChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void qs::bluetooth::BluetoothAdapter::pairableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void qs::bluetooth::BluetoothAdapter::pairableTimeoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
