// This file is autogenerated by CMake. Do not edit.

#include <QtCore/qtsymbolmacros.h>
#include <QtQml/qqmlextensionplugin.h>


QT_DECLARE_EXTERN_RESOURCE(qmlcache_quickshell_io)
QT_DECLARE_EXTERN_RESOURCE(qmake_Quickshell_Io)
QT_DECLARE_EXTERN_RESOURCE(quickshell_io_raw_qml_0)


QT_DECLARE_EXTERN_SYMBOL_VOID(qml_register_types_Quickshell_Io)

class Quickshell_IoPlugin : public QQmlEngineExtensionPlugin
{
    Q_OBJECT
    Q_PLUGIN_METADATA(IID QQmlEngineExtensionInterface_iid)

public:
    Quickshell_IoPlugin(QObject *parent = nullptr) : QQmlEngineExtensionPlugin(parent)
    {

QT_KEEP_SYMBOL(qml_register_types_Quickshell_Io)
QT_KEEP_RESOURCE(qmlcache_quickshell_io)
QT_KEEP_RESOURCE(qmake_Quickshell_Io)
QT_KEEP_RESOURCE(quickshell_io_raw_qml_0)
    }
};



#include "quickshell-ioplugin_Quickshell_IoPlugin.moc"
