/****************************************************************************
** Meta object code from reading C++ file 'qml.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../src/wayland/hyprland/global_shortcuts/qml.hpp"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qml.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs8hyprland16global_shortcuts14GlobalShortcutE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::hyprland::global_shortcuts::GlobalShortcut::qt_create_metaobjectdata<qt_meta_tag_ZN2qs8hyprland16global_shortcuts14GlobalShortcutE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::hyprland::global_shortcuts::GlobalShortcut",
        "QML.Element",
        "auto",
        "pressed",
        "",
        "released",
        "pressedChanged",
        "appidChanged",
        "nameChanged",
        "descriptionChanged",
        "triggerDescriptionChanged",
        "onPressed",
        "onReleased",
        "appid",
        "name",
        "description",
        "triggerDescription"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'pressed'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'released'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pressedChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'appidChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'descriptionChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'triggerDescriptionChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onPressed'
        QtMocHelpers::SlotData<void()>(11, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onReleased'
        QtMocHelpers::SlotData<void()>(12, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'pressed'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'appid'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'triggerDescription'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<GlobalShortcut, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject qs::hyprland::global_shortcuts::GlobalShortcut::staticMetaObject = { {
    QMetaObject::SuperData::link<PostReloadHook::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs8hyprland16global_shortcuts14GlobalShortcutE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs8hyprland16global_shortcuts14GlobalShortcutE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs8hyprland16global_shortcuts14GlobalShortcutE_t>.metaTypes,
    nullptr
} };

void qs::hyprland::global_shortcuts::GlobalShortcut::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GlobalShortcut *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->pressed(); break;
        case 1: _t->released(); break;
        case 2: _t->pressedChanged(); break;
        case 3: _t->appidChanged(); break;
        case 4: _t->nameChanged(); break;
        case 5: _t->descriptionChanged(); break;
        case 6: _t->triggerDescriptionChanged(); break;
        case 7: _t->onPressed(); break;
        case 8: _t->onReleased(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GlobalShortcut::*)()>(_a, &GlobalShortcut::pressed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalShortcut::*)()>(_a, &GlobalShortcut::released, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalShortcut::*)()>(_a, &GlobalShortcut::pressedChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalShortcut::*)()>(_a, &GlobalShortcut::appidChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalShortcut::*)()>(_a, &GlobalShortcut::nameChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalShortcut::*)()>(_a, &GlobalShortcut::descriptionChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalShortcut::*)()>(_a, &GlobalShortcut::triggerDescriptionChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isPressed(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->appid(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->description(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->triggerDescription(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setAppid(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setDescription(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setTriggerDescription(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *qs::hyprland::global_shortcuts::GlobalShortcut::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::hyprland::global_shortcuts::GlobalShortcut::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs8hyprland16global_shortcuts14GlobalShortcutE_t>.strings))
        return static_cast<void*>(this);
    return PostReloadHook::qt_metacast(_clname);
}

int qs::hyprland::global_shortcuts::GlobalShortcut::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PostReloadHook::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void qs::hyprland::global_shortcuts::GlobalShortcut::pressed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void qs::hyprland::global_shortcuts::GlobalShortcut::released()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void qs::hyprland::global_shortcuts::GlobalShortcut::pressedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void qs::hyprland::global_shortcuts::GlobalShortcut::appidChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void qs::hyprland::global_shortcuts::GlobalShortcut::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void qs::hyprland::global_shortcuts::GlobalShortcut::descriptionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void qs::hyprland::global_shortcuts::GlobalShortcut::triggerDescriptionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
