/****************************************************************************
** Meta object code from reading C++ file 'qml.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/services/pam/qml.hpp"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qml.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10PamContextE_t {};
} // unnamed namespace

template <> constexpr inline auto PamContext::qt_create_metaobjectdata<qt_meta_tag_ZN10PamContextE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PamContext",
        "QML.Element",
        "auto",
        "completed",
        "",
        "PamResult::Enum",
        "result",
        "error",
        "PamError::Enum",
        "pamMessage",
        "activeChanged",
        "configChanged",
        "configDirectoryChanged",
        "userChanged",
        "messageChanged",
        "messageIsErrorChanged",
        "responseRequiredChanged",
        "responseVisibleChanged",
        "onCompleted",
        "onError",
        "onMessage",
        "message",
        "isError",
        "responseRequired",
        "responseVisible",
        "start",
        "abort",
        "respond",
        "response",
        "active",
        "config",
        "configDirectory",
        "user",
        "messageIsError"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'completed'
        QtMocHelpers::SignalData<void(PamResult::Enum)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'error'
        QtMocHelpers::SignalData<void(PamError::Enum)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 7 },
        }}),
        // Signal 'pamMessage'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'configChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'configDirectoryChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'userChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'messageChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'messageIsErrorChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'responseRequiredChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'responseVisibleChanged'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onCompleted'
        QtMocHelpers::SlotData<void(PamResult::Enum)>(18, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'onError'
        QtMocHelpers::SlotData<void(PamError::Enum)>(19, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 7 },
        }}),
        // Slot 'onMessage'
        QtMocHelpers::SlotData<void(QString, bool, bool, bool)>(20, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 21 }, { QMetaType::Bool, 22 }, { QMetaType::Bool, 23 }, { QMetaType::Bool, 24 },
        }}),
        // Method 'start'
        QtMocHelpers::MethodData<bool()>(25, 4, QMC::AccessPublic, QMetaType::Bool),
        // Method 'abort'
        QtMocHelpers::MethodData<void()>(26, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'respond'
        QtMocHelpers::MethodData<void(const QString &)>(27, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'active'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'config'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'configDirectory'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'user'
        QtMocHelpers::PropertyData<QString>(32, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'message'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags, 7),
        // property 'messageIsError'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags, 8),
        // property 'responseRequired'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags, 9),
        // property 'responseVisible'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags, 10),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<PamContext, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PamContext::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PamContextE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PamContextE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10PamContextE_t>.metaTypes,
    nullptr
} };

void PamContext::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PamContext *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->completed((*reinterpret_cast<std::add_pointer_t<PamResult::Enum>>(_a[1]))); break;
        case 1: _t->error((*reinterpret_cast<std::add_pointer_t<PamError::Enum>>(_a[1]))); break;
        case 2: _t->pamMessage(); break;
        case 3: _t->activeChanged(); break;
        case 4: _t->configChanged(); break;
        case 5: _t->configDirectoryChanged(); break;
        case 6: _t->userChanged(); break;
        case 7: _t->messageChanged(); break;
        case 8: _t->messageIsErrorChanged(); break;
        case 9: _t->responseRequiredChanged(); break;
        case 10: _t->responseVisibleChanged(); break;
        case 11: _t->onCompleted((*reinterpret_cast<std::add_pointer_t<PamResult::Enum>>(_a[1]))); break;
        case 12: _t->onError((*reinterpret_cast<std::add_pointer_t<PamError::Enum>>(_a[1]))); break;
        case 13: _t->onMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 14: { bool _r = _t->start();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->abort(); break;
        case 16: _t->respond((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PamContext::*)(PamResult::Enum )>(_a, &PamContext::completed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamContext::*)(PamError::Enum )>(_a, &PamContext::error, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamContext::*)()>(_a, &PamContext::pamMessage, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamContext::*)()>(_a, &PamContext::activeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamContext::*)()>(_a, &PamContext::configChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamContext::*)()>(_a, &PamContext::configDirectoryChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamContext::*)()>(_a, &PamContext::userChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamContext::*)()>(_a, &PamContext::messageChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamContext::*)()>(_a, &PamContext::messageIsErrorChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamContext::*)()>(_a, &PamContext::responseRequiredChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamContext::*)()>(_a, &PamContext::responseVisibleChanged, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isActive(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->config(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->configDirectory(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->user(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->message(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->messageIsError(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isResponseRequired(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isResponseVisible(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setActive(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setConfig(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setConfigDirectory(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setUser(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PamContext::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PamContext::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PamContextE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int PamContext::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void PamContext::completed(PamResult::Enum _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PamContext::error(PamError::Enum _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PamContext::pamMessage()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PamContext::activeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PamContext::configChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PamContext::configDirectoryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void PamContext::userChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void PamContext::messageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void PamContext::messageIsErrorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void PamContext::responseRequiredChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void PamContext::responseVisibleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
