/****************************************************************************
** Meta object code from reading C++ file 'qml.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/wayland/background_effect/qml.hpp"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qml.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs7wayland17background_effect16BackgroundEffectE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::wayland::background_effect::BackgroundEffect::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7wayland17background_effect16BackgroundEffectE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::wayland::background_effect::BackgroundEffect",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "BackgroundEffect can only be used as an attached object.",
        "QML.Attached",
        "BackgroundEffect",
        "blurRegionChanged",
        "",
        "onWindowConnected",
        "onWindowVisibleChanged",
        "onWaylandWindowDestroyed",
        "onWaylandSurfaceCreated",
        "onWaylandSurfaceDestroyed",
        "onProxyWindowDestroyed",
        "onBlurRegionDestroyed",
        "onWindowPolished",
        "updateBlurRegion",
        "blurRegion",
        "PendingRegion*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'blurRegionChanged'
        QtMocHelpers::SignalData<void()>(9, 10, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onWindowConnected'
        QtMocHelpers::SlotData<void()>(11, 10, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onWindowVisibleChanged'
        QtMocHelpers::SlotData<void()>(12, 10, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onWaylandWindowDestroyed'
        QtMocHelpers::SlotData<void()>(13, 10, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onWaylandSurfaceCreated'
        QtMocHelpers::SlotData<void()>(14, 10, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onWaylandSurfaceDestroyed'
        QtMocHelpers::SlotData<void()>(15, 10, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onProxyWindowDestroyed'
        QtMocHelpers::SlotData<void()>(16, 10, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onBlurRegionDestroyed'
        QtMocHelpers::SlotData<void()>(17, 10, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onWindowPolished'
        QtMocHelpers::SlotData<void()>(18, 10, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateBlurRegion'
        QtMocHelpers::SlotData<void()>(19, 10, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'blurRegion'
        QtMocHelpers::PropertyData<PendingRegion*>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<BackgroundEffect, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject qs::wayland::background_effect::BackgroundEffect::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland17background_effect16BackgroundEffectE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland17background_effect16BackgroundEffectE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7wayland17background_effect16BackgroundEffectE_t>.metaTypes,
    nullptr
} };

void qs::wayland::background_effect::BackgroundEffect::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BackgroundEffect *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->blurRegionChanged(); break;
        case 1: _t->onWindowConnected(); break;
        case 2: _t->onWindowVisibleChanged(); break;
        case 3: _t->onWaylandWindowDestroyed(); break;
        case 4: _t->onWaylandSurfaceCreated(); break;
        case 5: _t->onWaylandSurfaceDestroyed(); break;
        case 6: _t->onProxyWindowDestroyed(); break;
        case 7: _t->onBlurRegionDestroyed(); break;
        case 8: _t->onWindowPolished(); break;
        case 9: _t->updateBlurRegion(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BackgroundEffect::*)()>(_a, &BackgroundEffect::blurRegionChanged, 0))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PendingRegion* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<PendingRegion**>(_v) = _t->blurRegion(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBlurRegion(*reinterpret_cast<PendingRegion**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *qs::wayland::background_effect::BackgroundEffect::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::wayland::background_effect::BackgroundEffect::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland17background_effect16BackgroundEffectE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::wayland::background_effect::BackgroundEffect::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void qs::wayland::background_effect::BackgroundEffect::blurRegionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
