/****************************************************************************
** Meta object code from reading C++ file 'accesspoint.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/network/nm/accesspoint.hpp"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'accesspoint.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs7network13NMAccessPointE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::network::NMAccessPoint::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7network13NMAccessPointE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::network::NMAccessPoint",
        "loaded",
        "",
        "ssidChanged",
        "ssid",
        "signalStrengthChanged",
        "signal",
        "flagsChanged",
        "NM80211ApFlags::Enum",
        "flags",
        "wpaFlagsChanged",
        "NM80211ApSecurityFlags::Enum",
        "wpaFlags",
        "rsnFlagsChanged",
        "rsnFlags",
        "modeChanged",
        "NM80211Mode::Enum",
        "mode",
        "securityChanged",
        "WifiSecurityType::Enum",
        "security"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'loaded'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ssidChanged'
        QtMocHelpers::SignalData<void(const QByteArray &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 4 },
        }}),
        // Signal 'signalStrengthChanged'
        QtMocHelpers::SignalData<void(quint8)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UChar, 6 },
        }}),
        // Signal 'flagsChanged'
        QtMocHelpers::SignalData<void(NM80211ApFlags::Enum)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'wpaFlagsChanged'
        QtMocHelpers::SignalData<void(NM80211ApSecurityFlags::Enum)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'rsnFlagsChanged'
        QtMocHelpers::SignalData<void(NM80211ApSecurityFlags::Enum)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 14 },
        }}),
        // Signal 'modeChanged'
        QtMocHelpers::SignalData<void(NM80211Mode::Enum)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Signal 'securityChanged'
        QtMocHelpers::SignalData<void(WifiSecurityType::Enum)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NMAccessPoint, qt_meta_tag_ZN2qs7network13NMAccessPointE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qs::network::NMAccessPoint::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network13NMAccessPointE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network13NMAccessPointE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7network13NMAccessPointE_t>.metaTypes,
    nullptr
} };

void qs::network::NMAccessPoint::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NMAccessPoint *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->loaded(); break;
        case 1: _t->ssidChanged((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 2: _t->signalStrengthChanged((*reinterpret_cast<std::add_pointer_t<quint8>>(_a[1]))); break;
        case 3: _t->flagsChanged((*reinterpret_cast<std::add_pointer_t<NM80211ApFlags::Enum>>(_a[1]))); break;
        case 4: _t->wpaFlagsChanged((*reinterpret_cast<std::add_pointer_t<NM80211ApSecurityFlags::Enum>>(_a[1]))); break;
        case 5: _t->rsnFlagsChanged((*reinterpret_cast<std::add_pointer_t<NM80211ApSecurityFlags::Enum>>(_a[1]))); break;
        case 6: _t->modeChanged((*reinterpret_cast<std::add_pointer_t<NM80211Mode::Enum>>(_a[1]))); break;
        case 7: _t->securityChanged((*reinterpret_cast<std::add_pointer_t<WifiSecurityType::Enum>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NMAccessPoint::*)()>(_a, &NMAccessPoint::loaded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMAccessPoint::*)(const QByteArray & )>(_a, &NMAccessPoint::ssidChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMAccessPoint::*)(quint8 )>(_a, &NMAccessPoint::signalStrengthChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMAccessPoint::*)(NM80211ApFlags::Enum )>(_a, &NMAccessPoint::flagsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMAccessPoint::*)(NM80211ApSecurityFlags::Enum )>(_a, &NMAccessPoint::wpaFlagsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMAccessPoint::*)(NM80211ApSecurityFlags::Enum )>(_a, &NMAccessPoint::rsnFlagsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMAccessPoint::*)(NM80211Mode::Enum )>(_a, &NMAccessPoint::modeChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMAccessPoint::*)(WifiSecurityType::Enum )>(_a, &NMAccessPoint::securityChanged, 7))
            return;
    }
}

const QMetaObject *qs::network::NMAccessPoint::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::network::NMAccessPoint::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network13NMAccessPointE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::network::NMAccessPoint::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void qs::network::NMAccessPoint::loaded()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void qs::network::NMAccessPoint::ssidChanged(const QByteArray & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void qs::network::NMAccessPoint::signalStrengthChanged(quint8 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void qs::network::NMAccessPoint::flagsChanged(NM80211ApFlags::Enum _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void qs::network::NMAccessPoint::wpaFlagsChanged(NM80211ApSecurityFlags::Enum _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void qs::network::NMAccessPoint::rsnFlagsChanged(NM80211ApSecurityFlags::Enum _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void qs::network::NMAccessPoint::modeChanged(NM80211Mode::Enum _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void qs::network::NMAccessPoint::securityChanged(WifiSecurityType::Enum _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
