/****************************************************************************
** Meta object code from reading C++ file 'inhibitor.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/wayland/shortcuts_inhibit/inhibitor.hpp"
#include <QtCore/qmetatype.h>
#include <QtCore/QProperty>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'inhibitor.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs7wayland17shortcuts_inhibit17ShortcutInhibitorE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::wayland::shortcuts_inhibit::ShortcutInhibitor::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7wayland17shortcuts_inhibit17ShortcutInhibitorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::wayland::shortcuts_inhibit::ShortcutInhibitor",
        "QML.Element",
        "auto",
        "enabledChanged",
        "",
        "windowChanged",
        "activeChanged",
        "cancelled",
        "onWindowDestroyed",
        "onWindowVisibilityChanged",
        "onWaylandWindowDestroyed",
        "onWaylandSurfaceCreated",
        "onWaylandSurfaceDestroyed",
        "onInhibitorActiveChanged",
        "enabled",
        "window",
        "active"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'windowChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cancelled'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onWindowDestroyed'
        QtMocHelpers::SlotData<void()>(8, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onWindowVisibilityChanged'
        QtMocHelpers::SlotData<void()>(9, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onWaylandWindowDestroyed'
        QtMocHelpers::SlotData<void()>(10, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onWaylandSurfaceCreated'
        QtMocHelpers::SlotData<void()>(11, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onWaylandSurfaceDestroyed'
        QtMocHelpers::SlotData<void()>(12, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onInhibitorActiveChanged'
        QtMocHelpers::SlotData<void()>(13, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Bindable, 0),
        // property 'window'
        QtMocHelpers::PropertyData<QObject*>(15, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Bindable, 1),
        // property 'active'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ShortcutInhibitor, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject qs::wayland::shortcuts_inhibit::ShortcutInhibitor::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland17shortcuts_inhibit17ShortcutInhibitorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland17shortcuts_inhibit17ShortcutInhibitorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7wayland17shortcuts_inhibit17ShortcutInhibitorE_t>.metaTypes,
    nullptr
} };

void qs::wayland::shortcuts_inhibit::ShortcutInhibitor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ShortcutInhibitor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->enabledChanged(); break;
        case 1: _t->windowChanged(); break;
        case 2: _t->activeChanged(); break;
        case 3: _t->cancelled(); break;
        case 4: _t->onWindowDestroyed(); break;
        case 5: _t->onWindowVisibilityChanged(); break;
        case 6: _t->onWaylandWindowDestroyed(); break;
        case 7: _t->onWaylandSurfaceCreated(); break;
        case 8: _t->onWaylandSurfaceDestroyed(); break;
        case 9: _t->onInhibitorActiveChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ShortcutInhibitor::*)()>(_a, &ShortcutInhibitor::enabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShortcutInhibitor::*)()>(_a, &ShortcutInhibitor::windowChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShortcutInhibitor::*)()>(_a, &ShortcutInhibitor::activeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShortcutInhibitor::*)()>(_a, &ShortcutInhibitor::cancelled, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->bindableEnabled().value(); break;
        case 1: *reinterpret_cast<QObject**>(_v) = _t->bindableWindow().value(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->bindableActive().value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: {
            _t->bindableEnabled().setValue(*reinterpret_cast<bool*>(_v));
            break;
        }
        case 1: {
            _t->bindableWindow().setValue(*reinterpret_cast<QObject**>(_v));
            break;
        }
        default: break;
        }
    }
    if (_c == QMetaObject::BindableProperty) {
        switch (_id) {
        case 0: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableEnabled(); break;
        case 1: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableWindow(); break;
        case 2: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableActive(); break;
        default: break;
        }
    }
}

const QMetaObject *qs::wayland::shortcuts_inhibit::ShortcutInhibitor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::wayland::shortcuts_inhibit::ShortcutInhibitor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland17shortcuts_inhibit17ShortcutInhibitorE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::wayland::shortcuts_inhibit::ShortcutInhibitor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void qs::wayland::shortcuts_inhibit::ShortcutInhibitor::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void qs::wayland::shortcuts_inhibit::ShortcutInhibitor::windowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void qs::wayland::shortcuts_inhibit::ShortcutInhibitor::activeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void qs::wayland::shortcuts_inhibit::ShortcutInhibitor::cancelled()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
