/****************************************************************************
** Meta object code from reading C++ file 'wlr_layershell.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/wayland/wlr_layershell/wlr_layershell.hpp"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'wlr_layershell.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs7wayland10layershell13WlrLayershellE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::wayland::layershell::WlrLayershell::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7wayland10layershell13WlrLayershellE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::wayland::layershell::WlrLayershell",
        "QML.Attached",
        "WlrLayershell",
        "QML.Element",
        "auto",
        "layerChanged",
        "",
        "namespaceChanged",
        "keyboardFocusChanged",
        "anchorsChanged",
        "exclusiveZoneChanged",
        "exclusionModeChanged",
        "marginsChanged",
        "updateAutoExclusion",
        "onBridgeDestroyed",
        "layer",
        "qs::wayland::layershell::WlrLayer::Enum",
        "namespace",
        "keyboardFocus",
        "qs::wayland::layershell::WlrKeyboardFocus::Enum",
        "anchors",
        "Anchors",
        "exclusiveZone",
        "exclusionMode",
        "ExclusionMode::Enum",
        "margins",
        "Margins",
        "aboveWindows",
        "focusable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'layerChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'namespaceChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keyboardFocusChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'anchorsChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'exclusiveZoneChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'exclusionModeChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'marginsChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateAutoExclusion'
        QtMocHelpers::SlotData<void()>(13, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onBridgeDestroyed'
        QtMocHelpers::SlotData<void()>(14, 6, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'layer'
        QtMocHelpers::PropertyData<qs::wayland::layershell::WlrLayer::Enum>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'namespace'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'keyboardFocus'
        QtMocHelpers::PropertyData<qs::wayland::layershell::WlrKeyboardFocus::Enum>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'anchors'
        QtMocHelpers::PropertyData<Anchors>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'exclusiveZone'
        QtMocHelpers::PropertyData<qint32>(22, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'exclusionMode'
        QtMocHelpers::PropertyData<ExclusionMode::Enum>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'margins'
        QtMocHelpers::PropertyData<Margins>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'aboveWindows'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'focusable'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<WlrLayershell, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN2qs7wayland10layershell13WlrLayershellE[] = {
    QMetaObject::SuperData::link<qs::wayland::layershell::WlrLayer::staticMetaObject>(),
    QMetaObject::SuperData::link<qs::wayland::layershell::WlrKeyboardFocus::staticMetaObject>(),
    QMetaObject::SuperData::link<ExclusionMode::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject qs::wayland::layershell::WlrLayershell::staticMetaObject = { {
    QMetaObject::SuperData::link<ProxyWindowBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland10layershell13WlrLayershellE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland10layershell13WlrLayershellE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN2qs7wayland10layershell13WlrLayershellE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7wayland10layershell13WlrLayershellE_t>.metaTypes,
    nullptr
} };

void qs::wayland::layershell::WlrLayershell::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WlrLayershell *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->layerChanged(); break;
        case 1: _t->namespaceChanged(); break;
        case 2: _t->keyboardFocusChanged(); break;
        case 3: _t->anchorsChanged(); break;
        case 4: _t->exclusiveZoneChanged(); break;
        case 5: _t->exclusionModeChanged(); break;
        case 6: _t->marginsChanged(); break;
        case 7: _t->updateAutoExclusion(); break;
        case 8: _t->onBridgeDestroyed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WlrLayershell::*)()>(_a, &WlrLayershell::layerChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WlrLayershell::*)()>(_a, &WlrLayershell::namespaceChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WlrLayershell::*)()>(_a, &WlrLayershell::keyboardFocusChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (WlrLayershell::*)()>(_a, &WlrLayershell::anchorsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (WlrLayershell::*)()>(_a, &WlrLayershell::exclusiveZoneChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (WlrLayershell::*)()>(_a, &WlrLayershell::exclusionModeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (WlrLayershell::*)()>(_a, &WlrLayershell::marginsChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qs::wayland::layershell::WlrLayer::Enum*>(_v) = _t->layer(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->ns(); break;
        case 2: *reinterpret_cast<qs::wayland::layershell::WlrKeyboardFocus::Enum*>(_v) = _t->keyboardFocus(); break;
        case 3: *reinterpret_cast<Anchors*>(_v) = _t->anchors(); break;
        case 4: *reinterpret_cast<qint32*>(_v) = _t->exclusiveZone(); break;
        case 5: *reinterpret_cast<ExclusionMode::Enum*>(_v) = _t->exclusionMode(); break;
        case 6: *reinterpret_cast<Margins*>(_v) = _t->margins(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->aboveWindows(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->focusable(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLayer(*reinterpret_cast<qs::wayland::layershell::WlrLayer::Enum*>(_v)); break;
        case 1: _t->setNamespace(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setKeyboardFocus(*reinterpret_cast<qs::wayland::layershell::WlrKeyboardFocus::Enum*>(_v)); break;
        case 3: _t->setAnchors(*reinterpret_cast<Anchors*>(_v)); break;
        case 4: _t->setExclusiveZone(*reinterpret_cast<qint32*>(_v)); break;
        case 5: _t->setExclusionMode(*reinterpret_cast<ExclusionMode::Enum*>(_v)); break;
        case 6: _t->setMargins(*reinterpret_cast<Margins*>(_v)); break;
        case 7: _t->setAboveWindows(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setFocusable(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *qs::wayland::layershell::WlrLayershell::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::wayland::layershell::WlrLayershell::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland10layershell13WlrLayershellE_t>.strings))
        return static_cast<void*>(this);
    return ProxyWindowBase::qt_metacast(_clname);
}

int qs::wayland::layershell::WlrLayershell::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ProxyWindowBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void qs::wayland::layershell::WlrLayershell::layerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void qs::wayland::layershell::WlrLayershell::namespaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void qs::wayland::layershell::WlrLayershell::keyboardFocusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void qs::wayland::layershell::WlrLayershell::anchorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void qs::wayland::layershell::WlrLayershell::exclusiveZoneChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void qs::wayland::layershell::WlrLayershell::exclusionModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void qs::wayland::layershell::WlrLayershell::marginsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
namespace {
struct qt_meta_tag_ZN2qs7wayland10layershell21WaylandPanelInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::wayland::layershell::WaylandPanelInterface::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7wayland10layershell21WaylandPanelInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::wayland::layershell::WaylandPanelInterface"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WaylandPanelInterface, qt_meta_tag_ZN2qs7wayland10layershell21WaylandPanelInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qs::wayland::layershell::WaylandPanelInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<PanelWindowInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland10layershell21WaylandPanelInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland10layershell21WaylandPanelInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7wayland10layershell21WaylandPanelInterfaceE_t>.metaTypes,
    nullptr
} };

void qs::wayland::layershell::WaylandPanelInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WaylandPanelInterface *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *qs::wayland::layershell::WaylandPanelInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::wayland::layershell::WaylandPanelInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland10layershell21WaylandPanelInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return PanelWindowInterface::qt_metacast(_clname);
}

int qs::wayland::layershell::WaylandPanelInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PanelWindowInterface::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN2qs7wayland10layershell8WlrLayerE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::wayland::layershell::WlrLayer::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7wayland10layershell8WlrLayerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::wayland::layershell::WlrLayer",
        "QML.Element",
        "auto",
        "Enum",
        "Background",
        "Bottom",
        "Top",
        "Overlay"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Enum'
        QtMocHelpers::EnumData<Enum>(3, 3, QMC::EnumFlags{}).add({
            {    4, Enum::Background },
            {    5, Enum::Bottom },
            {    6, Enum::Top },
            {    7, Enum::Overlay },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN2qs7wayland10layershell8WlrLayerE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN2qs7wayland10layershell8WlrLayerE =
    qs::wayland::layershell::WlrLayer::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7wayland10layershell8WlrLayerE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN2qs7wayland10layershell8WlrLayerE =
    qt_staticMetaObjectContent_ZN2qs7wayland10layershell8WlrLayerE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN2qs7wayland10layershell8WlrLayerE =
    qt_staticMetaObjectContent_ZN2qs7wayland10layershell8WlrLayerE.relocatingData;

Q_CONSTINIT const QMetaObject qs::wayland::layershell::WlrLayer::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN2qs7wayland10layershell8WlrLayerE.stringdata,
    qt_staticMetaObjectStaticContent_ZN2qs7wayland10layershell8WlrLayerE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN2qs7wayland10layershell8WlrLayerE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN2qs7wayland10layershell16WlrKeyboardFocusE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::wayland::layershell::WlrKeyboardFocus::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7wayland10layershell16WlrKeyboardFocusE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::wayland::layershell::WlrKeyboardFocus",
        "QML.Element",
        "auto",
        "Enum",
        "None",
        "Exclusive",
        "OnDemand"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Enum'
        QtMocHelpers::EnumData<Enum>(3, 3, QMC::EnumFlags{}).add({
            {    4, Enum::None },
            {    5, Enum::Exclusive },
            {    6, Enum::OnDemand },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN2qs7wayland10layershell16WlrKeyboardFocusE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN2qs7wayland10layershell16WlrKeyboardFocusE =
    qs::wayland::layershell::WlrKeyboardFocus::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7wayland10layershell16WlrKeyboardFocusE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN2qs7wayland10layershell16WlrKeyboardFocusE =
    qt_staticMetaObjectContent_ZN2qs7wayland10layershell16WlrKeyboardFocusE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN2qs7wayland10layershell16WlrKeyboardFocusE =
    qt_staticMetaObjectContent_ZN2qs7wayland10layershell16WlrKeyboardFocusE.relocatingData;

Q_CONSTINIT const QMetaObject qs::wayland::layershell::WlrKeyboardFocus::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN2qs7wayland10layershell16WlrKeyboardFocusE.stringdata,
    qt_staticMetaObjectStaticContent_ZN2qs7wayland10layershell16WlrKeyboardFocusE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN2qs7wayland10layershell16WlrKeyboardFocusE.metaTypes,
    nullptr
} };

QT_WARNING_POP
