/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.UPower.Device.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef DBUS_DEVICE_H
#define DBUS_DEVICE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.freedesktop.UPower.Device
 */
class DBusUPowerDevice: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.UPower.Device"; }

public:
    DBusUPowerDevice(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~DBusUPowerDevice();

    Q_PROPERTY(double Capacity READ capacity)
    inline double capacity() const
    { return qvariant_cast< double >(property("Capacity")); }

    Q_PROPERTY(double Energy READ energy)
    inline double energy() const
    { return qvariant_cast< double >(property("Energy")); }

    Q_PROPERTY(double EnergyFull READ energyFull)
    inline double energyFull() const
    { return qvariant_cast< double >(property("EnergyFull")); }

    Q_PROPERTY(double EnergyRate READ energyRate)
    inline double energyRate() const
    { return qvariant_cast< double >(property("EnergyRate")); }

    Q_PROPERTY(QString IconName READ iconName)
    inline QString iconName() const
    { return qvariant_cast< QString >(property("IconName")); }

    Q_PROPERTY(bool IsPresent READ isPresent)
    inline bool isPresent() const
    { return qvariant_cast< bool >(property("IsPresent")); }

    Q_PROPERTY(double Percentage READ percentage)
    inline double percentage() const
    { return qvariant_cast< double >(property("Percentage")); }

    Q_PROPERTY(bool PowerSupply READ powerSupply)
    inline bool powerSupply() const
    { return qvariant_cast< bool >(property("PowerSupply")); }

    Q_PROPERTY(uint State READ state)
    inline uint state() const
    { return qvariant_cast< uint >(property("State")); }

    Q_PROPERTY(qlonglong TimeToEmpty READ timeToEmpty)
    inline qlonglong timeToEmpty() const
    { return qvariant_cast< qlonglong >(property("TimeToEmpty")); }

    Q_PROPERTY(qlonglong TimeToFull READ timeToFull)
    inline qlonglong timeToFull() const
    { return qvariant_cast< qlonglong >(property("TimeToFull")); }

    Q_PROPERTY(uint Type READ type)
    inline uint type() const
    { return qvariant_cast< uint >(property("Type")); }

public Q_SLOTS: // METHODS
Q_SIGNALS: // SIGNALS
};

#endif
