/****************************************************************************
** Meta object code from reading C++ file 'view.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/wayland/screencopy/view.hpp"
#include <QtCore/qmetatype.h>
#include <QtCore/QProperty>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'view.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs7wayland10screencopy14ScreencopyViewE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::wayland::screencopy::ScreencopyView::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7wayland10screencopy14ScreencopyViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::wayland::screencopy::ScreencopyView",
        "QML.Element",
        "auto",
        "stopped",
        "",
        "captureSourceChanged",
        "paintCursorsChanged",
        "liveChanged",
        "hasContentChanged",
        "sourceSizeChanged",
        "constraintSizeChanged",
        "onCaptureSourceDestroyed",
        "onFrameCaptured",
        "destroyContextWithUpdate",
        "onBuffersReady",
        "captureFrame",
        "captureSource",
        "paintCursor",
        "live",
        "hasContent",
        "sourceSize",
        "QSize",
        "constraintSize",
        "QSizeF"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'stopped'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'captureSourceChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paintCursorsChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'liveChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasContentChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceSizeChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'constraintSizeChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onCaptureSourceDestroyed'
        QtMocHelpers::SlotData<void()>(11, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onFrameCaptured'
        QtMocHelpers::SlotData<void()>(12, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'destroyContextWithUpdate'
        QtMocHelpers::SlotData<void()>(13, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onBuffersReady'
        QtMocHelpers::SlotData<void()>(14, 4, QMC::AccessPrivate, QMetaType::Void),
        // Method 'captureFrame'
        QtMocHelpers::MethodData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'captureSource'
        QtMocHelpers::PropertyData<QObject*>(16, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'paintCursor'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'live'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'hasContent'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 4),
        // property 'sourceSize'
        QtMocHelpers::PropertyData<QSize>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Bindable, 5),
        // property 'constraintSize'
        QtMocHelpers::PropertyData<QSizeF>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Bindable, 6),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ScreencopyView, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject qs::wayland::screencopy::ScreencopyView::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland10screencopy14ScreencopyViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland10screencopy14ScreencopyViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7wayland10screencopy14ScreencopyViewE_t>.metaTypes,
    nullptr
} };

void qs::wayland::screencopy::ScreencopyView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScreencopyView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->stopped(); break;
        case 1: _t->captureSourceChanged(); break;
        case 2: _t->paintCursorsChanged(); break;
        case 3: _t->liveChanged(); break;
        case 4: _t->hasContentChanged(); break;
        case 5: _t->sourceSizeChanged(); break;
        case 6: _t->constraintSizeChanged(); break;
        case 7: _t->onCaptureSourceDestroyed(); break;
        case 8: _t->onFrameCaptured(); break;
        case 9: _t->destroyContextWithUpdate(); break;
        case 10: _t->onBuffersReady(); break;
        case 11: _t->captureFrame(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ScreencopyView::*)()>(_a, &ScreencopyView::stopped, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreencopyView::*)()>(_a, &ScreencopyView::captureSourceChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreencopyView::*)()>(_a, &ScreencopyView::paintCursorsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreencopyView::*)()>(_a, &ScreencopyView::liveChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreencopyView::*)()>(_a, &ScreencopyView::hasContentChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreencopyView::*)()>(_a, &ScreencopyView::sourceSizeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreencopyView::*)()>(_a, &ScreencopyView::constraintSizeChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QObject**>(_v) = _t->captureSource(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->paintCursors(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->live(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->bindableHasContent().value(); break;
        case 4: *reinterpret_cast<QSize*>(_v) = _t->bindableSourceSize().value(); break;
        case 5: *reinterpret_cast<QSizeF*>(_v) = _t->bindableConstraintSize().value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCaptureSource(*reinterpret_cast<QObject**>(_v)); break;
        case 1: _t->setPaintCursors(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setLive(*reinterpret_cast<bool*>(_v)); break;
        case 5: {
            _t->bindableConstraintSize().setValue(*reinterpret_cast<QSizeF*>(_v));
            break;
        }
        default: break;
        }
    }
    if (_c == QMetaObject::BindableProperty) {
        switch (_id) {
        case 3: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableHasContent(); break;
        case 4: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableSourceSize(); break;
        case 5: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableConstraintSize(); break;
        default: break;
        }
    }
}

const QMetaObject *qs::wayland::screencopy::ScreencopyView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::wayland::screencopy::ScreencopyView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland10screencopy14ScreencopyViewE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int qs::wayland::screencopy::ScreencopyView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void qs::wayland::screencopy::ScreencopyView::stopped()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void qs::wayland::screencopy::ScreencopyView::captureSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void qs::wayland::screencopy::ScreencopyView::paintCursorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void qs::wayland::screencopy::ScreencopyView::liveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void qs::wayland::screencopy::ScreencopyView::hasContentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void qs::wayland::screencopy::ScreencopyView::sourceSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void qs::wayland::screencopy::ScreencopyView::constraintSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
