/****************************************************************************
** Meta object code from reading C++ file 'qml.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/services/notifications/qml.hpp"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qml.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs7service13notifications21NotificationServerQmlE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::service::notifications::NotificationServerQml::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7service13notifications21NotificationServerQmlE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::service::notifications::NotificationServerQml",
        "QML.Element",
        "NotificationServer",
        "notification",
        "",
        "qs::service::notifications::Notification*",
        "keepOnReloadChanged",
        "persistenceSupportedChanged",
        "bodySupportedChanged",
        "bodyMarkupSupportedChanged",
        "bodyHyperlinksSupportedChanged",
        "bodyImagesSupportedChanged",
        "actionsSupportedChanged",
        "actionIconsSupportedChanged",
        "imageSupportedChanged",
        "inlineReplySupportedChanged",
        "extraHintsChanged",
        "trackedNotificationsChanged",
        "keepOnReload",
        "persistenceSupported",
        "bodySupported",
        "bodyMarkupSupported",
        "bodyHyperlinksSupported",
        "bodyImagesSupported",
        "actionsSupported",
        "actionIconsSupported",
        "imageSupported",
        "inlineReplySupported",
        "trackedNotifications",
        "UntypedObjectModel*",
        "extraHints"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'notification'
        QtMocHelpers::SignalData<void(qs::service::notifications::Notification *)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 3 },
        }}),
        // Signal 'keepOnReloadChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'persistenceSupportedChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bodySupportedChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bodyMarkupSupportedChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bodyHyperlinksSupportedChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bodyImagesSupportedChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'actionsSupportedChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'actionIconsSupportedChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imageSupportedChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inlineReplySupportedChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'extraHintsChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trackedNotificationsChanged'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'keepOnReload'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'persistenceSupported'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'bodySupported'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'bodyMarkupSupported'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'bodyHyperlinksSupported'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'bodyImagesSupported'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'actionsSupported'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'actionIconsSupported'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'imageSupported'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'inlineReplySupported'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'trackedNotifications'
        QtMocHelpers::PropertyData<UntypedObjectModel*>(28, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 12),
        // property 'extraHints'
        QtMocHelpers::PropertyData<QList<QString>>(30, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<NotificationServerQml, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject qs::service::notifications::NotificationServerQml::staticMetaObject = { {
    QMetaObject::SuperData::link<PostReloadHook::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service13notifications21NotificationServerQmlE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service13notifications21NotificationServerQmlE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7service13notifications21NotificationServerQmlE_t>.metaTypes,
    nullptr
} };

void qs::service::notifications::NotificationServerQml::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NotificationServerQml *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->notification((*reinterpret_cast<std::add_pointer_t<qs::service::notifications::Notification*>>(_a[1]))); break;
        case 1: _t->keepOnReloadChanged(); break;
        case 2: _t->persistenceSupportedChanged(); break;
        case 3: _t->bodySupportedChanged(); break;
        case 4: _t->bodyMarkupSupportedChanged(); break;
        case 5: _t->bodyHyperlinksSupportedChanged(); break;
        case 6: _t->bodyImagesSupportedChanged(); break;
        case 7: _t->actionsSupportedChanged(); break;
        case 8: _t->actionIconsSupportedChanged(); break;
        case 9: _t->imageSupportedChanged(); break;
        case 10: _t->inlineReplySupportedChanged(); break;
        case 11: _t->extraHintsChanged(); break;
        case 12: _t->trackedNotificationsChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< qs::service::notifications::Notification* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NotificationServerQml::*)(qs::service::notifications::Notification * )>(_a, &NotificationServerQml::notification, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationServerQml::*)()>(_a, &NotificationServerQml::keepOnReloadChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationServerQml::*)()>(_a, &NotificationServerQml::persistenceSupportedChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationServerQml::*)()>(_a, &NotificationServerQml::bodySupportedChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationServerQml::*)()>(_a, &NotificationServerQml::bodyMarkupSupportedChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationServerQml::*)()>(_a, &NotificationServerQml::bodyHyperlinksSupportedChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationServerQml::*)()>(_a, &NotificationServerQml::bodyImagesSupportedChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationServerQml::*)()>(_a, &NotificationServerQml::actionsSupportedChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationServerQml::*)()>(_a, &NotificationServerQml::actionIconsSupportedChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationServerQml::*)()>(_a, &NotificationServerQml::imageSupportedChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationServerQml::*)()>(_a, &NotificationServerQml::inlineReplySupportedChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationServerQml::*)()>(_a, &NotificationServerQml::extraHintsChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationServerQml::*)()>(_a, &NotificationServerQml::trackedNotificationsChanged, 12))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 10:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< UntypedObjectModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->keepOnReload(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->persistenceSupported(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->bodySupported(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->bodyMarkupSupported(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->bodyHyperlinksSupported(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->bodyImagesSupported(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->actionsSupported(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->actionIconsSupported(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->imageSupported(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->inlineReplySupported(); break;
        case 10: *reinterpret_cast<UntypedObjectModel**>(_v) = _t->trackedNotifications(); break;
        case 11: *reinterpret_cast<QList<QString>*>(_v) = _t->extraHints(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setKeepOnReload(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setPersistenceSupported(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setBodySupported(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setBodyMarkupSupported(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setBodyHyperlinksSupported(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setBodyImagesSupported(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setActionsSupported(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setActionIconsSupported(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setImageSupported(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setInlineReplySupported(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setExtraHints(*reinterpret_cast<QList<QString>*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *qs::service::notifications::NotificationServerQml::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::service::notifications::NotificationServerQml::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service13notifications21NotificationServerQmlE_t>.strings))
        return static_cast<void*>(this);
    return PostReloadHook::qt_metacast(_clname);
}

int qs::service::notifications::NotificationServerQml::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PostReloadHook::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void qs::service::notifications::NotificationServerQml::notification(qs::service::notifications::Notification * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void qs::service::notifications::NotificationServerQml::keepOnReloadChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void qs::service::notifications::NotificationServerQml::persistenceSupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void qs::service::notifications::NotificationServerQml::bodySupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void qs::service::notifications::NotificationServerQml::bodyMarkupSupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void qs::service::notifications::NotificationServerQml::bodyHyperlinksSupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void qs::service::notifications::NotificationServerQml::bodyImagesSupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void qs::service::notifications::NotificationServerQml::actionsSupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void qs::service::notifications::NotificationServerQml::actionIconsSupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void qs::service::notifications::NotificationServerQml::imageSupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void qs::service::notifications::NotificationServerQml::inlineReplySupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void qs::service::notifications::NotificationServerQml::extraHintsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void qs::service::notifications::NotificationServerQml::trackedNotificationsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}
QT_WARNING_POP
