/****************************************************************************
** Meta object code from reading C++ file 'workspace.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../src/wayland/hyprland/ipc/workspace.hpp"
#include <QtCore/qmetatype.h>
#include <QtCore/QProperty>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'workspace.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs8hyprland3ipc17HyprlandWorkspaceE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::hyprland::ipc::HyprlandWorkspace::qt_create_metaobjectdata<qt_meta_tag_ZN2qs8hyprland3ipc17HyprlandWorkspaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::hyprland::ipc::HyprlandWorkspace",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "HyprlandWorkspaces must be retrieved from the HyprlandIpc object.",
        "idChanged",
        "",
        "nameChanged",
        "activeChanged",
        "focusedChanged",
        "urgentChanged",
        "hasFullscreenChanged",
        "lastIpcObjectChanged",
        "monitorChanged",
        "onMonitorDestroyed",
        "updateUrgent",
        "activate",
        "id",
        "name",
        "active",
        "focused",
        "urgent",
        "hasFullscreen",
        "lastIpcObject",
        "QVariantMap",
        "monitor",
        "qs::hyprland::ipc::HyprlandMonitor*",
        "toplevels",
        "UntypedObjectModel*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'idChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeChanged'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusedChanged'
        QtMocHelpers::SignalData<void()>(11, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'urgentChanged'
        QtMocHelpers::SignalData<void()>(12, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasFullscreenChanged'
        QtMocHelpers::SignalData<void()>(13, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastIpcObjectChanged'
        QtMocHelpers::SignalData<void()>(14, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'monitorChanged'
        QtMocHelpers::SignalData<void()>(15, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onMonitorDestroyed'
        QtMocHelpers::SlotData<void()>(16, 8, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateUrgent'
        QtMocHelpers::SlotData<void()>(17, 8, QMC::AccessPrivate, QMetaType::Void),
        // Method 'activate'
        QtMocHelpers::MethodData<void()>(18, 8, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'id'
        QtMocHelpers::PropertyData<qint32>(19, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Bindable, 0),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Bindable, 1),
        // property 'active'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 2),
        // property 'focused'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 3),
        // property 'urgent'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 4),
        // property 'hasFullscreen'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 5),
        // property 'lastIpcObject'
        QtMocHelpers::PropertyData<QVariantMap>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 6),
        // property 'monitor'
        QtMocHelpers::PropertyData<qs::hyprland::ipc::HyprlandMonitor*>(27, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Bindable, 7),
        // property 'toplevels'
        QtMocHelpers::PropertyData<UntypedObjectModel*>(29, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<HyprlandWorkspace, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject qs::hyprland::ipc::HyprlandWorkspace::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs8hyprland3ipc17HyprlandWorkspaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs8hyprland3ipc17HyprlandWorkspaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs8hyprland3ipc17HyprlandWorkspaceE_t>.metaTypes,
    nullptr
} };

void qs::hyprland::ipc::HyprlandWorkspace::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HyprlandWorkspace *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->idChanged(); break;
        case 1: _t->nameChanged(); break;
        case 2: _t->activeChanged(); break;
        case 3: _t->focusedChanged(); break;
        case 4: _t->urgentChanged(); break;
        case 5: _t->hasFullscreenChanged(); break;
        case 6: _t->lastIpcObjectChanged(); break;
        case 7: _t->monitorChanged(); break;
        case 8: _t->onMonitorDestroyed(); break;
        case 9: _t->updateUrgent(); break;
        case 10: _t->activate(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (HyprlandWorkspace::*)()>(_a, &HyprlandWorkspace::idChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (HyprlandWorkspace::*)()>(_a, &HyprlandWorkspace::nameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (HyprlandWorkspace::*)()>(_a, &HyprlandWorkspace::activeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (HyprlandWorkspace::*)()>(_a, &HyprlandWorkspace::focusedChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (HyprlandWorkspace::*)()>(_a, &HyprlandWorkspace::urgentChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (HyprlandWorkspace::*)()>(_a, &HyprlandWorkspace::hasFullscreenChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (HyprlandWorkspace::*)()>(_a, &HyprlandWorkspace::lastIpcObjectChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (HyprlandWorkspace::*)()>(_a, &HyprlandWorkspace::monitorChanged, 7))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 8:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< UntypedObjectModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qint32*>(_v) = _t->bindableId().value(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->bindableName().value(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->bindableActive().value(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->bindableFocused().value(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->bindableUrgent().value(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->bindableHasFullscreen().value(); break;
        case 6: *reinterpret_cast<QVariantMap*>(_v) = _t->lastIpcObject(); break;
        case 7: *reinterpret_cast<qs::hyprland::ipc::HyprlandMonitor**>(_v) = _t->bindableMonitor().value(); break;
        case 8: *reinterpret_cast<UntypedObjectModel**>(_v) = _t->toplevels(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::BindableProperty) {
        switch (_id) {
        case 0: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableId(); break;
        case 1: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableName(); break;
        case 2: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableActive(); break;
        case 3: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableFocused(); break;
        case 4: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableUrgent(); break;
        case 5: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableHasFullscreen(); break;
        case 7: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableMonitor(); break;
        default: break;
        }
    }
}

const QMetaObject *qs::hyprland::ipc::HyprlandWorkspace::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::hyprland::ipc::HyprlandWorkspace::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs8hyprland3ipc17HyprlandWorkspaceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::hyprland::ipc::HyprlandWorkspace::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void qs::hyprland::ipc::HyprlandWorkspace::idChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void qs::hyprland::ipc::HyprlandWorkspace::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void qs::hyprland::ipc::HyprlandWorkspace::activeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void qs::hyprland::ipc::HyprlandWorkspace::focusedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void qs::hyprland::ipc::HyprlandWorkspace::urgentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void qs::hyprland::ipc::HyprlandWorkspace::hasFullscreenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void qs::hyprland::ipc::HyprlandWorkspace::lastIpcObjectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void qs::hyprland::ipc::HyprlandWorkspace::monitorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
