// This file was generated by qtwaylandscanner
// source file is ext-workspace-v1.xml

#include "qwayland-ext-workspace-v1.h"

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {

static inline void *wlRegistryBind(struct ::wl_registry *registry, uint32_t name, const struct ::wl_interface *interface, uint32_t version)
{
    const uint32_t bindOpCode = 0;
    return (void *) wl_proxy_marshal_constructor_versioned((struct wl_proxy *) registry,
    bindOpCode, interface, version, name, interface->name, version, nullptr);
}

    ext_workspace_manager_v1::ext_workspace_manager_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    ext_workspace_manager_v1::ext_workspace_manager_v1(struct ::ext_workspace_manager_v1 *obj)
        : m_ext_workspace_manager_v1(obj)
    {
        init_listener();
    }

    ext_workspace_manager_v1::ext_workspace_manager_v1()
        : m_ext_workspace_manager_v1(nullptr)
    {
    }

    ext_workspace_manager_v1::~ext_workspace_manager_v1()
    {
    }

    void ext_workspace_manager_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_ext_workspace_manager_v1 = static_cast<struct ::ext_workspace_manager_v1 *>(wlRegistryBind(registry, id, &ext_workspace_manager_v1_interface, version));
        init_listener();
    }

    void ext_workspace_manager_v1::init(struct ::ext_workspace_manager_v1 *obj)
    {
        m_ext_workspace_manager_v1 = obj;
        init_listener();
    }

    ext_workspace_manager_v1 *ext_workspace_manager_v1::fromObject(struct ::ext_workspace_manager_v1 *object)
    {
        if (wl_proxy_get_listener((struct ::wl_proxy *)object) != (void *)&m_ext_workspace_manager_v1_listener)
            return nullptr;
        return static_cast<ext_workspace_manager_v1 *>(ext_workspace_manager_v1_get_user_data(object));
    }

    bool ext_workspace_manager_v1::isInitialized() const
    {
        return m_ext_workspace_manager_v1 != nullptr;
    }

    uint32_t ext_workspace_manager_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_ext_workspace_manager_v1));
    }

    const struct wl_interface *ext_workspace_manager_v1::interface()
    {
        return &::ext_workspace_manager_v1_interface;
    }

    void ext_workspace_manager_v1::commit()
    {
        ::ext_workspace_manager_v1_commit(
            m_ext_workspace_manager_v1);
    }

    void ext_workspace_manager_v1::stop()
    {
        ::ext_workspace_manager_v1_stop(
            m_ext_workspace_manager_v1);
    }

    void ext_workspace_manager_v1::ext_workspace_manager_v1_workspace_group(struct ::ext_workspace_group_handle_v1 *)
    {
    }

    void ext_workspace_manager_v1::handle_workspace_group(
        void *data,
        struct ::ext_workspace_manager_v1 *object,
        struct ::ext_workspace_group_handle_v1 *workspace_group)
    {
        Q_UNUSED(object);
        static_cast<ext_workspace_manager_v1 *>(data)->ext_workspace_manager_v1_workspace_group(
            workspace_group);
    }

    void ext_workspace_manager_v1::ext_workspace_manager_v1_workspace(struct ::ext_workspace_handle_v1 *)
    {
    }

    void ext_workspace_manager_v1::handle_workspace(
        void *data,
        struct ::ext_workspace_manager_v1 *object,
        struct ::ext_workspace_handle_v1 *workspace)
    {
        Q_UNUSED(object);
        static_cast<ext_workspace_manager_v1 *>(data)->ext_workspace_manager_v1_workspace(
            workspace);
    }

    void ext_workspace_manager_v1::ext_workspace_manager_v1_done()
    {
    }

    void ext_workspace_manager_v1::handle_done(
        void *data,
        struct ::ext_workspace_manager_v1 *object)
    {
        Q_UNUSED(object);
        static_cast<ext_workspace_manager_v1 *>(data)->ext_workspace_manager_v1_done();
    }

    void ext_workspace_manager_v1::ext_workspace_manager_v1_finished()
    {
    }

    void ext_workspace_manager_v1::handle_finished(
        void *data,
        struct ::ext_workspace_manager_v1 *object)
    {
        Q_UNUSED(object);
        static_cast<ext_workspace_manager_v1 *>(data)->ext_workspace_manager_v1_finished();
    }

    const struct ext_workspace_manager_v1_listener ext_workspace_manager_v1::m_ext_workspace_manager_v1_listener = {
        ext_workspace_manager_v1::handle_workspace_group,
        ext_workspace_manager_v1::handle_workspace,
        ext_workspace_manager_v1::handle_done,
        ext_workspace_manager_v1::handle_finished,
    };

    void ext_workspace_manager_v1::init_listener()
    {
        ext_workspace_manager_v1_add_listener(m_ext_workspace_manager_v1, &m_ext_workspace_manager_v1_listener, this);
    }

    ext_workspace_group_handle_v1::ext_workspace_group_handle_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    ext_workspace_group_handle_v1::ext_workspace_group_handle_v1(struct ::ext_workspace_group_handle_v1 *obj)
        : m_ext_workspace_group_handle_v1(obj)
    {
        init_listener();
    }

    ext_workspace_group_handle_v1::ext_workspace_group_handle_v1()
        : m_ext_workspace_group_handle_v1(nullptr)
    {
    }

    ext_workspace_group_handle_v1::~ext_workspace_group_handle_v1()
    {
    }

    void ext_workspace_group_handle_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_ext_workspace_group_handle_v1 = static_cast<struct ::ext_workspace_group_handle_v1 *>(wlRegistryBind(registry, id, &ext_workspace_group_handle_v1_interface, version));
        init_listener();
    }

    void ext_workspace_group_handle_v1::init(struct ::ext_workspace_group_handle_v1 *obj)
    {
        m_ext_workspace_group_handle_v1 = obj;
        init_listener();
    }

    ext_workspace_group_handle_v1 *ext_workspace_group_handle_v1::fromObject(struct ::ext_workspace_group_handle_v1 *object)
    {
        if (wl_proxy_get_listener((struct ::wl_proxy *)object) != (void *)&m_ext_workspace_group_handle_v1_listener)
            return nullptr;
        return static_cast<ext_workspace_group_handle_v1 *>(ext_workspace_group_handle_v1_get_user_data(object));
    }

    bool ext_workspace_group_handle_v1::isInitialized() const
    {
        return m_ext_workspace_group_handle_v1 != nullptr;
    }

    uint32_t ext_workspace_group_handle_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_ext_workspace_group_handle_v1));
    }

    const struct wl_interface *ext_workspace_group_handle_v1::interface()
    {
        return &::ext_workspace_group_handle_v1_interface;
    }

    void ext_workspace_group_handle_v1::create_workspace(const QString &workspace)
    {
        ::ext_workspace_group_handle_v1_create_workspace(
            m_ext_workspace_group_handle_v1,
            workspace.toUtf8().constData());
    }

    void ext_workspace_group_handle_v1::destroy()
    {
        ::ext_workspace_group_handle_v1_destroy(
            m_ext_workspace_group_handle_v1);
        m_ext_workspace_group_handle_v1 = nullptr;
    }

    void ext_workspace_group_handle_v1::ext_workspace_group_handle_v1_capabilities(uint32_t )
    {
    }

    void ext_workspace_group_handle_v1::handle_capabilities(
        void *data,
        struct ::ext_workspace_group_handle_v1 *object,
        uint32_t capabilities)
    {
        Q_UNUSED(object);
        static_cast<ext_workspace_group_handle_v1 *>(data)->ext_workspace_group_handle_v1_capabilities(
            capabilities);
    }

    void ext_workspace_group_handle_v1::ext_workspace_group_handle_v1_output_enter(struct ::wl_output *)
    {
    }

    void ext_workspace_group_handle_v1::handle_output_enter(
        void *data,
        struct ::ext_workspace_group_handle_v1 *object,
        struct ::wl_output *output)
    {
        Q_UNUSED(object);
        static_cast<ext_workspace_group_handle_v1 *>(data)->ext_workspace_group_handle_v1_output_enter(
            output);
    }

    void ext_workspace_group_handle_v1::ext_workspace_group_handle_v1_output_leave(struct ::wl_output *)
    {
    }

    void ext_workspace_group_handle_v1::handle_output_leave(
        void *data,
        struct ::ext_workspace_group_handle_v1 *object,
        struct ::wl_output *output)
    {
        Q_UNUSED(object);
        static_cast<ext_workspace_group_handle_v1 *>(data)->ext_workspace_group_handle_v1_output_leave(
            output);
    }

    void ext_workspace_group_handle_v1::ext_workspace_group_handle_v1_workspace_enter(struct ::ext_workspace_handle_v1 *)
    {
    }

    void ext_workspace_group_handle_v1::handle_workspace_enter(
        void *data,
        struct ::ext_workspace_group_handle_v1 *object,
        struct ::ext_workspace_handle_v1 *workspace)
    {
        Q_UNUSED(object);
        static_cast<ext_workspace_group_handle_v1 *>(data)->ext_workspace_group_handle_v1_workspace_enter(
            workspace);
    }

    void ext_workspace_group_handle_v1::ext_workspace_group_handle_v1_workspace_leave(struct ::ext_workspace_handle_v1 *)
    {
    }

    void ext_workspace_group_handle_v1::handle_workspace_leave(
        void *data,
        struct ::ext_workspace_group_handle_v1 *object,
        struct ::ext_workspace_handle_v1 *workspace)
    {
        Q_UNUSED(object);
        static_cast<ext_workspace_group_handle_v1 *>(data)->ext_workspace_group_handle_v1_workspace_leave(
            workspace);
    }

    void ext_workspace_group_handle_v1::ext_workspace_group_handle_v1_removed()
    {
    }

    void ext_workspace_group_handle_v1::handle_removed(
        void *data,
        struct ::ext_workspace_group_handle_v1 *object)
    {
        Q_UNUSED(object);
        static_cast<ext_workspace_group_handle_v1 *>(data)->ext_workspace_group_handle_v1_removed();
    }

    const struct ext_workspace_group_handle_v1_listener ext_workspace_group_handle_v1::m_ext_workspace_group_handle_v1_listener = {
        ext_workspace_group_handle_v1::handle_capabilities,
        ext_workspace_group_handle_v1::handle_output_enter,
        ext_workspace_group_handle_v1::handle_output_leave,
        ext_workspace_group_handle_v1::handle_workspace_enter,
        ext_workspace_group_handle_v1::handle_workspace_leave,
        ext_workspace_group_handle_v1::handle_removed,
    };

    void ext_workspace_group_handle_v1::init_listener()
    {
        ext_workspace_group_handle_v1_add_listener(m_ext_workspace_group_handle_v1, &m_ext_workspace_group_handle_v1_listener, this);
    }

    ext_workspace_handle_v1::ext_workspace_handle_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    ext_workspace_handle_v1::ext_workspace_handle_v1(struct ::ext_workspace_handle_v1 *obj)
        : m_ext_workspace_handle_v1(obj)
    {
        init_listener();
    }

    ext_workspace_handle_v1::ext_workspace_handle_v1()
        : m_ext_workspace_handle_v1(nullptr)
    {
    }

    ext_workspace_handle_v1::~ext_workspace_handle_v1()
    {
    }

    void ext_workspace_handle_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_ext_workspace_handle_v1 = static_cast<struct ::ext_workspace_handle_v1 *>(wlRegistryBind(registry, id, &ext_workspace_handle_v1_interface, version));
        init_listener();
    }

    void ext_workspace_handle_v1::init(struct ::ext_workspace_handle_v1 *obj)
    {
        m_ext_workspace_handle_v1 = obj;
        init_listener();
    }

    ext_workspace_handle_v1 *ext_workspace_handle_v1::fromObject(struct ::ext_workspace_handle_v1 *object)
    {
        if (wl_proxy_get_listener((struct ::wl_proxy *)object) != (void *)&m_ext_workspace_handle_v1_listener)
            return nullptr;
        return static_cast<ext_workspace_handle_v1 *>(ext_workspace_handle_v1_get_user_data(object));
    }

    bool ext_workspace_handle_v1::isInitialized() const
    {
        return m_ext_workspace_handle_v1 != nullptr;
    }

    uint32_t ext_workspace_handle_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_ext_workspace_handle_v1));
    }

    const struct wl_interface *ext_workspace_handle_v1::interface()
    {
        return &::ext_workspace_handle_v1_interface;
    }

    void ext_workspace_handle_v1::destroy()
    {
        ::ext_workspace_handle_v1_destroy(
            m_ext_workspace_handle_v1);
        m_ext_workspace_handle_v1 = nullptr;
    }

    void ext_workspace_handle_v1::activate()
    {
        ::ext_workspace_handle_v1_activate(
            m_ext_workspace_handle_v1);
    }

    void ext_workspace_handle_v1::deactivate()
    {
        ::ext_workspace_handle_v1_deactivate(
            m_ext_workspace_handle_v1);
    }

    void ext_workspace_handle_v1::assign(struct ::ext_workspace_group_handle_v1 *workspace_group)
    {
        ::ext_workspace_handle_v1_assign(
            m_ext_workspace_handle_v1,
            workspace_group);
    }

    void ext_workspace_handle_v1::remove()
    {
        ::ext_workspace_handle_v1_remove(
            m_ext_workspace_handle_v1);
    }

    void ext_workspace_handle_v1::ext_workspace_handle_v1_id(const QString &)
    {
    }

    void ext_workspace_handle_v1::handle_id(
        void *data,
        struct ::ext_workspace_handle_v1 *object,
        const char *id)
    {
        Q_UNUSED(object);
        static_cast<ext_workspace_handle_v1 *>(data)->ext_workspace_handle_v1_id(
            QString::fromUtf8(id));
    }

    void ext_workspace_handle_v1::ext_workspace_handle_v1_name(const QString &)
    {
    }

    void ext_workspace_handle_v1::handle_name(
        void *data,
        struct ::ext_workspace_handle_v1 *object,
        const char *name)
    {
        Q_UNUSED(object);
        static_cast<ext_workspace_handle_v1 *>(data)->ext_workspace_handle_v1_name(
            QString::fromUtf8(name));
    }

    void ext_workspace_handle_v1::ext_workspace_handle_v1_coordinates(wl_array *)
    {
    }

    void ext_workspace_handle_v1::handle_coordinates(
        void *data,
        struct ::ext_workspace_handle_v1 *object,
        wl_array *coordinates)
    {
        Q_UNUSED(object);
        static_cast<ext_workspace_handle_v1 *>(data)->ext_workspace_handle_v1_coordinates(
            coordinates);
    }

    void ext_workspace_handle_v1::ext_workspace_handle_v1_state(uint32_t )
    {
    }

    void ext_workspace_handle_v1::handle_state(
        void *data,
        struct ::ext_workspace_handle_v1 *object,
        uint32_t state)
    {
        Q_UNUSED(object);
        static_cast<ext_workspace_handle_v1 *>(data)->ext_workspace_handle_v1_state(
            state);
    }

    void ext_workspace_handle_v1::ext_workspace_handle_v1_capabilities(uint32_t )
    {
    }

    void ext_workspace_handle_v1::handle_capabilities(
        void *data,
        struct ::ext_workspace_handle_v1 *object,
        uint32_t capabilities)
    {
        Q_UNUSED(object);
        static_cast<ext_workspace_handle_v1 *>(data)->ext_workspace_handle_v1_capabilities(
            capabilities);
    }

    void ext_workspace_handle_v1::ext_workspace_handle_v1_removed()
    {
    }

    void ext_workspace_handle_v1::handle_removed(
        void *data,
        struct ::ext_workspace_handle_v1 *object)
    {
        Q_UNUSED(object);
        static_cast<ext_workspace_handle_v1 *>(data)->ext_workspace_handle_v1_removed();
    }

    const struct ext_workspace_handle_v1_listener ext_workspace_handle_v1::m_ext_workspace_handle_v1_listener = {
        ext_workspace_handle_v1::handle_id,
        ext_workspace_handle_v1::handle_name,
        ext_workspace_handle_v1::handle_coordinates,
        ext_workspace_handle_v1::handle_state,
        ext_workspace_handle_v1::handle_capabilities,
        ext_workspace_handle_v1::handle_removed,
    };

    void ext_workspace_handle_v1::init_listener()
    {
        ext_workspace_handle_v1_add_listener(m_ext_workspace_handle_v1, &m_ext_workspace_handle_v1_listener, this);
    }
}

QT_WARNING_POP
QT_END_NAMESPACE
