/****************************************************************************
** Meta object code from reading C++ file 'powerprofiles.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/services/upower/powerprofiles.hpp"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#include <QtCore/QProperty>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'powerprofiles.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs7service6upower12PowerProfileE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::service::upower::PowerProfile::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7service6upower12PowerProfileE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::service::upower::PowerProfile",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "toString",
        "",
        "qs::service::upower::PowerProfile::Enum",
        "profile",
        "Enum",
        "PowerSaver",
        "Balanced",
        "Performance"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'toString'
        QtMocHelpers::MethodData<QString(qs::service::upower::PowerProfile::Enum)>(5, 6, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 7, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Enum'
        QtMocHelpers::EnumData<enum Enum>(9, 9, QMC::EnumFlags{}).add({
            {   10, Enum::PowerSaver },
            {   11, Enum::Balanced },
            {   12, Enum::Performance },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<PowerProfile, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject qs::service::upower::PowerProfile::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service6upower12PowerProfileE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service6upower12PowerProfileE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7service6upower12PowerProfileE_t>.metaTypes,
    nullptr
} };

void qs::service::upower::PowerProfile::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PowerProfile *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->toString((*reinterpret_cast<std::add_pointer_t<qs::service::upower::PowerProfile::Enum>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *qs::service::upower::PowerProfile::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::service::upower::PowerProfile::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service6upower12PowerProfileE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::service::upower::PowerProfile::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN2qs7service6upower28PerformanceDegradationReasonE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::service::upower::PerformanceDegradationReason::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7service6upower28PerformanceDegradationReasonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::service::upower::PerformanceDegradationReason",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "toString",
        "",
        "qs::service::upower::PerformanceDegradationReason::Enum",
        "reason",
        "Enum",
        "None",
        "LapDetected",
        "HighTemperature"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'toString'
        QtMocHelpers::MethodData<QString(qs::service::upower::PerformanceDegradationReason::Enum)>(5, 6, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 7, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Enum'
        QtMocHelpers::EnumData<enum Enum>(9, 9, QMC::EnumFlags{}).add({
            {   10, Enum::None },
            {   11, Enum::LapDetected },
            {   12, Enum::HighTemperature },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<PerformanceDegradationReason, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject qs::service::upower::PerformanceDegradationReason::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service6upower28PerformanceDegradationReasonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service6upower28PerformanceDegradationReasonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7service6upower28PerformanceDegradationReasonE_t>.metaTypes,
    nullptr
} };

void qs::service::upower::PerformanceDegradationReason::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PerformanceDegradationReason *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->toString((*reinterpret_cast<std::add_pointer_t<qs::service::upower::PerformanceDegradationReason::Enum>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *qs::service::upower::PerformanceDegradationReason::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::service::upower::PerformanceDegradationReason::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service6upower28PerformanceDegradationReasonE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::service::upower::PerformanceDegradationReason::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN2qs7service6upower16PowerProfileHoldE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::service::upower::PowerProfileHold::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7service6upower16PowerProfileHoldE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::service::upower::PowerProfileHold",
        "QML.Element",
        "powerProfileHold",
        "profile",
        "qs::service::upower::PowerProfile::Enum",
        "applicationId",
        "reason"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'profile'
        QtMocHelpers::PropertyData<qs::service::upower::PowerProfile::Enum>(3, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'applicationId'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'reason'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<PowerProfileHold, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN2qs7service6upower16PowerProfileHoldE[] = {
    QMetaObject::SuperData::link<qs::service::upower::PowerProfile::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject qs::service::upower::PowerProfileHold::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service6upower16PowerProfileHoldE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service6upower16PowerProfileHoldE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN2qs7service6upower16PowerProfileHoldE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7service6upower16PowerProfileHoldE_t>.metaTypes,
    nullptr
} };

void qs::service::upower::PowerProfileHold::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<PowerProfileHold *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qs::service::upower::PowerProfile::Enum*>(_v) = _t->profile; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->applicationId; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->reason; break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN2qs7service6upower13PowerProfilesE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::service::upower::PowerProfiles::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7service6upower13PowerProfilesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::service::upower::PowerProfiles"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PowerProfiles, qt_meta_tag_ZN2qs7service6upower13PowerProfilesE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qs::service::upower::PowerProfiles::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service6upower13PowerProfilesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service6upower13PowerProfilesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7service6upower13PowerProfilesE_t>.metaTypes,
    nullptr
} };

void qs::service::upower::PowerProfiles::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PowerProfiles *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *qs::service::upower::PowerProfiles::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::service::upower::PowerProfiles::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service6upower13PowerProfilesE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::service::upower::PowerProfiles::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN2qs7service6upower16PowerProfilesQmlE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::service::upower::PowerProfilesQml::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7service6upower16PowerProfilesQmlE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::service::upower::PowerProfilesQml",
        "QML.Element",
        "PowerProfiles",
        "QML.Singleton",
        "true",
        "profileChanged",
        "",
        "hasPerformanceProfileChanged",
        "degradationReasonChanged",
        "holdsChanged",
        "profile",
        "qs::service::upower::PowerProfile::Enum",
        "hasPerformanceProfile",
        "degradationReason",
        "qs::service::upower::PerformanceDegradationReason::Enum",
        "holds",
        "QList<qs::service::upower::PowerProfileHold>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'profileChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasPerformanceProfileChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'degradationReasonChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'holdsChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'profile'
        QtMocHelpers::PropertyData<qs::service::upower::PowerProfile::Enum>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Bindable, 0),
        // property 'hasPerformanceProfile'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 1),
        // property 'degradationReason'
        QtMocHelpers::PropertyData<qs::service::upower::PerformanceDegradationReason::Enum>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Bindable, 2),
        // property 'holds'
        QtMocHelpers::PropertyData<QList<qs::service::upower::PowerProfileHold>>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Bindable, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<PowerProfilesQml, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN2qs7service6upower16PowerProfilesQmlE[] = {
    QMetaObject::SuperData::link<qs::service::upower::PowerProfile::staticMetaObject>(),
    QMetaObject::SuperData::link<qs::service::upower::PerformanceDegradationReason::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject qs::service::upower::PowerProfilesQml::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service6upower16PowerProfilesQmlE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service6upower16PowerProfilesQmlE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN2qs7service6upower16PowerProfilesQmlE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7service6upower16PowerProfilesQmlE_t>.metaTypes,
    nullptr
} };

void qs::service::upower::PowerProfilesQml::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PowerProfilesQml *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->profileChanged(); break;
        case 1: _t->hasPerformanceProfileChanged(); break;
        case 2: _t->degradationReasonChanged(); break;
        case 3: _t->holdsChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PowerProfilesQml::*)()>(_a, &PowerProfilesQml::profileChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerProfilesQml::*)()>(_a, &PowerProfilesQml::hasPerformanceProfileChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerProfilesQml::*)()>(_a, &PowerProfilesQml::degradationReasonChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerProfilesQml::*)()>(_a, &PowerProfilesQml::holdsChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qs::service::upower::PowerProfile::Enum*>(_v) = _t->bindableProfile().value(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->bindableHasPerformanceProfile().value(); break;
        case 2: *reinterpret_cast<qs::service::upower::PerformanceDegradationReason::Enum*>(_v) = _t->bindableDegradationReason().value(); break;
        case 3: *reinterpret_cast<QList<qs::service::upower::PowerProfileHold>*>(_v) = _t->bindableHolds().value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setProfile(*reinterpret_cast<qs::service::upower::PowerProfile::Enum*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::BindableProperty) {
        switch (_id) {
        case 0: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableProfile(); break;
        case 1: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableHasPerformanceProfile(); break;
        case 2: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableDegradationReason(); break;
        case 3: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableHolds(); break;
        default: break;
        }
    }
}

const QMetaObject *qs::service::upower::PowerProfilesQml::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::service::upower::PowerProfilesQml::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service6upower16PowerProfilesQmlE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::service::upower::PowerProfilesQml::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void qs::service::upower::PowerProfilesQml::profileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void qs::service::upower::PowerProfilesQml::hasPerformanceProfileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void qs::service::upower::PowerProfilesQml::degradationReasonChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void qs::service::upower::PowerProfilesQml::holdsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
