/****************************************************************************
** Meta object code from reading C++ file 'network.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../src/network/network.hpp"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#include <QtCore/QProperty>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'network.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs7network7NetworkE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::network::Network::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7network7NetworkE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::network::Network",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Network can only be aqcuired through networking devices",
        "connectionFailed",
        "",
        "ConnectionFailReason::Enum",
        "reason",
        "nameChanged",
        "connectedChanged",
        "knownChanged",
        "stateChanged",
        "stateChangingChanged",
        "nmSettingsChanged",
        "requestConnect",
        "requestConnectWithSettings",
        "NMSettings*",
        "settings",
        "requestDisconnect",
        "requestForget",
        "connect",
        "connectWithSettings",
        "disconnect",
        "forget",
        "name",
        "device",
        "NetworkDevice*",
        "nmSettings",
        "QList<NMSettings*>",
        "connected",
        "known",
        "state",
        "ConnectionState::Enum",
        "stateChanging"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'connectionFailed'
        QtMocHelpers::SignalData<void(ConnectionFailReason::Enum)>(7, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(11, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'connectedChanged'
        QtMocHelpers::SignalData<void()>(12, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'knownChanged'
        QtMocHelpers::SignalData<void()>(13, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void()>(14, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stateChangingChanged'
        QtMocHelpers::SignalData<void()>(15, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nmSettingsChanged'
        QtMocHelpers::SignalData<void()>(16, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestConnect'
        QtMocHelpers::SignalData<void()>(17, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestConnectWithSettings'
        QtMocHelpers::SignalData<void(NMSettings *)>(18, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'requestDisconnect'
        QtMocHelpers::SignalData<void()>(21, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestForget'
        QtMocHelpers::SignalData<void()>(22, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'connect'
        QtMocHelpers::MethodData<void()>(23, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'connectWithSettings'
        QtMocHelpers::MethodData<void(NMSettings *)>(24, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Method 'disconnect'
        QtMocHelpers::MethodData<void()>(25, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'forget'
        QtMocHelpers::MethodData<void()>(26, 8, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Bindable, 1),
        // property 'device'
        QtMocHelpers::PropertyData<NetworkDevice*>(28, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'nmSettings'
        QtMocHelpers::PropertyData<QList<NMSettings*>>(30, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Bindable, 6),
        // property 'connected'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 2),
        // property 'known'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 3),
        // property 'state'
        QtMocHelpers::PropertyData<ConnectionState::Enum>(34, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Bindable, 4),
        // property 'stateChanging'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<Network, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN2qs7network7NetworkE[] = {
    QMetaObject::SuperData::link<qs::network::ConnectionState::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject qs::network::Network::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network7NetworkE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network7NetworkE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN2qs7network7NetworkE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7network7NetworkE_t>.metaTypes,
    nullptr
} };

void qs::network::Network::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Network *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->connectionFailed((*reinterpret_cast<std::add_pointer_t<ConnectionFailReason::Enum>>(_a[1]))); break;
        case 1: _t->nameChanged(); break;
        case 2: _t->connectedChanged(); break;
        case 3: _t->knownChanged(); break;
        case 4: _t->stateChanged(); break;
        case 5: _t->stateChangingChanged(); break;
        case 6: _t->nmSettingsChanged(); break;
        case 7: _t->requestConnect(); break;
        case 8: _t->requestConnectWithSettings((*reinterpret_cast<std::add_pointer_t<NMSettings*>>(_a[1]))); break;
        case 9: _t->requestDisconnect(); break;
        case 10: _t->requestForget(); break;
        case 11: _t->connect(); break;
        case 12: _t->connectWithSettings((*reinterpret_cast<std::add_pointer_t<NMSettings*>>(_a[1]))); break;
        case 13: _t->disconnect(); break;
        case 14: _t->forget(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< NMSettings* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< NMSettings* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Network::*)(ConnectionFailReason::Enum )>(_a, &Network::connectionFailed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Network::*)()>(_a, &Network::nameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Network::*)()>(_a, &Network::connectedChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Network::*)()>(_a, &Network::knownChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Network::*)()>(_a, &Network::stateChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Network::*)()>(_a, &Network::stateChangingChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Network::*)()>(_a, &Network::nmSettingsChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Network::*)()>(_a, &Network::requestConnect, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Network::*)(NMSettings * )>(_a, &Network::requestConnectWithSettings, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Network::*)()>(_a, &Network::requestDisconnect, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Network::*)()>(_a, &Network::requestForget, 10))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<NMSettings*> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->bindableName().value(); break;
        case 1: *reinterpret_cast<NetworkDevice**>(_v) = _t->device(); break;
        case 2: *reinterpret_cast<QList<NMSettings*>*>(_v) = _t->bindableNmSettings().value(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->bindableConnected().value(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->bindableKnown().value(); break;
        case 5: *reinterpret_cast<ConnectionState::Enum*>(_v) = _t->bindableState().value(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->bindableStateChanging().value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::BindableProperty) {
        switch (_id) {
        case 0: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableName(); break;
        case 2: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableNmSettings(); break;
        case 3: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableConnected(); break;
        case 4: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableKnown(); break;
        case 5: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableState(); break;
        case 6: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableStateChanging(); break;
        default: break;
        }
    }
}

const QMetaObject *qs::network::Network::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::network::Network::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network7NetworkE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::network::Network::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void qs::network::Network::connectionFailed(ConnectionFailReason::Enum _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void qs::network::Network::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void qs::network::Network::connectedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void qs::network::Network::knownChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void qs::network::Network::stateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void qs::network::Network::stateChangingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void qs::network::Network::nmSettingsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void qs::network::Network::requestConnect()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void qs::network::Network::requestConnectWithSettings(NMSettings * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void qs::network::Network::requestDisconnect()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void qs::network::Network::requestForget()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
