// This file was generated by qtwaylandscanner
// source file is hyprland-surface-v1.xml

#ifndef QT_WAYLAND_HYPRLAND_SURFACE_V1
#define QT_WAYLAND_HYPRLAND_SURFACE_V1

#include "wayland-hyprland-surface-v1-client-protocol.h"
#include <QByteArray>
#include <QString>

struct wl_registry;

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {
    class  hyprland_surface_manager_v1
    {
    public:
        hyprland_surface_manager_v1(struct ::wl_registry *registry, uint32_t id, int version);
        hyprland_surface_manager_v1(struct ::hyprland_surface_manager_v1 *object);
        hyprland_surface_manager_v1();

        virtual ~hyprland_surface_manager_v1();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::hyprland_surface_manager_v1 *object);

        struct ::hyprland_surface_manager_v1 *object() { return m_hyprland_surface_manager_v1; }
        const struct ::hyprland_surface_manager_v1 *object() const { return m_hyprland_surface_manager_v1; }
        static hyprland_surface_manager_v1 *fromObject(struct ::hyprland_surface_manager_v1 *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        enum error {
            error_already_constructed = 0, // wl_surface already has a hyprland surface object
        };

        struct ::hyprland_surface_v1 *get_hyprland_surface(struct ::wl_surface *surface);
        void destroy();

    private:
        struct ::hyprland_surface_manager_v1 *m_hyprland_surface_manager_v1;
    };

    class  hyprland_surface_v1
    {
    public:
        hyprland_surface_v1(struct ::wl_registry *registry, uint32_t id, int version);
        hyprland_surface_v1(struct ::hyprland_surface_v1 *object);
        hyprland_surface_v1();

        virtual ~hyprland_surface_v1();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::hyprland_surface_v1 *object);

        struct ::hyprland_surface_v1 *object() { return m_hyprland_surface_v1; }
        const struct ::hyprland_surface_v1 *object() const { return m_hyprland_surface_v1; }
        static hyprland_surface_v1 *fromObject(struct ::hyprland_surface_v1 *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        enum error {
            error_no_surface = 0, // wl_surface was destroyed
            error_out_of_range = 1, // given opacity was not in the range 0.0 - 1.0 (inclusive)
        };

        void set_opacity(wl_fixed_t opacity);
        void destroy();
        void set_visible_region(struct ::wl_region *region);

    private:
        struct ::hyprland_surface_v1 *m_hyprland_surface_v1;
    };
}

QT_WARNING_POP
QT_END_NAMESPACE

#endif
