/****************************************************************************
** Meta object code from reading C++ file 'device.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/network/nm/device.hpp"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'device.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs7network8NMDeviceE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::network::NMDevice::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7network8NMDeviceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::network::NMDevice",
        "loaded",
        "",
        "activateConnection",
        "QDBusObjectPath",
        "connPath",
        "devPath",
        "addAndActivateConnection",
        "NMSettingsMap",
        "settings",
        "specificObjectPath",
        "networkAdded",
        "Network*",
        "net",
        "networkRemoved",
        "settingsLoaded",
        "NMSettings*",
        "settingsRemoved",
        "availableSettingsPathsChanged",
        "QList<QDBusObjectPath>",
        "paths",
        "activeConnectionPathChanged",
        "connection",
        "activeConnectionLoaded",
        "NMActiveConnection*",
        "active",
        "interfaceChanged",
        "interface",
        "hwAddressChanged",
        "hwAddress",
        "managedChanged",
        "managed",
        "stateChanged",
        "NMDeviceState::Enum",
        "state",
        "stateReasonChanged",
        "NMDeviceStateReason::Enum",
        "reason",
        "lastFailReasonChanged",
        "autoconnectChanged",
        "autoconnect",
        "interfaceFlagsChanged",
        "NMDeviceInterfaceFlags::Enum",
        "flags",
        "disconnect",
        "setAutoconnect",
        "setManaged",
        "onStateChanged",
        "newState",
        "oldState",
        "onAvailableSettingsPathsChanged",
        "onActiveConnectionPathChanged",
        "path"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'loaded'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activateConnection'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &, const QDBusObjectPath &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 4, 6 },
        }}),
        // Signal 'addAndActivateConnection'
        QtMocHelpers::SignalData<void(const NMSettingsMap &, const QDBusObjectPath &, const QDBusObjectPath &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 4, 6 }, { 0x80000000 | 4, 10 },
        }}),
        // Signal 'networkAdded'
        QtMocHelpers::SignalData<void(Network *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'networkRemoved'
        QtMocHelpers::SignalData<void(Network *)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'settingsLoaded'
        QtMocHelpers::SignalData<void(NMSettings *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 9 },
        }}),
        // Signal 'settingsRemoved'
        QtMocHelpers::SignalData<void(NMSettings *)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 9 },
        }}),
        // Signal 'availableSettingsPathsChanged'
        QtMocHelpers::SignalData<void(QList<QDBusObjectPath>)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'activeConnectionPathChanged'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 22 },
        }}),
        // Signal 'activeConnectionLoaded'
        QtMocHelpers::SignalData<void(NMActiveConnection *)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Signal 'interfaceChanged'
        QtMocHelpers::SignalData<void(const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 },
        }}),
        // Signal 'hwAddressChanged'
        QtMocHelpers::SignalData<void(const QString &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 },
        }}),
        // Signal 'managedChanged'
        QtMocHelpers::SignalData<void(bool)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 31 },
        }}),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void(NMDeviceState::Enum)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Signal 'stateReasonChanged'
        QtMocHelpers::SignalData<void(NMDeviceStateReason::Enum)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Signal 'lastFailReasonChanged'
        QtMocHelpers::SignalData<void(NMDeviceStateReason::Enum)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Signal 'autoconnectChanged'
        QtMocHelpers::SignalData<void(bool)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 40 },
        }}),
        // Signal 'interfaceFlagsChanged'
        QtMocHelpers::SignalData<void(NMDeviceInterfaceFlags::Enum)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 42, 43 },
        }}),
        // Slot 'disconnect'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setAutoconnect'
        QtMocHelpers::SlotData<void(bool)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 40 },
        }}),
        // Slot 'setManaged'
        QtMocHelpers::SlotData<void(bool)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 31 },
        }}),
        // Slot 'onStateChanged'
        QtMocHelpers::SlotData<void(quint32, quint32, quint32)>(47, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 48 }, { QMetaType::UInt, 49 }, { QMetaType::UInt, 37 },
        }}),
        // Slot 'onAvailableSettingsPathsChanged'
        QtMocHelpers::SlotData<void(const QList<QDBusObjectPath> &)>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'onActiveConnectionPathChanged'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 52 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NMDevice, qt_meta_tag_ZN2qs7network8NMDeviceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qs::network::NMDevice::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network8NMDeviceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network8NMDeviceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7network8NMDeviceE_t>.metaTypes,
    nullptr
} };

void qs::network::NMDevice::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NMDevice *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->loaded(); break;
        case 1: _t->activateConnection((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2]))); break;
        case 2: _t->addAndActivateConnection((*reinterpret_cast<std::add_pointer_t<NMSettingsMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[3]))); break;
        case 3: _t->networkAdded((*reinterpret_cast<std::add_pointer_t<Network*>>(_a[1]))); break;
        case 4: _t->networkRemoved((*reinterpret_cast<std::add_pointer_t<Network*>>(_a[1]))); break;
        case 5: _t->settingsLoaded((*reinterpret_cast<std::add_pointer_t<NMSettings*>>(_a[1]))); break;
        case 6: _t->settingsRemoved((*reinterpret_cast<std::add_pointer_t<NMSettings*>>(_a[1]))); break;
        case 7: _t->availableSettingsPathsChanged((*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>>>(_a[1]))); break;
        case 8: _t->activeConnectionPathChanged((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 9: _t->activeConnectionLoaded((*reinterpret_cast<std::add_pointer_t<NMActiveConnection*>>(_a[1]))); break;
        case 10: _t->interfaceChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->hwAddressChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->managedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->stateChanged((*reinterpret_cast<std::add_pointer_t<NMDeviceState::Enum>>(_a[1]))); break;
        case 14: _t->stateReasonChanged((*reinterpret_cast<std::add_pointer_t<NMDeviceStateReason::Enum>>(_a[1]))); break;
        case 15: _t->lastFailReasonChanged((*reinterpret_cast<std::add_pointer_t<NMDeviceStateReason::Enum>>(_a[1]))); break;
        case 16: _t->autoconnectChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->interfaceFlagsChanged((*reinterpret_cast<std::add_pointer_t<NMDeviceInterfaceFlags::Enum>>(_a[1]))); break;
        case 18: _t->disconnect(); break;
        case 19: _t->setAutoconnect((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->setManaged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->onStateChanged((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[3]))); break;
        case 22: _t->onAvailableSettingsPathsChanged((*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>>>(_a[1]))); break;
        case 23: _t->onActiveConnectionPathChanged((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Network* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Network* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< NMSettings* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< NMSettings* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QDBusObjectPath> >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< NMActiveConnection* >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QDBusObjectPath> >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NMDevice::*)()>(_a, &NMDevice::loaded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMDevice::*)(const QDBusObjectPath & , const QDBusObjectPath & )>(_a, &NMDevice::activateConnection, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMDevice::*)(const NMSettingsMap & , const QDBusObjectPath & , const QDBusObjectPath & )>(_a, &NMDevice::addAndActivateConnection, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMDevice::*)(Network * )>(_a, &NMDevice::networkAdded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMDevice::*)(Network * )>(_a, &NMDevice::networkRemoved, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMDevice::*)(NMSettings * )>(_a, &NMDevice::settingsLoaded, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMDevice::*)(NMSettings * )>(_a, &NMDevice::settingsRemoved, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMDevice::*)(QList<QDBusObjectPath> )>(_a, &NMDevice::availableSettingsPathsChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMDevice::*)(const QDBusObjectPath & )>(_a, &NMDevice::activeConnectionPathChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMDevice::*)(NMActiveConnection * )>(_a, &NMDevice::activeConnectionLoaded, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMDevice::*)(const QString & )>(_a, &NMDevice::interfaceChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMDevice::*)(const QString & )>(_a, &NMDevice::hwAddressChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMDevice::*)(bool )>(_a, &NMDevice::managedChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMDevice::*)(NMDeviceState::Enum )>(_a, &NMDevice::stateChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMDevice::*)(NMDeviceStateReason::Enum )>(_a, &NMDevice::stateReasonChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMDevice::*)(NMDeviceStateReason::Enum )>(_a, &NMDevice::lastFailReasonChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMDevice::*)(bool )>(_a, &NMDevice::autoconnectChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMDevice::*)(NMDeviceInterfaceFlags::Enum )>(_a, &NMDevice::interfaceFlagsChanged, 17))
            return;
    }
}

const QMetaObject *qs::network::NMDevice::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::network::NMDevice::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network8NMDeviceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::network::NMDevice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void qs::network::NMDevice::loaded()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void qs::network::NMDevice::activateConnection(const QDBusObjectPath & _t1, const QDBusObjectPath & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void qs::network::NMDevice::addAndActivateConnection(const NMSettingsMap & _t1, const QDBusObjectPath & _t2, const QDBusObjectPath & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void qs::network::NMDevice::networkAdded(Network * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void qs::network::NMDevice::networkRemoved(Network * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void qs::network::NMDevice::settingsLoaded(NMSettings * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void qs::network::NMDevice::settingsRemoved(NMSettings * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void qs::network::NMDevice::availableSettingsPathsChanged(QList<QDBusObjectPath> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void qs::network::NMDevice::activeConnectionPathChanged(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void qs::network::NMDevice::activeConnectionLoaded(NMActiveConnection * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void qs::network::NMDevice::interfaceChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void qs::network::NMDevice::hwAddressChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void qs::network::NMDevice::managedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void qs::network::NMDevice::stateChanged(NMDeviceState::Enum _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void qs::network::NMDevice::stateReasonChanged(NMDeviceStateReason::Enum _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void qs::network::NMDevice::lastFailReasonChanged(NMDeviceStateReason::Enum _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void qs::network::NMDevice::autoconnectChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void qs::network::NMDevice::interfaceFlagsChanged(NMDeviceInterfaceFlags::Enum _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}
QT_WARNING_POP
