/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.NetworkManager.Settings.Connection.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef DBUS_NM_CONNECTION_SETTINGS_H
#define DBUS_NM_CONNECTION_SETTINGS_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>
#include "/build/quickshell/src/quickshell/src/network/nm/dbus_types.hpp"

/*
 * Proxy class for interface org.freedesktop.NetworkManager.Settings.Connection
 */
class DBusNMConnectionSettingsProxy: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.NetworkManager.Settings.Connection"; }

public:
    DBusNMConnectionSettingsProxy(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~DBusNMConnectionSettingsProxy();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> ClearSecrets()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("ClearSecrets"), argumentList);
    }

    inline QDBusPendingReply<> Delete()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("Delete"), argumentList);
    }

    inline QDBusPendingReply<qs::network::NMSettingsMap> GetSecrets(const QString &setting_name)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(setting_name);
        return asyncCallWithArgumentList(QStringLiteral("GetSecrets"), argumentList);
    }

    inline QDBusPendingReply<qs::network::NMSettingsMap> GetSettings()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("GetSettings"), argumentList);
    }

    inline QDBusPendingReply<> Update(qs::network::NMSettingsMap properties)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(properties);
        return asyncCallWithArgumentList(QStringLiteral("Update"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void Removed();
    void Updated();
};

#endif
