/****************************************************************************
** Meta object code from reading C++ file 'qml.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../src/network/qml.hpp"
#include <QtCore/qmetatype.h>
#include <QtCore/QProperty>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qml.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs7network14NetworkBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::network::NetworkBackend::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7network14NetworkBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::network::NetworkBackend"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetworkBackend, qt_meta_tag_ZN2qs7network14NetworkBackendE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qs::network::NetworkBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network14NetworkBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network14NetworkBackendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7network14NetworkBackendE_t>.metaTypes,
    nullptr
} };

void qs::network::NetworkBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetworkBackend *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *qs::network::NetworkBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::network::NetworkBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network14NetworkBackendE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::network::NetworkBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN2qs7network10NetworkingE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::network::Networking::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7network10NetworkingE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::network::Networking",
        "requestSetWifiEnabled",
        "",
        "enabled",
        "requestSetConnectivityCheckEnabled",
        "requestCheckConnectivity",
        "wifiEnabledChanged",
        "wifiHardwareEnabledChanged",
        "canCheckConnectivityChanged",
        "connectivityCheckEnabledChanged",
        "connectivityChanged",
        "deviceAdded",
        "NetworkDevice*",
        "dev",
        "deviceRemoved"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestSetWifiEnabled'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'requestSetConnectivityCheckEnabled'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'requestCheckConnectivity'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wifiEnabledChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wifiHardwareEnabledChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canCheckConnectivityChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'connectivityCheckEnabledChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'connectivityChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deviceAdded'
        QtMocHelpers::SlotData<void(NetworkDevice *)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'deviceRemoved'
        QtMocHelpers::SlotData<void(NetworkDevice *)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Networking, qt_meta_tag_ZN2qs7network10NetworkingE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qs::network::Networking::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network10NetworkingE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network10NetworkingE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7network10NetworkingE_t>.metaTypes,
    nullptr
} };

void qs::network::Networking::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Networking *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestSetWifiEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->requestSetConnectivityCheckEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->requestCheckConnectivity(); break;
        case 3: _t->wifiEnabledChanged(); break;
        case 4: _t->wifiHardwareEnabledChanged(); break;
        case 5: _t->canCheckConnectivityChanged(); break;
        case 6: _t->connectivityCheckEnabledChanged(); break;
        case 7: _t->connectivityChanged(); break;
        case 8: _t->deviceAdded((*reinterpret_cast<std::add_pointer_t<NetworkDevice*>>(_a[1]))); break;
        case 9: _t->deviceRemoved((*reinterpret_cast<std::add_pointer_t<NetworkDevice*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< NetworkDevice* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< NetworkDevice* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Networking::*)(bool )>(_a, &Networking::requestSetWifiEnabled, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Networking::*)(bool )>(_a, &Networking::requestSetConnectivityCheckEnabled, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Networking::*)()>(_a, &Networking::requestCheckConnectivity, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Networking::*)()>(_a, &Networking::wifiEnabledChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Networking::*)()>(_a, &Networking::wifiHardwareEnabledChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Networking::*)()>(_a, &Networking::canCheckConnectivityChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Networking::*)()>(_a, &Networking::connectivityCheckEnabledChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Networking::*)()>(_a, &Networking::connectivityChanged, 7))
            return;
    }
}

const QMetaObject *qs::network::Networking::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::network::Networking::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network10NetworkingE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::network::Networking::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void qs::network::Networking::requestSetWifiEnabled(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void qs::network::Networking::requestSetConnectivityCheckEnabled(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void qs::network::Networking::requestCheckConnectivity()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void qs::network::Networking::wifiEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void qs::network::Networking::wifiHardwareEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void qs::network::Networking::canCheckConnectivityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void qs::network::Networking::connectivityCheckEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void qs::network::Networking::connectivityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
namespace {
struct qt_meta_tag_ZN2qs7network13NetworkingQmlE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::network::NetworkingQml::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7network13NetworkingQmlE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::network::NetworkingQml",
        "QML.Element",
        "Networking",
        "QML.Singleton",
        "true",
        "wifiEnabledChanged",
        "",
        "wifiHardwareEnabledChanged",
        "canCheckConnectivityChanged",
        "connectivityCheckEnabledChanged",
        "connectivityChanged",
        "checkConnectivity",
        "devices",
        "UntypedObjectModel*",
        "backend",
        "qs::network::NetworkBackendType::Enum",
        "wifiEnabled",
        "wifiHardwareEnabled",
        "canCheckConnectivity",
        "connectivityCheckEnabled",
        "connectivity",
        "qs::network::NetworkConnectivity::Enum"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'wifiEnabledChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wifiHardwareEnabledChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canCheckConnectivityChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'connectivityCheckEnabledChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'connectivityChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'checkConnectivity'
        QtMocHelpers::MethodData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'devices'
        QtMocHelpers::PropertyData<UntypedObjectModel*>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'backend'
        QtMocHelpers::PropertyData<qs::network::NetworkBackendType::Enum>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'wifiEnabled'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'wifiHardwareEnabled'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 1),
        // property 'canCheckConnectivity'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 2),
        // property 'connectivityCheckEnabled'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'connectivity'
        QtMocHelpers::PropertyData<qs::network::NetworkConnectivity::Enum>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Bindable, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<NetworkingQml, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN2qs7network13NetworkingQmlE[] = {
    QMetaObject::SuperData::link<qs::network::NetworkBackendType::staticMetaObject>(),
    QMetaObject::SuperData::link<qs::network::NetworkConnectivity::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject qs::network::NetworkingQml::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network13NetworkingQmlE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network13NetworkingQmlE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN2qs7network13NetworkingQmlE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7network13NetworkingQmlE_t>.metaTypes,
    nullptr
} };

void qs::network::NetworkingQml::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetworkingQml *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->wifiEnabledChanged(); break;
        case 1: _t->wifiHardwareEnabledChanged(); break;
        case 2: _t->canCheckConnectivityChanged(); break;
        case 3: _t->connectivityCheckEnabledChanged(); break;
        case 4: _t->connectivityChanged(); break;
        case 5: _t->checkConnectivity(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NetworkingQml::*)()>(_a, &NetworkingQml::wifiEnabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkingQml::*)()>(_a, &NetworkingQml::wifiHardwareEnabledChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkingQml::*)()>(_a, &NetworkingQml::canCheckConnectivityChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkingQml::*)()>(_a, &NetworkingQml::connectivityCheckEnabledChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkingQml::*)()>(_a, &NetworkingQml::connectivityChanged, 4))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< UntypedObjectModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<UntypedObjectModel**>(_v) = _t->devices(); break;
        case 1: *reinterpret_cast<qs::network::NetworkBackendType::Enum*>(_v) = _t->backend(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->wifiEnabled(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->bindableWifiHardwareEnabled().value(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->bindableCanCheckConnectivity().value(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->connectivityCheckEnabled(); break;
        case 6: *reinterpret_cast<qs::network::NetworkConnectivity::Enum*>(_v) = _t->bindableConnectivity().value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setWifiEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setConnectivityCheckEnabled(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::BindableProperty) {
        switch (_id) {
        case 3: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableWifiHardwareEnabled(); break;
        case 4: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableCanCheckConnectivity(); break;
        case 6: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableConnectivity(); break;
        default: break;
        }
    }
}

const QMetaObject *qs::network::NetworkingQml::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::network::NetworkingQml::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network13NetworkingQmlE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::network::NetworkingQml::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void qs::network::NetworkingQml::wifiEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void qs::network::NetworkingQml::wifiHardwareEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void qs::network::NetworkingQml::canCheckConnectivityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void qs::network::NetworkingQml::connectivityCheckEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void qs::network::NetworkingQml::connectivityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
