/****************************************************************************
** Meta object code from reading C++ file 'player.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/services/mpris/player.hpp"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#include <QtCore/QProperty>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'player.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs7service5mpris18MprisPlaybackStateE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::service::mpris::MprisPlaybackState::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7service5mpris18MprisPlaybackStateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::service::mpris::MprisPlaybackState",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "toString",
        "",
        "qs::service::mpris::MprisPlaybackState::Enum",
        "status",
        "Enum",
        "Stopped",
        "Playing",
        "Paused"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'toString'
        QtMocHelpers::MethodData<QString(qs::service::mpris::MprisPlaybackState::Enum)>(5, 6, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 7, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Enum'
        QtMocHelpers::EnumData<enum Enum>(9, 9, QMC::EnumFlags{}).add({
            {   10, Enum::Stopped },
            {   11, Enum::Playing },
            {   12, Enum::Paused },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<MprisPlaybackState, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject qs::service::mpris::MprisPlaybackState::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service5mpris18MprisPlaybackStateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service5mpris18MprisPlaybackStateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7service5mpris18MprisPlaybackStateE_t>.metaTypes,
    nullptr
} };

void qs::service::mpris::MprisPlaybackState::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MprisPlaybackState *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->toString((*reinterpret_cast<std::add_pointer_t<qs::service::mpris::MprisPlaybackState::Enum>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *qs::service::mpris::MprisPlaybackState::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::service::mpris::MprisPlaybackState::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service5mpris18MprisPlaybackStateE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::service::mpris::MprisPlaybackState::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN2qs7service5mpris14MprisLoopStateE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::service::mpris::MprisLoopState::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7service5mpris14MprisLoopStateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::service::mpris::MprisLoopState",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "toString",
        "",
        "qs::service::mpris::MprisLoopState::Enum",
        "status",
        "Enum",
        "None",
        "Track",
        "Playlist"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'toString'
        QtMocHelpers::MethodData<QString(qs::service::mpris::MprisLoopState::Enum)>(5, 6, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 7, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Enum'
        QtMocHelpers::EnumData<enum Enum>(9, 9, QMC::EnumFlags{}).add({
            {   10, Enum::None },
            {   11, Enum::Track },
            {   12, Enum::Playlist },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<MprisLoopState, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject qs::service::mpris::MprisLoopState::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service5mpris14MprisLoopStateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service5mpris14MprisLoopStateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7service5mpris14MprisLoopStateE_t>.metaTypes,
    nullptr
} };

void qs::service::mpris::MprisLoopState::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MprisLoopState *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->toString((*reinterpret_cast<std::add_pointer_t<qs::service::mpris::MprisLoopState::Enum>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *qs::service::mpris::MprisLoopState::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::service::mpris::MprisLoopState::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service5mpris14MprisLoopStateE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::service::mpris::MprisLoopState::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN2qs7service5mpris11MprisPlayerE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::service::mpris::MprisPlayer::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7service5mpris11MprisPlayerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::service::mpris::MprisPlayer",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "MprisPlayers can only be acquired from Mpris",
        "trackChanged",
        "",
        "postTrackChanged",
        "ready",
        "canControlChanged",
        "canPlayChanged",
        "canPauseChanged",
        "canTogglePlayingChanged",
        "canSeekChanged",
        "canGoNextChanged",
        "canGoPreviousChanged",
        "canQuitChanged",
        "canRaiseChanged",
        "canSetFullscreenChanged",
        "identityChanged",
        "desktopEntryChanged",
        "positionChanged",
        "positionSupportedChanged",
        "lengthChanged",
        "lengthSupportedChanged",
        "volumeChanged",
        "volumeSupportedChanged",
        "metadataChanged",
        "uniqueIdChanged",
        "trackTitleChanged",
        "trackArtistChanged",
        "trackAlbumChanged",
        "trackAlbumArtistChanged",
        "trackArtUrlChanged",
        "playbackStateChanged",
        "isPlayingChanged",
        "loopStateChanged",
        "loopSupportedChanged",
        "rateChanged",
        "minRateChanged",
        "maxRateChanged",
        "shuffleChanged",
        "shuffleSupportedChanged",
        "fullscreenChanged",
        "supportedUriSchemesChanged",
        "supportedMimeTypesChanged",
        "onGetAllFinished",
        "onExportedPositionChanged",
        "onSeek",
        "time",
        "raise",
        "quit",
        "openUri",
        "uri",
        "next",
        "previous",
        "seek",
        "offset",
        "play",
        "pause",
        "stop",
        "togglePlaying",
        "canControl",
        "canPlay",
        "canPause",
        "canTogglePlaying",
        "canSeek",
        "canGoNext",
        "canGoPrevious",
        "canQuit",
        "canRaise",
        "canSetFullscreen",
        "identity",
        "desktopEntry",
        "dbusName",
        "position",
        "positionSupported",
        "length",
        "lengthSupported",
        "volume",
        "volumeSupported",
        "metadata",
        "QVariantMap",
        "uniqueId",
        "trackTitle",
        "trackArtist",
        "trackArtists",
        "trackAlbum",
        "trackAlbumArtist",
        "trackArtUrl",
        "playbackState",
        "qs::service::mpris::MprisPlaybackState::Enum",
        "isPlaying",
        "loopState",
        "qs::service::mpris::MprisLoopState::Enum",
        "loopSupported",
        "rate",
        "minRate",
        "maxRate",
        "shuffle",
        "shuffleSupported",
        "fullscreen",
        "supportedUriSchemes",
        "supportedMimeTypes"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'trackChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'postTrackChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ready'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canControlChanged'
        QtMocHelpers::SignalData<void()>(11, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canPlayChanged'
        QtMocHelpers::SignalData<void()>(12, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canPauseChanged'
        QtMocHelpers::SignalData<void()>(13, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canTogglePlayingChanged'
        QtMocHelpers::SignalData<void()>(14, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canSeekChanged'
        QtMocHelpers::SignalData<void()>(15, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canGoNextChanged'
        QtMocHelpers::SignalData<void()>(16, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canGoPreviousChanged'
        QtMocHelpers::SignalData<void()>(17, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canQuitChanged'
        QtMocHelpers::SignalData<void()>(18, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canRaiseChanged'
        QtMocHelpers::SignalData<void()>(19, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canSetFullscreenChanged'
        QtMocHelpers::SignalData<void()>(20, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'identityChanged'
        QtMocHelpers::SignalData<void()>(21, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'desktopEntryChanged'
        QtMocHelpers::SignalData<void()>(22, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void()>(23, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'positionSupportedChanged'
        QtMocHelpers::SignalData<void()>(24, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lengthChanged'
        QtMocHelpers::SignalData<void()>(25, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lengthSupportedChanged'
        QtMocHelpers::SignalData<void()>(26, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'volumeChanged'
        QtMocHelpers::SignalData<void()>(27, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'volumeSupportedChanged'
        QtMocHelpers::SignalData<void()>(28, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'metadataChanged'
        QtMocHelpers::SignalData<void()>(29, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'uniqueIdChanged'
        QtMocHelpers::SignalData<void()>(30, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trackTitleChanged'
        QtMocHelpers::SignalData<void()>(31, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trackArtistChanged'
        QtMocHelpers::SignalData<void()>(32, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trackAlbumChanged'
        QtMocHelpers::SignalData<void()>(33, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trackAlbumArtistChanged'
        QtMocHelpers::SignalData<void()>(34, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trackArtUrlChanged'
        QtMocHelpers::SignalData<void()>(35, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playbackStateChanged'
        QtMocHelpers::SignalData<void()>(36, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isPlayingChanged'
        QtMocHelpers::SignalData<void()>(37, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loopStateChanged'
        QtMocHelpers::SignalData<void()>(38, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loopSupportedChanged'
        QtMocHelpers::SignalData<void()>(39, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rateChanged'
        QtMocHelpers::SignalData<void()>(40, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minRateChanged'
        QtMocHelpers::SignalData<void()>(41, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxRateChanged'
        QtMocHelpers::SignalData<void()>(42, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shuffleChanged'
        QtMocHelpers::SignalData<void()>(43, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shuffleSupportedChanged'
        QtMocHelpers::SignalData<void()>(44, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fullscreenChanged'
        QtMocHelpers::SignalData<void()>(45, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'supportedUriSchemesChanged'
        QtMocHelpers::SignalData<void()>(46, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'supportedMimeTypesChanged'
        QtMocHelpers::SignalData<void()>(47, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onGetAllFinished'
        QtMocHelpers::SlotData<void()>(48, 8, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onExportedPositionChanged'
        QtMocHelpers::SlotData<void()>(49, 8, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSeek'
        QtMocHelpers::SlotData<void(qlonglong)>(50, 8, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::LongLong, 51 },
        }}),
        // Method 'raise'
        QtMocHelpers::MethodData<void()>(52, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'quit'
        QtMocHelpers::MethodData<void()>(53, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'openUri'
        QtMocHelpers::MethodData<void(const QString &)>(54, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 55 },
        }}),
        // Method 'next'
        QtMocHelpers::MethodData<void()>(56, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'previous'
        QtMocHelpers::MethodData<void()>(57, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'seek'
        QtMocHelpers::MethodData<void(qreal)>(58, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 59 },
        }}),
        // Method 'play'
        QtMocHelpers::MethodData<void()>(60, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'pause'
        QtMocHelpers::MethodData<void()>(61, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'stop'
        QtMocHelpers::MethodData<void()>(62, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'togglePlaying'
        QtMocHelpers::MethodData<void()>(63, 8, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'canControl'
        QtMocHelpers::PropertyData<bool>(64, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 3),
        // property 'canPlay'
        QtMocHelpers::PropertyData<bool>(65, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 4),
        // property 'canPause'
        QtMocHelpers::PropertyData<bool>(66, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 5),
        // property 'canTogglePlaying'
        QtMocHelpers::PropertyData<bool>(67, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 6),
        // property 'canSeek'
        QtMocHelpers::PropertyData<bool>(68, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 7),
        // property 'canGoNext'
        QtMocHelpers::PropertyData<bool>(69, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 8),
        // property 'canGoPrevious'
        QtMocHelpers::PropertyData<bool>(70, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 9),
        // property 'canQuit'
        QtMocHelpers::PropertyData<bool>(71, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 10),
        // property 'canRaise'
        QtMocHelpers::PropertyData<bool>(72, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 11),
        // property 'canSetFullscreen'
        QtMocHelpers::PropertyData<bool>(73, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 12),
        // property 'identity'
        QtMocHelpers::PropertyData<QString>(74, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Bindable, 13),
        // property 'desktopEntry'
        QtMocHelpers::PropertyData<QString>(75, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Bindable, 14),
        // property 'dbusName'
        QtMocHelpers::PropertyData<QString>(76, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'position'
        QtMocHelpers::PropertyData<qreal>(77, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'positionSupported'
        QtMocHelpers::PropertyData<bool>(78, QMetaType::Bool, QMC::DefaultPropertyFlags, 16),
        // property 'length'
        QtMocHelpers::PropertyData<qreal>(79, QMetaType::QReal, QMC::DefaultPropertyFlags, 17),
        // property 'lengthSupported'
        QtMocHelpers::PropertyData<bool>(80, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 18),
        // property 'volume'
        QtMocHelpers::PropertyData<qreal>(81, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'volumeSupported'
        QtMocHelpers::PropertyData<bool>(82, QMetaType::Bool, QMC::DefaultPropertyFlags, 20),
        // property 'metadata'
        QtMocHelpers::PropertyData<QVariantMap>(83, 0x80000000 | 84, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Bindable, 21),
        // property 'uniqueId'
        QtMocHelpers::PropertyData<quint32>(85, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Bindable, 22),
        // property 'trackTitle'
        QtMocHelpers::PropertyData<QString>(86, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Bindable, 23),
        // property 'trackArtist'
        QtMocHelpers::PropertyData<QString>(87, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Bindable, 24),
        // property 'trackArtists'
        QtMocHelpers::PropertyData<QString>(88, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Bindable, 24),
        // property 'trackAlbum'
        QtMocHelpers::PropertyData<QString>(89, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Bindable, 25),
        // property 'trackAlbumArtist'
        QtMocHelpers::PropertyData<QString>(90, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Bindable, 26),
        // property 'trackArtUrl'
        QtMocHelpers::PropertyData<QString>(91, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Bindable, 27),
        // property 'playbackState'
        QtMocHelpers::PropertyData<qs::service::mpris::MprisPlaybackState::Enum>(92, 0x80000000 | 93, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 28),
        // property 'isPlaying'
        QtMocHelpers::PropertyData<bool>(94, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 29),
        // property 'loopState'
        QtMocHelpers::PropertyData<qs::service::mpris::MprisLoopState::Enum>(95, 0x80000000 | 96, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 30),
        // property 'loopSupported'
        QtMocHelpers::PropertyData<bool>(97, QMetaType::Bool, QMC::DefaultPropertyFlags, 31),
        // property 'rate'
        QtMocHelpers::PropertyData<qreal>(98, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 32),
        // property 'minRate'
        QtMocHelpers::PropertyData<qreal>(99, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Bindable, 33),
        // property 'maxRate'
        QtMocHelpers::PropertyData<qreal>(100, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Bindable, 34),
        // property 'shuffle'
        QtMocHelpers::PropertyData<bool>(101, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 35),
        // property 'shuffleSupported'
        QtMocHelpers::PropertyData<bool>(102, QMetaType::Bool, QMC::DefaultPropertyFlags, 36),
        // property 'fullscreen'
        QtMocHelpers::PropertyData<bool>(103, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 37),
        // property 'supportedUriSchemes'
        QtMocHelpers::PropertyData<QList<QString>>(104, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Bindable, 38),
        // property 'supportedMimeTypes'
        QtMocHelpers::PropertyData<QList<QString>>(105, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Bindable, 39),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<MprisPlayer, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN2qs7service5mpris11MprisPlayerE[] = {
    QMetaObject::SuperData::link<qs::service::mpris::MprisPlaybackState::staticMetaObject>(),
    QMetaObject::SuperData::link<qs::service::mpris::MprisLoopState::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject qs::service::mpris::MprisPlayer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service5mpris11MprisPlayerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service5mpris11MprisPlayerE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN2qs7service5mpris11MprisPlayerE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7service5mpris11MprisPlayerE_t>.metaTypes,
    nullptr
} };

void qs::service::mpris::MprisPlayer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MprisPlayer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->trackChanged(); break;
        case 1: _t->postTrackChanged(); break;
        case 2: _t->ready(); break;
        case 3: _t->canControlChanged(); break;
        case 4: _t->canPlayChanged(); break;
        case 5: _t->canPauseChanged(); break;
        case 6: _t->canTogglePlayingChanged(); break;
        case 7: _t->canSeekChanged(); break;
        case 8: _t->canGoNextChanged(); break;
        case 9: _t->canGoPreviousChanged(); break;
        case 10: _t->canQuitChanged(); break;
        case 11: _t->canRaiseChanged(); break;
        case 12: _t->canSetFullscreenChanged(); break;
        case 13: _t->identityChanged(); break;
        case 14: _t->desktopEntryChanged(); break;
        case 15: _t->positionChanged(); break;
        case 16: _t->positionSupportedChanged(); break;
        case 17: _t->lengthChanged(); break;
        case 18: _t->lengthSupportedChanged(); break;
        case 19: _t->volumeChanged(); break;
        case 20: _t->volumeSupportedChanged(); break;
        case 21: _t->metadataChanged(); break;
        case 22: _t->uniqueIdChanged(); break;
        case 23: _t->trackTitleChanged(); break;
        case 24: _t->trackArtistChanged(); break;
        case 25: _t->trackAlbumChanged(); break;
        case 26: _t->trackAlbumArtistChanged(); break;
        case 27: _t->trackArtUrlChanged(); break;
        case 28: _t->playbackStateChanged(); break;
        case 29: _t->isPlayingChanged(); break;
        case 30: _t->loopStateChanged(); break;
        case 31: _t->loopSupportedChanged(); break;
        case 32: _t->rateChanged(); break;
        case 33: _t->minRateChanged(); break;
        case 34: _t->maxRateChanged(); break;
        case 35: _t->shuffleChanged(); break;
        case 36: _t->shuffleSupportedChanged(); break;
        case 37: _t->fullscreenChanged(); break;
        case 38: _t->supportedUriSchemesChanged(); break;
        case 39: _t->supportedMimeTypesChanged(); break;
        case 40: _t->onGetAllFinished(); break;
        case 41: _t->onExportedPositionChanged(); break;
        case 42: _t->onSeek((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 43: _t->raise(); break;
        case 44: _t->quit(); break;
        case 45: _t->openUri((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 46: _t->next(); break;
        case 47: _t->previous(); break;
        case 48: _t->seek((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 49: _t->play(); break;
        case 50: _t->pause(); break;
        case 51: _t->stop(); break;
        case 52: _t->togglePlaying(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::trackChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::postTrackChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::ready, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::canControlChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::canPlayChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::canPauseChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::canTogglePlayingChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::canSeekChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::canGoNextChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::canGoPreviousChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::canQuitChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::canRaiseChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::canSetFullscreenChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::identityChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::desktopEntryChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::positionChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::positionSupportedChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::lengthChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::lengthSupportedChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::volumeChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::volumeSupportedChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::metadataChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::uniqueIdChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::trackTitleChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::trackArtistChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::trackAlbumChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::trackAlbumArtistChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::trackArtUrlChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::playbackStateChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::isPlayingChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::loopStateChanged, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::loopSupportedChanged, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::rateChanged, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::minRateChanged, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::maxRateChanged, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::shuffleChanged, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::shuffleSupportedChanged, 36))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::fullscreenChanged, 37))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::supportedUriSchemesChanged, 38))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::supportedMimeTypesChanged, 39))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->bindableCanControl().value(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->bindableCanPlay().value(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->bindableCanPause().value(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->bindableCanTogglePlaying().value(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->bindableCanSeek().value(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->bindableCanGoNext().value(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->bindableCanGoPrevious().value(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->bindableCanQuit().value(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->bindableCanRaise().value(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->bindableCanSetFullscreen().value(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->bindableIdentity().value(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->bindableDesktopEntry().value(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->address(); break;
        case 13: *reinterpret_cast<qreal*>(_v) = _t->position(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->positionSupported(); break;
        case 15: *reinterpret_cast<qreal*>(_v) = _t->length(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->bindableLengthSupported().value(); break;
        case 17: *reinterpret_cast<qreal*>(_v) = _t->volume(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->volumeSupported(); break;
        case 19: *reinterpret_cast<QVariantMap*>(_v) = _t->bindableMetadata().value(); break;
        case 20: *reinterpret_cast<quint32*>(_v) = _t->bindableUniqueId().value(); break;
        case 21: *reinterpret_cast<QString*>(_v) = _t->bindableTrackTitle().value(); break;
        case 22: *reinterpret_cast<QString*>(_v) = _t->bindableTrackArtist().value(); break;
        case 23: *reinterpret_cast<QString*>(_v) = _t->bindableTrackArtist().value(); break;
        case 24: *reinterpret_cast<QString*>(_v) = _t->bindableTrackAlbum().value(); break;
        case 25: *reinterpret_cast<QString*>(_v) = _t->bindableTrackAlbumArtist().value(); break;
        case 26: *reinterpret_cast<QString*>(_v) = _t->bindableTrackArtUrl().value(); break;
        case 27: *reinterpret_cast<qs::service::mpris::MprisPlaybackState::Enum*>(_v) = _t->playbackState(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->isPlaying(); break;
        case 29: *reinterpret_cast<qs::service::mpris::MprisLoopState::Enum*>(_v) = _t->loopState(); break;
        case 30: *reinterpret_cast<bool*>(_v) = _t->loopSupported(); break;
        case 31: *reinterpret_cast<qreal*>(_v) = _t->rate(); break;
        case 32: *reinterpret_cast<qreal*>(_v) = _t->bindableMinRate().value(); break;
        case 33: *reinterpret_cast<qreal*>(_v) = _t->bindableMaxRate().value(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->shuffle(); break;
        case 35: *reinterpret_cast<bool*>(_v) = _t->shuffleSupported(); break;
        case 36: *reinterpret_cast<bool*>(_v) = _t->fullscreen(); break;
        case 37: *reinterpret_cast<QList<QString>*>(_v) = _t->bindableSupportedUriSchemes().value(); break;
        case 38: *reinterpret_cast<QList<QString>*>(_v) = _t->bindableSupportedMimeTypes().value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 13: _t->setPosition(*reinterpret_cast<qreal*>(_v)); break;
        case 17: _t->setVolume(*reinterpret_cast<qreal*>(_v)); break;
        case 27: _t->setPlaybackState(*reinterpret_cast<qs::service::mpris::MprisPlaybackState::Enum*>(_v)); break;
        case 28: _t->setPlaying(*reinterpret_cast<bool*>(_v)); break;
        case 29: _t->setLoopState(*reinterpret_cast<qs::service::mpris::MprisLoopState::Enum*>(_v)); break;
        case 31: _t->setRate(*reinterpret_cast<qreal*>(_v)); break;
        case 34: _t->setShuffle(*reinterpret_cast<bool*>(_v)); break;
        case 36: _t->setFullscreen(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::BindableProperty) {
        switch (_id) {
        case 0: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableCanControl(); break;
        case 1: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableCanPlay(); break;
        case 2: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableCanPause(); break;
        case 3: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableCanTogglePlaying(); break;
        case 4: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableCanSeek(); break;
        case 5: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableCanGoNext(); break;
        case 6: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableCanGoPrevious(); break;
        case 7: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableCanQuit(); break;
        case 8: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableCanRaise(); break;
        case 9: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableCanSetFullscreen(); break;
        case 10: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableIdentity(); break;
        case 11: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableDesktopEntry(); break;
        case 16: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableLengthSupported(); break;
        case 19: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableMetadata(); break;
        case 20: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableUniqueId(); break;
        case 21: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableTrackTitle(); break;
        case 22: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableTrackArtist(); break;
        case 23: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableTrackArtist(); break;
        case 24: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableTrackAlbum(); break;
        case 25: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableTrackAlbumArtist(); break;
        case 26: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableTrackArtUrl(); break;
        case 32: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableMinRate(); break;
        case 33: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableMaxRate(); break;
        case 37: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableSupportedUriSchemes(); break;
        case 38: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableSupportedMimeTypes(); break;
        default: break;
        }
    }
}

const QMetaObject *qs::service::mpris::MprisPlayer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::service::mpris::MprisPlayer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service5mpris11MprisPlayerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::service::mpris::MprisPlayer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 53)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 53;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 53)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 53;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 39;
    }
    return _id;
}

// SIGNAL 0
void qs::service::mpris::MprisPlayer::trackChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void qs::service::mpris::MprisPlayer::postTrackChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void qs::service::mpris::MprisPlayer::ready()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void qs::service::mpris::MprisPlayer::canControlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void qs::service::mpris::MprisPlayer::canPlayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void qs::service::mpris::MprisPlayer::canPauseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void qs::service::mpris::MprisPlayer::canTogglePlayingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void qs::service::mpris::MprisPlayer::canSeekChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void qs::service::mpris::MprisPlayer::canGoNextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void qs::service::mpris::MprisPlayer::canGoPreviousChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void qs::service::mpris::MprisPlayer::canQuitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void qs::service::mpris::MprisPlayer::canRaiseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void qs::service::mpris::MprisPlayer::canSetFullscreenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void qs::service::mpris::MprisPlayer::identityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void qs::service::mpris::MprisPlayer::desktopEntryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void qs::service::mpris::MprisPlayer::positionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void qs::service::mpris::MprisPlayer::positionSupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void qs::service::mpris::MprisPlayer::lengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void qs::service::mpris::MprisPlayer::lengthSupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void qs::service::mpris::MprisPlayer::volumeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void qs::service::mpris::MprisPlayer::volumeSupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void qs::service::mpris::MprisPlayer::metadataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void qs::service::mpris::MprisPlayer::uniqueIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void qs::service::mpris::MprisPlayer::trackTitleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void qs::service::mpris::MprisPlayer::trackArtistChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void qs::service::mpris::MprisPlayer::trackAlbumChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void qs::service::mpris::MprisPlayer::trackAlbumArtistChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void qs::service::mpris::MprisPlayer::trackArtUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void qs::service::mpris::MprisPlayer::playbackStateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void qs::service::mpris::MprisPlayer::isPlayingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void qs::service::mpris::MprisPlayer::loopStateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 30, nullptr);
}

// SIGNAL 31
void qs::service::mpris::MprisPlayer::loopSupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 31, nullptr);
}

// SIGNAL 32
void qs::service::mpris::MprisPlayer::rateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 32, nullptr);
}

// SIGNAL 33
void qs::service::mpris::MprisPlayer::minRateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 33, nullptr);
}

// SIGNAL 34
void qs::service::mpris::MprisPlayer::maxRateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 34, nullptr);
}

// SIGNAL 35
void qs::service::mpris::MprisPlayer::shuffleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 35, nullptr);
}

// SIGNAL 36
void qs::service::mpris::MprisPlayer::shuffleSupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 36, nullptr);
}

// SIGNAL 37
void qs::service::mpris::MprisPlayer::fullscreenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 37, nullptr);
}

// SIGNAL 38
void qs::service::mpris::MprisPlayer::supportedUriSchemesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 38, nullptr);
}

// SIGNAL 39
void qs::service::mpris::MprisPlayer::supportedMimeTypesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 39, nullptr);
}
QT_WARNING_POP
