/****************************************************************************
** Meta object code from reading C++ file 'qml.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/services/greetd/qml.hpp"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qml.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6GreetdE_t {};
} // unnamed namespace

template <> constexpr inline auto Greetd::qt_create_metaobjectdata<qt_meta_tag_ZN6GreetdE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Greetd",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "authMessage",
        "",
        "message",
        "error",
        "responseRequired",
        "echoResponse",
        "authFailure",
        "readyToLaunch",
        "launched",
        "stateChanged",
        "userChanged",
        "createSession",
        "user",
        "cancelSession",
        "respond",
        "response",
        "launch",
        "command",
        "environment",
        "quit",
        "available",
        "state",
        "GreetdState::Enum"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'authMessage'
        QtMocHelpers::SignalData<void(QString, bool, bool, bool)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::Bool, 8 }, { QMetaType::Bool, 9 }, { QMetaType::Bool, 10 },
        }}),
        // Signal 'authFailure'
        QtMocHelpers::SignalData<void(QString)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'readyToLaunch'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'launched'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'error'
        QtMocHelpers::SignalData<void(QString)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'userChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'createSession'
        QtMocHelpers::MethodData<void(QString)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Method 'cancelSession'
        QtMocHelpers::MethodData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'respond'
        QtMocHelpers::MethodData<void(QString)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Method 'launch'
        QtMocHelpers::MethodData<void(const QList<QString> &)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 22 },
        }}),
        // Method 'launch'
        QtMocHelpers::MethodData<void(const QList<QString> &, const QList<QString> &)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 22 }, { QMetaType::QStringList, 23 },
        }}),
        // Method 'launch'
        QtMocHelpers::MethodData<void(const QList<QString> &, const QList<QString> &, bool)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 22 }, { QMetaType::QStringList, 23 }, { QMetaType::Bool, 24 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'available'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'state'
        QtMocHelpers::PropertyData<GreetdState::Enum>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'user'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Greetd, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN6GreetdE[] = {
    QMetaObject::SuperData::link<GreetdState::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Greetd::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6GreetdE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6GreetdE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN6GreetdE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6GreetdE_t>.metaTypes,
    nullptr
} };

void Greetd::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Greetd *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->authMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 1: _t->authFailure((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->readyToLaunch(); break;
        case 3: _t->launched(); break;
        case 4: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->stateChanged(); break;
        case 6: _t->userChanged(); break;
        case 7: _t->createSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->cancelSession(); break;
        case 9: _t->respond((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->launch((*reinterpret_cast<std::add_pointer_t<QList<QString>>>(_a[1]))); break;
        case 11: _t->launch((*reinterpret_cast<std::add_pointer_t<QList<QString>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QString>>>(_a[2]))); break;
        case 12: _t->launch((*reinterpret_cast<std::add_pointer_t<QList<QString>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QString>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Greetd::*)(QString , bool , bool , bool )>(_a, &Greetd::authMessage, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Greetd::*)(QString )>(_a, &Greetd::authFailure, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Greetd::*)()>(_a, &Greetd::readyToLaunch, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Greetd::*)()>(_a, &Greetd::launched, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Greetd::*)(QString )>(_a, &Greetd::error, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Greetd::*)()>(_a, &Greetd::stateChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Greetd::*)()>(_a, &Greetd::userChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isAvailable(); break;
        case 1: *reinterpret_cast<GreetdState::Enum*>(_v) = _t->state(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->user(); break;
        default: break;
        }
    }
}

const QMetaObject *Greetd::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Greetd::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6GreetdE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Greetd::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void Greetd::authMessage(QString _t1, bool _t2, bool _t3, bool _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 1
void Greetd::authFailure(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Greetd::readyToLaunch()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Greetd::launched()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Greetd::error(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Greetd::stateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Greetd::userChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
