/****************************************************************************
** Meta object code from reading C++ file 'registry.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/services/pipewire/registry.hpp"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'registry.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs7service8pipewire16PwBindableObjectE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::service::pipewire::PwBindableObject::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7service8pipewire16PwBindableObjectE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::service::pipewire::PwBindableObject",
        "destroying",
        "",
        "PwBindableObject*",
        "self"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'destroying'
        QtMocHelpers::SignalData<void(PwBindableObject *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PwBindableObject, qt_meta_tag_ZN2qs7service8pipewire16PwBindableObjectE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qs::service::pipewire::PwBindableObject::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service8pipewire16PwBindableObjectE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service8pipewire16PwBindableObjectE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7service8pipewire16PwBindableObjectE_t>.metaTypes,
    nullptr
} };

void qs::service::pipewire::PwBindableObject::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PwBindableObject *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->destroying((*reinterpret_cast<std::add_pointer_t<PwBindableObject*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PwBindableObject* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PwBindableObject::*)(PwBindableObject * )>(_a, &PwBindableObject::destroying, 0))
            return;
    }
}

const QMetaObject *qs::service::pipewire::PwBindableObject::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::service::pipewire::PwBindableObject::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service8pipewire16PwBindableObjectE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::service::pipewire::PwBindableObject::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void qs::service::pipewire::PwBindableObject::destroying(PwBindableObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN2qs7service8pipewire19PwBindableObjectRefE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::service::pipewire::PwBindableObjectRef::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7service8pipewire19PwBindableObjectRefE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::service::pipewire::PwBindableObjectRef",
        "objectDestroyed",
        "",
        "onObjectDestroyed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'objectDestroyed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onObjectDestroyed'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PwBindableObjectRef, qt_meta_tag_ZN2qs7service8pipewire19PwBindableObjectRefE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qs::service::pipewire::PwBindableObjectRef::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service8pipewire19PwBindableObjectRefE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service8pipewire19PwBindableObjectRefE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7service8pipewire19PwBindableObjectRefE_t>.metaTypes,
    nullptr
} };

void qs::service::pipewire::PwBindableObjectRef::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PwBindableObjectRef *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->objectDestroyed(); break;
        case 1: _t->onObjectDestroyed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PwBindableObjectRef::*)()>(_a, &PwBindableObjectRef::objectDestroyed, 0))
            return;
    }
}

const QMetaObject *qs::service::pipewire::PwBindableObjectRef::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::service::pipewire::PwBindableObjectRef::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service8pipewire19PwBindableObjectRefE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::service::pipewire::PwBindableObjectRef::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void qs::service::pipewire::PwBindableObjectRef::objectDestroyed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN2qs7service8pipewire10PwRegistryE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::service::pipewire::PwRegistry::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7service8pipewire10PwRegistryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::service::pipewire::PwRegistry",
        "nodeAdded",
        "",
        "PwNode*",
        "node",
        "linkAdded",
        "PwLink*",
        "link",
        "linkGroupAdded",
        "PwLinkGroup*",
        "group",
        "metadataAdded",
        "PwMetadata*",
        "metadata",
        "initialized",
        "cleared",
        "onLinkGroupDestroyed",
        "object",
        "onCoreSync",
        "id",
        "seq"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nodeAdded'
        QtMocHelpers::SignalData<void(PwNode *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'linkAdded'
        QtMocHelpers::SignalData<void(PwLink *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'linkGroupAdded'
        QtMocHelpers::SignalData<void(PwLinkGroup *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'metadataAdded'
        QtMocHelpers::SignalData<void(PwMetadata *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'initialized'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cleared'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onLinkGroupDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 17 },
        }}),
        // Slot 'onCoreSync'
        QtMocHelpers::SlotData<void(quint32, qint32)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 19 }, { QMetaType::Int, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PwRegistry, qt_meta_tag_ZN2qs7service8pipewire10PwRegistryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qs::service::pipewire::PwRegistry::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service8pipewire10PwRegistryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service8pipewire10PwRegistryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7service8pipewire10PwRegistryE_t>.metaTypes,
    nullptr
} };

void qs::service::pipewire::PwRegistry::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PwRegistry *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nodeAdded((*reinterpret_cast<std::add_pointer_t<PwNode*>>(_a[1]))); break;
        case 1: _t->linkAdded((*reinterpret_cast<std::add_pointer_t<PwLink*>>(_a[1]))); break;
        case 2: _t->linkGroupAdded((*reinterpret_cast<std::add_pointer_t<PwLinkGroup*>>(_a[1]))); break;
        case 3: _t->metadataAdded((*reinterpret_cast<std::add_pointer_t<PwMetadata*>>(_a[1]))); break;
        case 4: _t->initialized(); break;
        case 5: _t->cleared(); break;
        case 6: _t->onLinkGroupDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 7: _t->onCoreSync((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint32>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PwRegistry::*)(PwNode * )>(_a, &PwRegistry::nodeAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PwRegistry::*)(PwLink * )>(_a, &PwRegistry::linkAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PwRegistry::*)(PwLinkGroup * )>(_a, &PwRegistry::linkGroupAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PwRegistry::*)(PwMetadata * )>(_a, &PwRegistry::metadataAdded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PwRegistry::*)()>(_a, &PwRegistry::initialized, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PwRegistry::*)()>(_a, &PwRegistry::cleared, 5))
            return;
    }
}

const QMetaObject *qs::service::pipewire::PwRegistry::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::service::pipewire::PwRegistry::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service8pipewire10PwRegistryE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "PwObject<pw_registry>"))
        return static_cast< PwObject<pw_registry>*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::service::pipewire::PwRegistry::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void qs::service::pipewire::PwRegistry::nodeAdded(PwNode * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void qs::service::pipewire::PwRegistry::linkAdded(PwLink * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void qs::service::pipewire::PwRegistry::linkGroupAdded(PwLinkGroup * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void qs::service::pipewire::PwRegistry::metadataAdded(PwMetadata * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void qs::service::pipewire::PwRegistry::initialized()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void qs::service::pipewire::PwRegistry::cleared()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
