// This file was generated by qtwaylandscanner
// source file is hyprland-global-shortcuts-v1.xml

#ifndef QT_WAYLAND_HYPRLAND_GLOBAL_SHORTCUTS_V1
#define QT_WAYLAND_HYPRLAND_GLOBAL_SHORTCUTS_V1

#include "wayland-hyprland-global-shortcuts-v1-client-protocol.h"
#include <QByteArray>
#include <QString>

struct wl_registry;

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {
    class  hyprland_global_shortcuts_manager_v1
    {
    public:
        hyprland_global_shortcuts_manager_v1(struct ::wl_registry *registry, uint32_t id, int version);
        hyprland_global_shortcuts_manager_v1(struct ::hyprland_global_shortcuts_manager_v1 *object);
        hyprland_global_shortcuts_manager_v1();

        virtual ~hyprland_global_shortcuts_manager_v1();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::hyprland_global_shortcuts_manager_v1 *object);

        struct ::hyprland_global_shortcuts_manager_v1 *object() { return m_hyprland_global_shortcuts_manager_v1; }
        const struct ::hyprland_global_shortcuts_manager_v1 *object() const { return m_hyprland_global_shortcuts_manager_v1; }
        static hyprland_global_shortcuts_manager_v1 *fromObject(struct ::hyprland_global_shortcuts_manager_v1 *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        enum error {
            error_already_taken = 0, // the app_id + id combination has already been registered.
        };

        struct ::hyprland_global_shortcut_v1 *register_shortcut(const QString &id, const QString &app_id, const QString &description, const QString &trigger_description);
        void destroy();

    private:
        struct ::hyprland_global_shortcuts_manager_v1 *m_hyprland_global_shortcuts_manager_v1;
    };

    class  hyprland_global_shortcut_v1
    {
    public:
        hyprland_global_shortcut_v1(struct ::wl_registry *registry, uint32_t id, int version);
        hyprland_global_shortcut_v1(struct ::hyprland_global_shortcut_v1 *object);
        hyprland_global_shortcut_v1();

        virtual ~hyprland_global_shortcut_v1();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::hyprland_global_shortcut_v1 *object);

        struct ::hyprland_global_shortcut_v1 *object() { return m_hyprland_global_shortcut_v1; }
        const struct ::hyprland_global_shortcut_v1 *object() const { return m_hyprland_global_shortcut_v1; }
        static hyprland_global_shortcut_v1 *fromObject(struct ::hyprland_global_shortcut_v1 *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        void destroy();

    protected:
        virtual void hyprland_global_shortcut_v1_pressed(uint32_t tv_sec_hi, uint32_t tv_sec_lo, uint32_t tv_nsec);
        virtual void hyprland_global_shortcut_v1_released(uint32_t tv_sec_hi, uint32_t tv_sec_lo, uint32_t tv_nsec);

    private:
        void init_listener();
        static const struct hyprland_global_shortcut_v1_listener m_hyprland_global_shortcut_v1_listener;
        static void handle_pressed(
            void *data,
            struct ::hyprland_global_shortcut_v1 *object,
            uint32_t tv_sec_hi,
            uint32_t tv_sec_lo,
            uint32_t tv_nsec);
        static void handle_released(
            void *data,
            struct ::hyprland_global_shortcut_v1 *object,
            uint32_t tv_sec_hi,
            uint32_t tv_sec_lo,
            uint32_t tv_nsec);
        struct ::hyprland_global_shortcut_v1 *m_hyprland_global_shortcut_v1;
    };
}

QT_WARNING_POP
QT_END_NAMESPACE

#endif
