/****************************************************************************
** Meta object code from reading C++ file 'flow.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/services/polkit/flow.hpp"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#include <QtCore/QProperty>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'flow.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs7service6polkit8AuthFlowE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::service::polkit::AuthFlow::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7service6polkit8AuthFlowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::service::polkit::AuthFlow",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "AuthFlow can only be obtained from PolkitAgent.",
        "authenticationSucceeded",
        "",
        "authenticationFailed",
        "authenticationRequestCancelled",
        "selectedIdentityChanged",
        "isResponseRequiredChanged",
        "inputPromptChanged",
        "responseVisibleChanged",
        "supplementaryMessageChanged",
        "supplementaryIsErrorChanged",
        "isCompletedChanged",
        "isSuccessfulChanged",
        "isCancelledChanged",
        "failedChanged",
        "request",
        "message",
        "echo",
        "completed",
        "gainedAuthorization",
        "showError",
        "showInfo",
        "submit",
        "value",
        "cancelAuthenticationRequest",
        "iconName",
        "actionId",
        "cookie",
        "identities",
        "QList<Identity*>",
        "selectedIdentity",
        "Identity*",
        "isResponseRequired",
        "inputPrompt",
        "responseVisible",
        "supplementaryMessage",
        "supplementaryIsError",
        "isCompleted",
        "isSuccessful",
        "isCancelled",
        "failed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'authenticationSucceeded'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'authenticationFailed'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'authenticationRequestCancelled'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectedIdentityChanged'
        QtMocHelpers::SignalData<void()>(11, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isResponseRequiredChanged'
        QtMocHelpers::SignalData<void()>(12, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputPromptChanged'
        QtMocHelpers::SignalData<void()>(13, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'responseVisibleChanged'
        QtMocHelpers::SignalData<void()>(14, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'supplementaryMessageChanged'
        QtMocHelpers::SignalData<void()>(15, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'supplementaryIsErrorChanged'
        QtMocHelpers::SignalData<void()>(16, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isCompletedChanged'
        QtMocHelpers::SignalData<void()>(17, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isSuccessfulChanged'
        QtMocHelpers::SignalData<void()>(18, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isCancelledChanged'
        QtMocHelpers::SignalData<void()>(19, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'failedChanged'
        QtMocHelpers::SignalData<void()>(20, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'request'
        QtMocHelpers::SlotData<void(const QString &, bool)>(21, 8, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 22 }, { QMetaType::Bool, 23 },
        }}),
        // Slot 'completed'
        QtMocHelpers::SlotData<void(bool)>(24, 8, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'showError'
        QtMocHelpers::SlotData<void(const QString &)>(26, 8, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'showInfo'
        QtMocHelpers::SlotData<void(const QString &)>(27, 8, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Method 'submit'
        QtMocHelpers::MethodData<void(const QString &)>(28, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 },
        }}),
        // Method 'cancelAuthenticationRequest'
        QtMocHelpers::MethodData<void()>(30, 8, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'message'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'iconName'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'actionId'
        QtMocHelpers::PropertyData<QString>(32, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'cookie'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'identities'
        QtMocHelpers::PropertyData<QList<Identity*>>(34, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'selectedIdentity'
        QtMocHelpers::PropertyData<Identity*>(36, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Bindable, 3),
        // property 'isResponseRequired'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 4),
        // property 'inputPrompt'
        QtMocHelpers::PropertyData<QString>(39, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Bindable, 5),
        // property 'responseVisible'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 6),
        // property 'supplementaryMessage'
        QtMocHelpers::PropertyData<QString>(41, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Bindable, 7),
        // property 'supplementaryIsError'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 8),
        // property 'isCompleted'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 9),
        // property 'isSuccessful'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 10),
        // property 'isCancelled'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 11),
        // property 'failed'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 12),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<AuthFlow, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject qs::service::polkit::AuthFlow::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service6polkit8AuthFlowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service6polkit8AuthFlowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7service6polkit8AuthFlowE_t>.metaTypes,
    nullptr
} };

void qs::service::polkit::AuthFlow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AuthFlow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->authenticationSucceeded(); break;
        case 1: _t->authenticationFailed(); break;
        case 2: _t->authenticationRequestCancelled(); break;
        case 3: _t->selectedIdentityChanged(); break;
        case 4: _t->isResponseRequiredChanged(); break;
        case 5: _t->inputPromptChanged(); break;
        case 6: _t->responseVisibleChanged(); break;
        case 7: _t->supplementaryMessageChanged(); break;
        case 8: _t->supplementaryIsErrorChanged(); break;
        case 9: _t->isCompletedChanged(); break;
        case 10: _t->isSuccessfulChanged(); break;
        case 11: _t->isCancelledChanged(); break;
        case 12: _t->failedChanged(); break;
        case 13: _t->request((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 14: _t->completed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->showError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->showInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->submit((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->cancelAuthenticationRequest(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AuthFlow::*)()>(_a, &AuthFlow::authenticationSucceeded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AuthFlow::*)()>(_a, &AuthFlow::authenticationFailed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AuthFlow::*)()>(_a, &AuthFlow::authenticationRequestCancelled, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AuthFlow::*)()>(_a, &AuthFlow::selectedIdentityChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AuthFlow::*)()>(_a, &AuthFlow::isResponseRequiredChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AuthFlow::*)()>(_a, &AuthFlow::inputPromptChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AuthFlow::*)()>(_a, &AuthFlow::responseVisibleChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AuthFlow::*)()>(_a, &AuthFlow::supplementaryMessageChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AuthFlow::*)()>(_a, &AuthFlow::supplementaryIsErrorChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AuthFlow::*)()>(_a, &AuthFlow::isCompletedChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AuthFlow::*)()>(_a, &AuthFlow::isSuccessfulChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AuthFlow::*)()>(_a, &AuthFlow::isCancelledChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (AuthFlow::*)()>(_a, &AuthFlow::failedChanged, 12))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Identity* >(); break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<Identity*> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->message(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->iconName(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->actionId(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->cookie(); break;
        case 4: *reinterpret_cast<QList<Identity*>*>(_v) = _t->identities(); break;
        case 5: *reinterpret_cast<Identity**>(_v) = _t->selectedIdentity().value(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isResponseRequired().value(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->inputPrompt().value(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->responseVisible().value(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->supplementaryMessage().value(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->supplementaryIsError().value(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->isCompleted().value(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->isSuccessful().value(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isCancelled().value(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->failed().value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 5: _t->setSelectedIdentity(*reinterpret_cast<Identity**>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::BindableProperty) {
        switch (_id) {
        case 5: *static_cast<QUntypedBindable *>(_a[0]) = _t->selectedIdentity(); break;
        case 6: *static_cast<QUntypedBindable *>(_a[0]) = _t->isResponseRequired(); break;
        case 7: *static_cast<QUntypedBindable *>(_a[0]) = _t->inputPrompt(); break;
        case 8: *static_cast<QUntypedBindable *>(_a[0]) = _t->responseVisible(); break;
        case 9: *static_cast<QUntypedBindable *>(_a[0]) = _t->supplementaryMessage(); break;
        case 10: *static_cast<QUntypedBindable *>(_a[0]) = _t->supplementaryIsError(); break;
        case 11: *static_cast<QUntypedBindable *>(_a[0]) = _t->isCompleted(); break;
        case 12: *static_cast<QUntypedBindable *>(_a[0]) = _t->isSuccessful(); break;
        case 13: *static_cast<QUntypedBindable *>(_a[0]) = _t->isCancelled(); break;
        case 14: *static_cast<QUntypedBindable *>(_a[0]) = _t->failed(); break;
        default: break;
        }
    }
}

const QMetaObject *qs::service::polkit::AuthFlow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::service::polkit::AuthFlow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7service6polkit8AuthFlowE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Retainable"))
        return static_cast< Retainable*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::service::polkit::AuthFlow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void qs::service::polkit::AuthFlow::authenticationSucceeded()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void qs::service::polkit::AuthFlow::authenticationFailed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void qs::service::polkit::AuthFlow::authenticationRequestCancelled()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void qs::service::polkit::AuthFlow::selectedIdentityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void qs::service::polkit::AuthFlow::isResponseRequiredChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void qs::service::polkit::AuthFlow::inputPromptChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void qs::service::polkit::AuthFlow::responseVisibleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void qs::service::polkit::AuthFlow::supplementaryMessageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void qs::service::polkit::AuthFlow::supplementaryIsErrorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void qs::service::polkit::AuthFlow::isCompletedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void qs::service::polkit::AuthFlow::isSuccessfulChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void qs::service::polkit::AuthFlow::isCancelledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void qs::service::polkit::AuthFlow::failedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}
QT_WARNING_POP
