/****************************************************************************
** Meta object code from reading C++ file 'qml.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/wayland/toplevel_management/qml.hpp"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qml.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs7wayland19toplevel_management8ToplevelE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::wayland::toplevel_management::Toplevel::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7wayland19toplevel_management8ToplevelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::wayland::toplevel_management::Toplevel",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Toplevels must be acquired from the ToplevelManager.",
        "closed",
        "",
        "appIdChanged",
        "titleChanged",
        "parentChanged",
        "activatedChanged",
        "screensChanged",
        "maximizedChanged",
        "minimizedChanged",
        "fullscreenChanged",
        "onClosed",
        "onRectangleProxyConnected",
        "onRectangleProxyDestroyed",
        "activate",
        "close",
        "fullscreenOn",
        "QuickshellScreenInfo*",
        "screen",
        "setRectangle",
        "window",
        "QRect",
        "rect",
        "unsetRectangle",
        "appId",
        "title",
        "parent",
        "qs::wayland::toplevel_management::Toplevel*",
        "activated",
        "screens",
        "QList<QuickshellScreenInfo*>",
        "maximized",
        "minimized",
        "fullscreen"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'closed'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'appIdChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'parentChanged'
        QtMocHelpers::SignalData<void()>(11, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activatedChanged'
        QtMocHelpers::SignalData<void()>(12, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'screensChanged'
        QtMocHelpers::SignalData<void()>(13, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maximizedChanged'
        QtMocHelpers::SignalData<void()>(14, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minimizedChanged'
        QtMocHelpers::SignalData<void()>(15, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fullscreenChanged'
        QtMocHelpers::SignalData<void()>(16, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onClosed'
        QtMocHelpers::SlotData<void()>(17, 8, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onRectangleProxyConnected'
        QtMocHelpers::SlotData<void()>(18, 8, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onRectangleProxyDestroyed'
        QtMocHelpers::SlotData<void()>(19, 8, QMC::AccessPrivate, QMetaType::Void),
        // Method 'activate'
        QtMocHelpers::MethodData<void()>(20, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'close'
        QtMocHelpers::MethodData<void()>(21, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'fullscreenOn'
        QtMocHelpers::MethodData<void(QuickshellScreenInfo *)>(22, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Method 'setRectangle'
        QtMocHelpers::MethodData<void(QObject *, QRect)>(25, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 26 }, { 0x80000000 | 27, 28 },
        }}),
        // Method 'unsetRectangle'
        QtMocHelpers::MethodData<void()>(29, 8, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'appId'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'title'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'parent'
        QtMocHelpers::PropertyData<qs::wayland::toplevel_management::Toplevel*>(32, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'activated'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'screens'
        QtMocHelpers::PropertyData<QList<QuickshellScreenInfo*>>(35, 0x80000000 | 36, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'maximized'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'minimized'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'fullscreen'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<Toplevel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject qs::wayland::toplevel_management::Toplevel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland19toplevel_management8ToplevelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland19toplevel_management8ToplevelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7wayland19toplevel_management8ToplevelE_t>.metaTypes,
    nullptr
} };

void qs::wayland::toplevel_management::Toplevel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Toplevel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->closed(); break;
        case 1: _t->appIdChanged(); break;
        case 2: _t->titleChanged(); break;
        case 3: _t->parentChanged(); break;
        case 4: _t->activatedChanged(); break;
        case 5: _t->screensChanged(); break;
        case 6: _t->maximizedChanged(); break;
        case 7: _t->minimizedChanged(); break;
        case 8: _t->fullscreenChanged(); break;
        case 9: _t->onClosed(); break;
        case 10: _t->onRectangleProxyConnected(); break;
        case 11: _t->onRectangleProxyDestroyed(); break;
        case 12: _t->activate(); break;
        case 13: _t->close(); break;
        case 14: _t->fullscreenOn((*reinterpret_cast<std::add_pointer_t<QuickshellScreenInfo*>>(_a[1]))); break;
        case 15: _t->setRectangle((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRect>>(_a[2]))); break;
        case 16: _t->unsetRectangle(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QuickshellScreenInfo* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Toplevel::*)()>(_a, &Toplevel::closed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Toplevel::*)()>(_a, &Toplevel::appIdChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Toplevel::*)()>(_a, &Toplevel::titleChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Toplevel::*)()>(_a, &Toplevel::parentChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Toplevel::*)()>(_a, &Toplevel::activatedChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Toplevel::*)()>(_a, &Toplevel::screensChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Toplevel::*)()>(_a, &Toplevel::maximizedChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Toplevel::*)()>(_a, &Toplevel::minimizedChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Toplevel::*)()>(_a, &Toplevel::fullscreenChanged, 8))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QuickshellScreenInfo*> >(); break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< qs::wayland::toplevel_management::Toplevel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->appId(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 2: *reinterpret_cast<qs::wayland::toplevel_management::Toplevel**>(_v) = _t->parent(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->activated(); break;
        case 4: *reinterpret_cast<QList<QuickshellScreenInfo*>*>(_v) = _t->screens(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->maximized(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->minimized(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->fullscreen(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 5: _t->setMaximized(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setMinimized(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setFullscreen(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *qs::wayland::toplevel_management::Toplevel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::wayland::toplevel_management::Toplevel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland19toplevel_management8ToplevelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::wayland::toplevel_management::Toplevel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void qs::wayland::toplevel_management::Toplevel::closed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void qs::wayland::toplevel_management::Toplevel::appIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void qs::wayland::toplevel_management::Toplevel::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void qs::wayland::toplevel_management::Toplevel::parentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void qs::wayland::toplevel_management::Toplevel::activatedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void qs::wayland::toplevel_management::Toplevel::screensChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void qs::wayland::toplevel_management::Toplevel::maximizedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void qs::wayland::toplevel_management::Toplevel::minimizedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void qs::wayland::toplevel_management::Toplevel::fullscreenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
namespace {
struct qt_meta_tag_ZN2qs7wayland19toplevel_management15ToplevelManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::wayland::toplevel_management::ToplevelManager::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7wayland19toplevel_management15ToplevelManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::wayland::toplevel_management::ToplevelManager",
        "activeToplevelChanged",
        "",
        "onToplevelReady",
        "impl::ToplevelHandle*",
        "handle",
        "onToplevelActiveChanged",
        "onToplevelClosed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'activeToplevelChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onToplevelReady'
        QtMocHelpers::SlotData<void(impl::ToplevelHandle *)>(3, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'onToplevelActiveChanged'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onToplevelClosed'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ToplevelManager, qt_meta_tag_ZN2qs7wayland19toplevel_management15ToplevelManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qs::wayland::toplevel_management::ToplevelManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland19toplevel_management15ToplevelManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland19toplevel_management15ToplevelManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7wayland19toplevel_management15ToplevelManagerE_t>.metaTypes,
    nullptr
} };

void qs::wayland::toplevel_management::ToplevelManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ToplevelManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->activeToplevelChanged(); break;
        case 1: _t->onToplevelReady((*reinterpret_cast<std::add_pointer_t<impl::ToplevelHandle*>>(_a[1]))); break;
        case 2: _t->onToplevelActiveChanged(); break;
        case 3: _t->onToplevelClosed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ToplevelManager::*)()>(_a, &ToplevelManager::activeToplevelChanged, 0))
            return;
    }
}

const QMetaObject *qs::wayland::toplevel_management::ToplevelManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::wayland::toplevel_management::ToplevelManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland19toplevel_management15ToplevelManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::wayland::toplevel_management::ToplevelManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void qs::wayland::toplevel_management::ToplevelManager::activeToplevelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN2qs7wayland19toplevel_management18ToplevelManagerQmlE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::wayland::toplevel_management::ToplevelManagerQml::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7wayland19toplevel_management18ToplevelManagerQmlE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::wayland::toplevel_management::ToplevelManagerQml",
        "QML.Element",
        "ToplevelManager",
        "QML.Singleton",
        "true",
        "activeToplevelChanged",
        "",
        "toplevels",
        "UntypedObjectModel*",
        "activeToplevel",
        "qs::wayland::toplevel_management::Toplevel*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'activeToplevelChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'toplevels'
        QtMocHelpers::PropertyData<UntypedObjectModel*>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'activeToplevel'
        QtMocHelpers::PropertyData<qs::wayland::toplevel_management::Toplevel*>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<ToplevelManagerQml, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject qs::wayland::toplevel_management::ToplevelManagerQml::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland19toplevel_management18ToplevelManagerQmlE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland19toplevel_management18ToplevelManagerQmlE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7wayland19toplevel_management18ToplevelManagerQmlE_t>.metaTypes,
    nullptr
} };

void qs::wayland::toplevel_management::ToplevelManagerQml::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ToplevelManagerQml *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->activeToplevelChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ToplevelManagerQml::*)()>(_a, &ToplevelManagerQml::activeToplevelChanged, 0))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< UntypedObjectModel* >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< qs::wayland::toplevel_management::Toplevel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<UntypedObjectModel**>(_v) = _t->toplevels(); break;
        case 1: *reinterpret_cast<qs::wayland::toplevel_management::Toplevel**>(_v) = _t->activeToplevel(); break;
        default: break;
        }
    }
}

const QMetaObject *qs::wayland::toplevel_management::ToplevelManagerQml::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::wayland::toplevel_management::ToplevelManagerQml::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7wayland19toplevel_management18ToplevelManagerQmlE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::wayland::toplevel_management::ToplevelManagerQml::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void qs::wayland::toplevel_management::ToplevelManagerQml::activeToplevelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
