/****************************************************************************
** Meta object code from reading C++ file 'qml.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../src/x11/i3/ipc/qml.hpp"
#include <QtCore/qmetatype.h>
#include <QtCore/QProperty>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qml.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs2i33ipc8I3IpcQmlE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::i3::ipc::I3IpcQml::qt_create_metaobjectdata<qt_meta_tag_ZN2qs2i33ipc8I3IpcQmlE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::i3::ipc::I3IpcQml",
        "QML.Element",
        "I3",
        "QML.Singleton",
        "true",
        "rawEvent",
        "",
        "I3IpcEvent*",
        "event",
        "connected",
        "focusedWorkspaceChanged",
        "focusedMonitorChanged",
        "dispatch",
        "request",
        "refreshMonitors",
        "refreshWorkspaces",
        "findWorkspaceByName",
        "I3Workspace*",
        "name",
        "findMonitorByName",
        "I3Monitor*",
        "monitorFor",
        "QuickshellScreenInfo*",
        "screen",
        "socketPath",
        "focusedWorkspace",
        "qs::i3::ipc::I3Workspace*",
        "focusedMonitor",
        "qs::i3::ipc::I3Monitor*",
        "monitors",
        "UntypedObjectModel*",
        "workspaces"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'rawEvent'
        QtMocHelpers::SignalData<void(I3IpcEvent *)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'connected'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusedWorkspaceChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusedMonitorChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'dispatch'
        QtMocHelpers::MethodData<void(const QString &)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Method 'refreshMonitors'
        QtMocHelpers::MethodData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'refreshWorkspaces'
        QtMocHelpers::MethodData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'findWorkspaceByName'
        QtMocHelpers::MethodData<I3Workspace *(const QString &)>(16, 6, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::QString, 18 },
        }}),
        // Method 'findMonitorByName'
        QtMocHelpers::MethodData<I3Monitor *(const QString &)>(19, 6, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::QString, 18 },
        }}),
        // Method 'monitorFor'
        QtMocHelpers::MethodData<I3Monitor *(QuickshellScreenInfo *)>(21, 6, QMC::AccessPublic, 0x80000000 | 20, {{
            { 0x80000000 | 22, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'socketPath'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusedWorkspace'
        QtMocHelpers::PropertyData<qs::i3::ipc::I3Workspace*>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Bindable, 2),
        // property 'focusedMonitor'
        QtMocHelpers::PropertyData<qs::i3::ipc::I3Monitor*>(27, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Bindable, 3),
        // property 'monitors'
        QtMocHelpers::PropertyData<UntypedObjectModel*>(29, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'workspaces'
        QtMocHelpers::PropertyData<UntypedObjectModel*>(31, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<I3IpcQml, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject qs::i3::ipc::I3IpcQml::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs2i33ipc8I3IpcQmlE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs2i33ipc8I3IpcQmlE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs2i33ipc8I3IpcQmlE_t>.metaTypes,
    nullptr
} };

void qs::i3::ipc::I3IpcQml::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<I3IpcQml *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->rawEvent((*reinterpret_cast<std::add_pointer_t<I3IpcEvent*>>(_a[1]))); break;
        case 1: _t->connected(); break;
        case 2: _t->focusedWorkspaceChanged(); break;
        case 3: _t->focusedMonitorChanged(); break;
        case 4: _t->dispatch((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->refreshMonitors(); break;
        case 6: _t->refreshWorkspaces(); break;
        case 7: { I3Workspace* _r = _t->findWorkspaceByName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<I3Workspace**>(_a[0]) = std::move(_r); }  break;
        case 8: { I3Monitor* _r = _t->findMonitorByName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<I3Monitor**>(_a[0]) = std::move(_r); }  break;
        case 9: { I3Monitor* _r = _t->monitorFor((*reinterpret_cast<std::add_pointer_t<QuickshellScreenInfo*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<I3Monitor**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< I3IpcEvent* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QuickshellScreenInfo* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (I3IpcQml::*)(I3IpcEvent * )>(_a, &I3IpcQml::rawEvent, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (I3IpcQml::*)()>(_a, &I3IpcQml::connected, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (I3IpcQml::*)()>(_a, &I3IpcQml::focusedWorkspaceChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (I3IpcQml::*)()>(_a, &I3IpcQml::focusedMonitorChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< UntypedObjectModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->socketPath(); break;
        case 1: *reinterpret_cast<qs::i3::ipc::I3Workspace**>(_v) = _t->bindableFocusedWorkspace().value(); break;
        case 2: *reinterpret_cast<qs::i3::ipc::I3Monitor**>(_v) = _t->bindableFocusedMonitor().value(); break;
        case 3: *reinterpret_cast<UntypedObjectModel**>(_v) = _t->monitors(); break;
        case 4: *reinterpret_cast<UntypedObjectModel**>(_v) = _t->workspaces(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::BindableProperty) {
        switch (_id) {
        case 1: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableFocusedWorkspace(); break;
        case 2: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableFocusedMonitor(); break;
        default: break;
        }
    }
}

const QMetaObject *qs::i3::ipc::I3IpcQml::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::i3::ipc::I3IpcQml::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs2i33ipc8I3IpcQmlE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::i3::ipc::I3IpcQml::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void qs::i3::ipc::I3IpcQml::rawEvent(I3IpcEvent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void qs::i3::ipc::I3IpcQml::connected()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void qs::i3::ipc::I3IpcQml::focusedWorkspaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void qs::i3::ipc::I3IpcQml::focusedMonitorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
