/****************************************************************************
** Meta object code from reading C++ file 'dbus_nm_backend.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "dbus_nm_backend.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbus_nm_backend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23DBusNetworkManagerProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto DBusNetworkManagerProxy::qt_create_metaobjectdata<qt_meta_tag_ZN23DBusNetworkManagerProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DBusNetworkManagerProxy",
        "DeviceAdded",
        "",
        "QDBusObjectPath",
        "device_path",
        "DeviceRemoved",
        "ActivateConnection",
        "QDBusPendingReply<QDBusObjectPath>",
        "connection",
        "device",
        "specific_object",
        "AddAndActivateConnection",
        "QDBusPendingReply<QDBusObjectPath,QDBusObjectPath>",
        "qs::network::NMSettingsMap",
        "QDBusReply<QDBusObjectPath>",
        "QDBusObjectPath&",
        "active_connection",
        "CheckConnectivity",
        "QDBusPendingReply<uint>",
        "GetAllDevices",
        "QDBusPendingReply<QList<QDBusObjectPath>>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'DeviceAdded'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'DeviceRemoved'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'ActivateConnection'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QDBusObjectPath &, const QDBusObjectPath &, const QDBusObjectPath &)>(6, 2, QMC::AccessPublic, 0x80000000 | 7, {{
            { 0x80000000 | 3, 8 }, { 0x80000000 | 3, 9 }, { 0x80000000 | 3, 10 },
        }}),
        // Slot 'AddAndActivateConnection'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath,QDBusObjectPath>(qs::network::NMSettingsMap, const QDBusObjectPath &, const QDBusObjectPath &)>(11, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { 0x80000000 | 13, 8 }, { 0x80000000 | 3, 9 }, { 0x80000000 | 3, 10 },
        }}),
        // Slot 'AddAndActivateConnection'
        QtMocHelpers::SlotData<QDBusReply<QDBusObjectPath>(qs::network::NMSettingsMap, const QDBusObjectPath &, const QDBusObjectPath &, QDBusObjectPath &)>(11, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { 0x80000000 | 13, 8 }, { 0x80000000 | 3, 9 }, { 0x80000000 | 3, 10 }, { 0x80000000 | 15, 16 },
        }}),
        // Slot 'CheckConnectivity'
        QtMocHelpers::SlotData<QDBusPendingReply<uint>()>(17, 2, QMC::AccessPublic, 0x80000000 | 18),
        // Slot 'GetAllDevices'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QDBusObjectPath> >()>(19, 2, QMC::AccessPublic, 0x80000000 | 20),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DBusNetworkManagerProxy, qt_meta_tag_ZN23DBusNetworkManagerProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DBusNetworkManagerProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23DBusNetworkManagerProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23DBusNetworkManagerProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23DBusNetworkManagerProxyE_t>.metaTypes,
    nullptr
} };

void DBusNetworkManagerProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBusNetworkManagerProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->DeviceAdded((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 1: _t->DeviceRemoved((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 2: { QDBusPendingReply<QDBusObjectPath> _r = _t->ActivateConnection((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<QDBusObjectPath,QDBusObjectPath> _r = _t->AddAndActivateConnection((*reinterpret_cast<std::add_pointer_t<qs::network::NMSettingsMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath,QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusReply<QDBusObjectPath> _r = _t->AddAndActivateConnection((*reinterpret_cast<std::add_pointer_t<qs::network::NMSettingsMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath&>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<uint> _r = _t->CheckConnectivity();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<uint>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<QList<QDBusObjectPath>> _r = _t->GetAllDevices();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QDBusObjectPath>>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< qs::network::NMSettingsMap >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< qs::network::NMSettingsMap >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DBusNetworkManagerProxy::*)(const QDBusObjectPath & )>(_a, &DBusNetworkManagerProxy::DeviceAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusNetworkManagerProxy::*)(const QDBusObjectPath & )>(_a, &DBusNetworkManagerProxy::DeviceRemoved, 1))
            return;
    }
}

const QMetaObject *DBusNetworkManagerProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DBusNetworkManagerProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23DBusNetworkManagerProxyE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int DBusNetworkManagerProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void DBusNetworkManagerProxy::DeviceAdded(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DBusNetworkManagerProxy::DeviceRemoved(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
