/****************************************************************************
** Meta object code from reading C++ file 'monitor.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../src/x11/i3/ipc/monitor.hpp"
#include <QtCore/qmetatype.h>
#include <QtCore/QProperty>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'monitor.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs2i33ipc9I3MonitorE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::i3::ipc::I3Monitor::qt_create_metaobjectdata<qt_meta_tag_ZN2qs2i33ipc9I3MonitorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::i3::ipc::I3Monitor",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "I3Monitors must be retrieved from the I3IpcController object.",
        "idChanged",
        "",
        "nameChanged",
        "powerChanged",
        "activeWorkspaceChanged",
        "xChanged",
        "yChanged",
        "widthChanged",
        "heightChanged",
        "scaleChanged",
        "lastIpcObjectChanged",
        "focusedChanged",
        "onActiveWorkspaceDestroyed",
        "id",
        "name",
        "power",
        "activeWorkspace",
        "qs::i3::ipc::I3Workspace*",
        "focusedWorkspace",
        "x",
        "y",
        "width",
        "height",
        "scale",
        "focused",
        "lastIpcObject",
        "QVariantMap"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'idChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'powerChanged'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeWorkspaceChanged'
        QtMocHelpers::SignalData<void()>(11, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'xChanged'
        QtMocHelpers::SignalData<void()>(12, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'yChanged'
        QtMocHelpers::SignalData<void()>(13, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'widthChanged'
        QtMocHelpers::SignalData<void()>(14, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'heightChanged'
        QtMocHelpers::SignalData<void()>(15, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scaleChanged'
        QtMocHelpers::SignalData<void()>(16, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastIpcObjectChanged'
        QtMocHelpers::SignalData<void()>(17, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusedChanged'
        QtMocHelpers::SignalData<void()>(18, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onActiveWorkspaceDestroyed'
        QtMocHelpers::SlotData<void()>(19, 8, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'id'
        QtMocHelpers::PropertyData<qint32>(20, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Bindable, 0),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Bindable, 1),
        // property 'power'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 2),
        // property 'activeWorkspace'
        QtMocHelpers::PropertyData<qs::i3::ipc::I3Workspace*>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Bindable, 3),
        // property 'focusedWorkspace'
        QtMocHelpers::PropertyData<qs::i3::ipc::I3Workspace*>(25, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Bindable, 3),
        // property 'x'
        QtMocHelpers::PropertyData<qint32>(26, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Bindable, 4),
        // property 'y'
        QtMocHelpers::PropertyData<qint32>(27, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Bindable, 5),
        // property 'width'
        QtMocHelpers::PropertyData<qint32>(28, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Bindable, 6),
        // property 'height'
        QtMocHelpers::PropertyData<qint32>(29, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Bindable, 7),
        // property 'scale'
        QtMocHelpers::PropertyData<qreal>(30, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Bindable, 8),
        // property 'focused'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 10),
        // property 'lastIpcObject'
        QtMocHelpers::PropertyData<QVariantMap>(32, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 9),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<I3Monitor, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject qs::i3::ipc::I3Monitor::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs2i33ipc9I3MonitorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs2i33ipc9I3MonitorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs2i33ipc9I3MonitorE_t>.metaTypes,
    nullptr
} };

void qs::i3::ipc::I3Monitor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<I3Monitor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->idChanged(); break;
        case 1: _t->nameChanged(); break;
        case 2: _t->powerChanged(); break;
        case 3: _t->activeWorkspaceChanged(); break;
        case 4: _t->xChanged(); break;
        case 5: _t->yChanged(); break;
        case 6: _t->widthChanged(); break;
        case 7: _t->heightChanged(); break;
        case 8: _t->scaleChanged(); break;
        case 9: _t->lastIpcObjectChanged(); break;
        case 10: _t->focusedChanged(); break;
        case 11: _t->onActiveWorkspaceDestroyed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (I3Monitor::*)()>(_a, &I3Monitor::idChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (I3Monitor::*)()>(_a, &I3Monitor::nameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (I3Monitor::*)()>(_a, &I3Monitor::powerChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (I3Monitor::*)()>(_a, &I3Monitor::activeWorkspaceChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (I3Monitor::*)()>(_a, &I3Monitor::xChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (I3Monitor::*)()>(_a, &I3Monitor::yChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (I3Monitor::*)()>(_a, &I3Monitor::widthChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (I3Monitor::*)()>(_a, &I3Monitor::heightChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (I3Monitor::*)()>(_a, &I3Monitor::scaleChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (I3Monitor::*)()>(_a, &I3Monitor::lastIpcObjectChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (I3Monitor::*)()>(_a, &I3Monitor::focusedChanged, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qint32*>(_v) = _t->bindableId().value(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->bindableName().value(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->bindablePower().value(); break;
        case 3: *reinterpret_cast<qs::i3::ipc::I3Workspace**>(_v) = _t->bindableActiveWorkspace().value(); break;
        case 4: *reinterpret_cast<qs::i3::ipc::I3Workspace**>(_v) = _t->bindableActiveWorkspace().value(); break;
        case 5: *reinterpret_cast<qint32*>(_v) = _t->bindableX().value(); break;
        case 6: *reinterpret_cast<qint32*>(_v) = _t->bindableY().value(); break;
        case 7: *reinterpret_cast<qint32*>(_v) = _t->bindableWidth().value(); break;
        case 8: *reinterpret_cast<qint32*>(_v) = _t->bindableHeight().value(); break;
        case 9: *reinterpret_cast<qreal*>(_v) = _t->bindableScale().value(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->bindableFocused().value(); break;
        case 11: *reinterpret_cast<QVariantMap*>(_v) = _t->lastIpcObject(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::BindableProperty) {
        switch (_id) {
        case 0: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableId(); break;
        case 1: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableName(); break;
        case 2: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindablePower(); break;
        case 3: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableActiveWorkspace(); break;
        case 4: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableActiveWorkspace(); break;
        case 5: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableX(); break;
        case 6: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableY(); break;
        case 7: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableWidth(); break;
        case 8: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableHeight(); break;
        case 9: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableScale(); break;
        case 10: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableFocused(); break;
        default: break;
        }
    }
}

const QMetaObject *qs::i3::ipc::I3Monitor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::i3::ipc::I3Monitor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs2i33ipc9I3MonitorE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::i3::ipc::I3Monitor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void qs::i3::ipc::I3Monitor::idChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void qs::i3::ipc::I3Monitor::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void qs::i3::ipc::I3Monitor::powerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void qs::i3::ipc::I3Monitor::activeWorkspaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void qs::i3::ipc::I3Monitor::xChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void qs::i3::ipc::I3Monitor::yChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void qs::i3::ipc::I3Monitor::widthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void qs::i3::ipc::I3Monitor::heightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void qs::i3::ipc::I3Monitor::scaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void qs::i3::ipc::I3Monitor::lastIpcObjectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void qs::i3::ipc::I3Monitor::focusedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
