/****************************************************************************
** Meta object code from reading C++ file 'dbus_menu.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "dbus_menu.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbus_menu.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17DBusMenuInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto DBusMenuInterface::qt_create_metaobjectdata<qt_meta_tag_ZN17DBusMenuInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DBusMenuInterface",
        "ItemActivationRequested",
        "",
        "id",
        "timestamp",
        "ItemsPropertiesUpdated",
        "DBusMenuItemPropertiesList",
        "updatedProps",
        "DBusMenuItemPropertyNamesList",
        "removedProps",
        "LayoutUpdated",
        "revision",
        "parent",
        "AboutToShow",
        "QDBusPendingReply<bool>",
        "AboutToShowGroup",
        "QDBusPendingReply<DBusMenuIdList,DBusMenuIdList>",
        "DBusMenuIdList",
        "ids",
        "QDBusReply<DBusMenuIdList>",
        "DBusMenuIdList&",
        "idErrors",
        "Event",
        "QDBusPendingReply<>",
        "eventId",
        "QDBusVariant",
        "data",
        "GetGroupProperties",
        "QDBusPendingReply<DBusMenuItemPropertiesList>",
        "propertyNames",
        "GetLayout",
        "QDBusPendingReply<uint,DBusMenuLayout>",
        "parentId",
        "recursionDepth",
        "QDBusReply<uint>",
        "DBusMenuLayout&",
        "layout",
        "GetProperty",
        "QDBusPendingReply<QDBusVariant>",
        "name",
        "IconThemePath",
        "Status",
        "TextDirection",
        "Version"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ItemActivationRequested'
        QtMocHelpers::SignalData<void(int, uint)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'ItemsPropertiesUpdated'
        QtMocHelpers::SignalData<void(DBusMenuItemPropertiesList, DBusMenuItemPropertyNamesList)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Signal 'LayoutUpdated'
        QtMocHelpers::SignalData<void(uint, int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 11 }, { QMetaType::Int, 12 },
        }}),
        // Slot 'AboutToShow'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(int)>(13, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'AboutToShowGroup'
        QtMocHelpers::SlotData<QDBusPendingReply<DBusMenuIdList,DBusMenuIdList>(DBusMenuIdList)>(15, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'AboutToShowGroup'
        QtMocHelpers::SlotData<QDBusReply<DBusMenuIdList>(DBusMenuIdList, DBusMenuIdList &)>(15, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { 0x80000000 | 17, 18 }, { 0x80000000 | 20, 21 },
        }}),
        // Slot 'Event'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int, const QString &, const QDBusVariant &, uint)>(22, 2, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::Int, 3 }, { QMetaType::QString, 24 }, { 0x80000000 | 25, 26 }, { QMetaType::UInt, 4 },
        }}),
        // Slot 'GetGroupProperties'
        QtMocHelpers::SlotData<QDBusPendingReply<DBusMenuItemPropertiesList>(DBusMenuIdList, const QStringList &)>(27, 2, QMC::AccessPublic, 0x80000000 | 28, {{
            { 0x80000000 | 17, 18 }, { QMetaType::QStringList, 29 },
        }}),
        // Slot 'GetLayout'
        QtMocHelpers::SlotData<QDBusPendingReply<uint,DBusMenuLayout>(int, int, const QStringList &)>(30, 2, QMC::AccessPublic, 0x80000000 | 31, {{
            { QMetaType::Int, 32 }, { QMetaType::Int, 33 }, { QMetaType::QStringList, 29 },
        }}),
        // Slot 'GetLayout'
        QtMocHelpers::SlotData<QDBusReply<uint>(int, int, const QStringList &, DBusMenuLayout &)>(30, 2, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::Int, 32 }, { QMetaType::Int, 33 }, { QMetaType::QStringList, 29 }, { 0x80000000 | 35, 36 },
        }}),
        // Slot 'GetProperty'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusVariant>(int, const QString &)>(37, 2, QMC::AccessPublic, 0x80000000 | 38, {{
            { QMetaType::Int, 3 }, { QMetaType::QString, 39 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'IconThemePath'
        QtMocHelpers::PropertyData<QStringList>(40, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'Status'
        QtMocHelpers::PropertyData<QString>(41, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'TextDirection'
        QtMocHelpers::PropertyData<QString>(42, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Version'
        QtMocHelpers::PropertyData<uint>(43, QMetaType::UInt, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DBusMenuInterface, qt_meta_tag_ZN17DBusMenuInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DBusMenuInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DBusMenuInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DBusMenuInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17DBusMenuInterfaceE_t>.metaTypes,
    nullptr
} };

void DBusMenuInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBusMenuInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ItemActivationRequested((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 1: _t->ItemsPropertiesUpdated((*reinterpret_cast<std::add_pointer_t<DBusMenuItemPropertiesList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<DBusMenuItemPropertyNamesList>>(_a[2]))); break;
        case 2: _t->LayoutUpdated((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: { QDBusPendingReply<bool> _r = _t->AboutToShow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<DBusMenuIdList,DBusMenuIdList> _r = _t->AboutToShowGroup((*reinterpret_cast<std::add_pointer_t<DBusMenuIdList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<DBusMenuIdList,DBusMenuIdList>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusReply<DBusMenuIdList> _r = _t->AboutToShowGroup((*reinterpret_cast<std::add_pointer_t<DBusMenuIdList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<DBusMenuIdList&>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusReply<DBusMenuIdList>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<> _r = _t->Event((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<DBusMenuItemPropertiesList> _r = _t->GetGroupProperties((*reinterpret_cast<std::add_pointer_t<DBusMenuIdList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<DBusMenuItemPropertiesList>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<uint,DBusMenuLayout> _r = _t->GetLayout((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<uint,DBusMenuLayout>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusReply<uint> _r = _t->GetLayout((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<DBusMenuLayout&>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusReply<uint>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<QDBusVariant> _r = _t->GetProperty((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusVariant>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DBusMenuItemPropertiesList >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DBusMenuItemPropertyNamesList >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DBusMenuIdList >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DBusMenuIdList >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DBusMenuIdList >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DBusMenuInterface::*)(int , uint )>(_a, &DBusMenuInterface::ItemActivationRequested, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusMenuInterface::*)(DBusMenuItemPropertiesList , DBusMenuItemPropertyNamesList )>(_a, &DBusMenuInterface::ItemsPropertiesUpdated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusMenuInterface::*)(uint , int )>(_a, &DBusMenuInterface::LayoutUpdated, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->iconThemePath(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->status(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->textDirection(); break;
        case 3: *reinterpret_cast<uint*>(_v) = _t->version(); break;
        default: break;
        }
    }
}

const QMetaObject *DBusMenuInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DBusMenuInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DBusMenuInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int DBusMenuInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void DBusMenuInterface::ItemActivationRequested(int _t1, uint _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void DBusMenuInterface::ItemsPropertiesUpdated(DBusMenuItemPropertiesList _t1, DBusMenuItemPropertyNamesList _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void DBusMenuInterface::LayoutUpdated(uint _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}
QT_WARNING_POP
