/****************************************************************************
** Meta object code from reading C++ file 'dbus_nm_connection_settings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "dbus_nm_connection_settings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbus_nm_connection_settings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN29DBusNMConnectionSettingsProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto DBusNMConnectionSettingsProxy::qt_create_metaobjectdata<qt_meta_tag_ZN29DBusNMConnectionSettingsProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DBusNMConnectionSettingsProxy",
        "Removed",
        "",
        "Updated",
        "ClearSecrets",
        "QDBusPendingReply<>",
        "Delete",
        "GetSecrets",
        "QDBusPendingReply<qs::network::NMSettingsMap>",
        "setting_name",
        "GetSettings",
        "Update",
        "qs::network::NMSettingsMap",
        "properties"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Removed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'Updated'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ClearSecrets'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(4, 2, QMC::AccessPublic, 0x80000000 | 5),
        // Slot 'Delete'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(6, 2, QMC::AccessPublic, 0x80000000 | 5),
        // Slot 'GetSecrets'
        QtMocHelpers::SlotData<QDBusPendingReply<qs::network::NMSettingsMap>(const QString &)>(7, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'GetSettings'
        QtMocHelpers::SlotData<QDBusPendingReply<qs::network::NMSettingsMap>()>(10, 2, QMC::AccessPublic, 0x80000000 | 8),
        // Slot 'Update'
        QtMocHelpers::SlotData<QDBusPendingReply<>(qs::network::NMSettingsMap)>(11, 2, QMC::AccessPublic, 0x80000000 | 5, {{
            { 0x80000000 | 12, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DBusNMConnectionSettingsProxy, qt_meta_tag_ZN29DBusNMConnectionSettingsProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DBusNMConnectionSettingsProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29DBusNMConnectionSettingsProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29DBusNMConnectionSettingsProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29DBusNMConnectionSettingsProxyE_t>.metaTypes,
    nullptr
} };

void DBusNMConnectionSettingsProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBusNMConnectionSettingsProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Removed(); break;
        case 1: _t->Updated(); break;
        case 2: { QDBusPendingReply<> _r = _t->ClearSecrets();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<> _r = _t->Delete();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<qs::network::NMSettingsMap> _r = _t->GetSecrets((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<qs::network::NMSettingsMap>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<qs::network::NMSettingsMap> _r = _t->GetSettings();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<qs::network::NMSettingsMap>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<> _r = _t->Update((*reinterpret_cast<std::add_pointer_t<qs::network::NMSettingsMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< qs::network::NMSettingsMap >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DBusNMConnectionSettingsProxy::*)()>(_a, &DBusNMConnectionSettingsProxy::Removed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusNMConnectionSettingsProxy::*)()>(_a, &DBusNMConnectionSettingsProxy::Updated, 1))
            return;
    }
}

const QMetaObject *DBusNMConnectionSettingsProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DBusNMConnectionSettingsProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29DBusNMConnectionSettingsProxyE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int DBusNMConnectionSettingsProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void DBusNMConnectionSettingsProxy::Removed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DBusNMConnectionSettingsProxy::Updated()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
