/****************************************************************************
** Meta object code from reading C++ file 'wireless.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/network/nm/wireless.hpp"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'wireless.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs7network16NMWirelessDeviceE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::network::NMWirelessDevice::qt_create_metaobjectdata<qt_meta_tag_ZN2qs7network16NMWirelessDeviceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::network::NMWirelessDevice",
        "accessPointLoaded",
        "",
        "NMAccessPoint*",
        "ap",
        "accessPointRemoved",
        "lastScanChanged",
        "lastScan",
        "scanningChanged",
        "scanning",
        "capabilitiesChanged",
        "NMWirelessCapabilities::Enum",
        "caps",
        "activeAccessPointChanged",
        "QDBusObjectPath",
        "path",
        "modeChanged",
        "NM80211Mode::Enum",
        "mode",
        "onAccessPointAdded",
        "onAccessPointRemoved",
        "onAccessPointLoaded",
        "onSettingsLoaded",
        "NMSettings*",
        "settings",
        "onActiveConnectionLoaded",
        "NMActiveConnection*",
        "active",
        "onScanTimeout",
        "onScanningChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'accessPointLoaded'
        QtMocHelpers::SignalData<void(NMAccessPoint *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'accessPointRemoved'
        QtMocHelpers::SignalData<void(NMAccessPoint *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'lastScanChanged'
        QtMocHelpers::SignalData<void(QDateTime)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDateTime, 7 },
        }}),
        // Signal 'scanningChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Signal 'capabilitiesChanged'
        QtMocHelpers::SignalData<void(NMWirelessCapabilities::Enum)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'activeAccessPointChanged'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Signal 'modeChanged'
        QtMocHelpers::SignalData<void(NM80211Mode::Enum)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'onAccessPointAdded'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'onAccessPointRemoved'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'onAccessPointLoaded'
        QtMocHelpers::SlotData<void(NMAccessPoint *)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'onSettingsLoaded'
        QtMocHelpers::SlotData<void(NMSettings *)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'onActiveConnectionLoaded'
        QtMocHelpers::SlotData<void(NMActiveConnection *)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'onScanTimeout'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onScanningChanged'
        QtMocHelpers::SlotData<void(bool)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NMWirelessDevice, qt_meta_tag_ZN2qs7network16NMWirelessDeviceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qs::network::NMWirelessDevice::staticMetaObject = { {
    QMetaObject::SuperData::link<NMDevice::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network16NMWirelessDeviceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network16NMWirelessDeviceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs7network16NMWirelessDeviceE_t>.metaTypes,
    nullptr
} };

void qs::network::NMWirelessDevice::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NMWirelessDevice *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->accessPointLoaded((*reinterpret_cast<std::add_pointer_t<NMAccessPoint*>>(_a[1]))); break;
        case 1: _t->accessPointRemoved((*reinterpret_cast<std::add_pointer_t<NMAccessPoint*>>(_a[1]))); break;
        case 2: _t->lastScanChanged((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1]))); break;
        case 3: _t->scanningChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->capabilitiesChanged((*reinterpret_cast<std::add_pointer_t<NMWirelessCapabilities::Enum>>(_a[1]))); break;
        case 5: _t->activeAccessPointChanged((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 6: _t->modeChanged((*reinterpret_cast<std::add_pointer_t<NM80211Mode::Enum>>(_a[1]))); break;
        case 7: _t->onAccessPointAdded((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 8: _t->onAccessPointRemoved((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 9: _t->onAccessPointLoaded((*reinterpret_cast<std::add_pointer_t<NMAccessPoint*>>(_a[1]))); break;
        case 10: _t->onSettingsLoaded((*reinterpret_cast<std::add_pointer_t<NMSettings*>>(_a[1]))); break;
        case 11: _t->onActiveConnectionLoaded((*reinterpret_cast<std::add_pointer_t<NMActiveConnection*>>(_a[1]))); break;
        case 12: _t->onScanTimeout(); break;
        case 13: _t->onScanningChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< NMAccessPoint* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< NMAccessPoint* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< NMAccessPoint* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< NMSettings* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< NMActiveConnection* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NMWirelessDevice::*)(NMAccessPoint * )>(_a, &NMWirelessDevice::accessPointLoaded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMWirelessDevice::*)(NMAccessPoint * )>(_a, &NMWirelessDevice::accessPointRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMWirelessDevice::*)(QDateTime )>(_a, &NMWirelessDevice::lastScanChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMWirelessDevice::*)(bool )>(_a, &NMWirelessDevice::scanningChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMWirelessDevice::*)(NMWirelessCapabilities::Enum )>(_a, &NMWirelessDevice::capabilitiesChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMWirelessDevice::*)(const QDBusObjectPath & )>(_a, &NMWirelessDevice::activeAccessPointChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (NMWirelessDevice::*)(NM80211Mode::Enum )>(_a, &NMWirelessDevice::modeChanged, 6))
            return;
    }
}

const QMetaObject *qs::network::NMWirelessDevice::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::network::NMWirelessDevice::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs7network16NMWirelessDeviceE_t>.strings))
        return static_cast<void*>(this);
    return NMDevice::qt_metacast(_clname);
}

int qs::network::NMWirelessDevice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NMDevice::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void qs::network::NMWirelessDevice::accessPointLoaded(NMAccessPoint * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void qs::network::NMWirelessDevice::accessPointRemoved(NMAccessPoint * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void qs::network::NMWirelessDevice::lastScanChanged(QDateTime _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void qs::network::NMWirelessDevice::scanningChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void qs::network::NMWirelessDevice::capabilitiesChanged(NMWirelessCapabilities::Enum _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void qs::network::NMWirelessDevice::activeAccessPointChanged(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void qs::network::NMWirelessDevice::modeChanged(NM80211Mode::Enum _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
