/****************************************************************************
** Meta object code from reading C++ file 'session_lock.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../src/wayland/session_lock.hpp"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'session_lock.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13WlSessionLockE_t {};
} // unnamed namespace

template <> constexpr inline auto WlSessionLock::qt_create_metaobjectdata<qt_meta_tag_ZN13WlSessionLockE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WlSessionLock",
        "QML.Element",
        "auto",
        "DefaultProperty",
        "surface",
        "lockStateChanged",
        "",
        "secureStateChanged",
        "surfaceComponentChanged",
        "unlock",
        "onScreensChanged",
        "locked",
        "secure",
        "QQmlComponent*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'lockStateChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'secureStateChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'surfaceComponentChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'unlock'
        QtMocHelpers::SlotData<void()>(9, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onScreensChanged'
        QtMocHelpers::SlotData<void()>(10, 6, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'locked'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'secure'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'surface'
        QtMocHelpers::PropertyData<QQmlComponent*>(4, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<WlSessionLock, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject WlSessionLock::staticMetaObject = { {
    QMetaObject::SuperData::link<Reloadable::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13WlSessionLockE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13WlSessionLockE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13WlSessionLockE_t>.metaTypes,
    nullptr
} };

void WlSessionLock::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WlSessionLock *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->lockStateChanged(); break;
        case 1: _t->secureStateChanged(); break;
        case 2: _t->surfaceComponentChanged(); break;
        case 3: _t->unlock(); break;
        case 4: _t->onScreensChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WlSessionLock::*)()>(_a, &WlSessionLock::lockStateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WlSessionLock::*)()>(_a, &WlSessionLock::secureStateChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WlSessionLock::*)()>(_a, &WlSessionLock::surfaceComponentChanged, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlComponent* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isLocked(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isSecure(); break;
        case 2: *reinterpret_cast<QQmlComponent**>(_v) = _t->surfaceComponent(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLocked(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setSurfaceComponent(*reinterpret_cast<QQmlComponent**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *WlSessionLock::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WlSessionLock::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13WlSessionLockE_t>.strings))
        return static_cast<void*>(this);
    return Reloadable::qt_metacast(_clname);
}

int WlSessionLock::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Reloadable::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void WlSessionLock::lockStateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void WlSessionLock::secureStateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void WlSessionLock::surfaceComponentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
namespace {
struct qt_meta_tag_ZN20WlSessionLockSurfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto WlSessionLockSurface::qt_create_metaobjectdata<qt_meta_tag_ZN20WlSessionLockSurfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WlSessionLockSurface",
        "QML.Element",
        "DefaultProperty",
        "data",
        "visibleChanged",
        "",
        "widthChanged",
        "heightChanged",
        "screenChanged",
        "colorChanged",
        "onScreenDestroyed",
        "onWidthChanged",
        "onHeightChanged",
        "contentItem",
        "QQuickItem*",
        "visible",
        "width",
        "height",
        "screen",
        "QuickshellScreenInfo*",
        "color",
        "QColor",
        "QQmlListProperty<QObject>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'visibleChanged'
        QtMocHelpers::SignalData<void()>(4, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'widthChanged'
        QtMocHelpers::SignalData<void()>(6, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'heightChanged'
        QtMocHelpers::SignalData<void()>(7, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'screenChanged'
        QtMocHelpers::SignalData<void()>(8, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorChanged'
        QtMocHelpers::SignalData<void()>(9, 5, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onScreenDestroyed'
        QtMocHelpers::SlotData<void()>(10, 5, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onWidthChanged'
        QtMocHelpers::SlotData<void()>(11, 5, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onHeightChanged'
        QtMocHelpers::SlotData<void()>(12, 5, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'contentItem'
        QtMocHelpers::PropertyData<QQuickItem*>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'visible'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'width'
        QtMocHelpers::PropertyData<qint32>(16, QMetaType::Int, QMC::DefaultPropertyFlags, 1),
        // property 'height'
        QtMocHelpers::PropertyData<qint32>(17, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'screen'
        QtMocHelpers::PropertyData<QuickshellScreenInfo*>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'color'
        QtMocHelpers::PropertyData<QColor>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'data'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(3, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    0 },
            {    2,    3 },
    });
    return QtMocHelpers::metaObjectData<WlSessionLockSurface, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject WlSessionLockSurface::staticMetaObject = { {
    QMetaObject::SuperData::link<Reloadable::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20WlSessionLockSurfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20WlSessionLockSurfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20WlSessionLockSurfaceE_t>.metaTypes,
    nullptr
} };

void WlSessionLockSurface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WlSessionLockSurface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->visibleChanged(); break;
        case 1: _t->widthChanged(); break;
        case 2: _t->heightChanged(); break;
        case 3: _t->screenChanged(); break;
        case 4: _t->colorChanged(); break;
        case 5: _t->onScreenDestroyed(); break;
        case 6: _t->onWidthChanged(); break;
        case 7: _t->onHeightChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WlSessionLockSurface::*)()>(_a, &WlSessionLockSurface::visibleChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WlSessionLockSurface::*)()>(_a, &WlSessionLockSurface::widthChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WlSessionLockSurface::*)()>(_a, &WlSessionLockSurface::heightChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (WlSessionLockSurface::*)()>(_a, &WlSessionLockSurface::screenChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (WlSessionLockSurface::*)()>(_a, &WlSessionLockSurface::colorChanged, 4))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QuickshellScreenInfo* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuickItem**>(_v) = _t->contentItem(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isVisible(); break;
        case 2: *reinterpret_cast<qint32*>(_v) = _t->width(); break;
        case 3: *reinterpret_cast<qint32*>(_v) = _t->height(); break;
        case 4: *reinterpret_cast<QuickshellScreenInfo**>(_v) = _t->screen(); break;
        case 5: *reinterpret_cast<QColor*>(_v) = _t->color(); break;
        case 6: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->data(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 5: _t->setColor(*reinterpret_cast<QColor*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *WlSessionLockSurface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WlSessionLockSurface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20WlSessionLockSurfaceE_t>.strings))
        return static_cast<void*>(this);
    return Reloadable::qt_metacast(_clname);
}

int WlSessionLockSurface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Reloadable::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void WlSessionLockSurface::visibleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void WlSessionLockSurface::widthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void WlSessionLockSurface::heightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void WlSessionLockSurface::screenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void WlSessionLockSurface::colorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
