// /qt/qml/Quickshell/Widgets/ClippingWrapperRectangle.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <type_traits>
namespace QmlCacheGeneratedCode {
namespace _qt_qml_Quickshell_Widgets_ClippingWrapperRectangle_qml {
extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x4a,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x50,0x8,0x0,0x0,0x73,0x85,0xf5,0x91,
0xa7,0x5c,0xc,0x58,0xb0,0x6,0x4f,0x8d,
0x86,0x3b,0x86,0xe6,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0xf8,0x1,0x0,0x0,
0x2,0x0,0x0,0x0,0xc8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd0,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0xd0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x1,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd8,0x5,0x0,0x0,
0x18,0x1,0x0,0x0,0x88,0x1,0x0,0x0,
0x33,0x0,0x0,0x0,0x60,0x1,0x0,0x0,
0xc0,0x0,0x0,0x0,0x33,0x0,0x0,0x0,
0x70,0x1,0x0,0x0,0x33,0x0,0x0,0x0,
0xf0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x33,0x0,0x0,0x0,0x60,0x1,0x0,0x0,
0xd0,0x0,0x0,0x0,0x33,0x0,0x0,0x0,
0x70,0x1,0x0,0x0,0x33,0x0,0x0,0x0,
0xf0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x40,0xf5,0x7f,
0x44,0x0,0x0,0x0,0x22,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x9,0x0,0x0,0x0,
0x3b,0x0,0x20,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x3b,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x0,0x3c,0x1,
0x3c,0x2,0x18,0x7,0x2e,0x3,0x3c,0x4,
0x50,0xe,0x2e,0x5,0x3c,0x6,0x3c,0x7,
0x18,0x8,0x10,0x2,0x9c,0x8,0x4c,0x1,
0x6,0x80,0x7,0x18,0x6,0x2,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x22,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x9,0x0,0x0,0x0,
0x3c,0x0,0x20,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x3c,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x8,0x3c,0x9,
0x3c,0xa,0x18,0x7,0x2e,0xb,0x3c,0xc,
0x50,0xe,0x2e,0xd,0x3c,0xe,0x3c,0xf,
0x18,0x8,0x10,0x2,0x9c,0x8,0x4c,0x1,
0x6,0x80,0x7,0x18,0x6,0x2,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x58,0x2,0x0,0x0,0x60,0x2,0x0,0x0,
0x78,0x2,0x0,0x0,0xc0,0x2,0x0,0x0,
0xd0,0x2,0x0,0x0,0xe8,0x2,0x0,0x0,
0x0,0x3,0x0,0x0,0x20,0x3,0x0,0x0,
0x38,0x3,0x0,0x0,0x58,0x3,0x0,0x0,
0x78,0x3,0x0,0x0,0x98,0x3,0x0,0x0,
0xb8,0x3,0x0,0x0,0xd8,0x3,0x0,0x0,
0x0,0x4,0x0,0x0,0x10,0x4,0x0,0x0,
0x28,0x4,0x0,0x0,0x38,0x4,0x0,0x0,
0x70,0x4,0x0,0x0,0xc8,0x4,0x0,0x0,
0x0,0x5,0x0,0x0,0x58,0x5,0x0,0x0,
0x88,0x5,0x0,0x0,0xa8,0x5,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x20,0x0,0x0,0x0,0x43,0x0,0x6c,0x0,
0x69,0x0,0x70,0x0,0x70,0x0,0x69,0x0,
0x6e,0x0,0x67,0x0,0x57,0x0,0x72,0x0,
0x61,0x0,0x70,0x0,0x70,0x0,0x65,0x0,
0x72,0x0,0x52,0x0,0x65,0x0,0x63,0x0,
0x74,0x0,0x61,0x0,0x6e,0x0,0x67,0x0,
0x6c,0x0,0x65,0x0,0x49,0x0,0x6e,0x0,
0x74,0x0,0x65,0x0,0x72,0x0,0x6e,0x0,
0x61,0x0,0x6c,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x72,0x0,0x6f,0x0,
0x6f,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x6d,0x0,0x61,0x0,
0x72,0x0,0x67,0x0,0x69,0x0,0x6e,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x6d,0x0,0x61,0x0,
0x6e,0x0,0x61,0x0,0x67,0x0,0x65,0x0,
0x72,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x74,0x0,0x72,0x0,0x61,0x0,0x4d,0x0,
0x61,0x0,0x72,0x0,0x67,0x0,0x69,0x0,
0x6e,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x74,0x0,0x6f,0x0,
0x70,0x0,0x4d,0x0,0x61,0x0,0x72,0x0,
0x67,0x0,0x69,0x0,0x6e,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x62,0x0,0x6f,0x0,
0x74,0x0,0x74,0x0,0x6f,0x0,0x6d,0x0,
0x4d,0x0,0x61,0x0,0x72,0x0,0x67,0x0,
0x69,0x0,0x6e,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x6c,0x0,0x65,0x0,
0x66,0x0,0x74,0x0,0x4d,0x0,0x61,0x0,
0x72,0x0,0x67,0x0,0x69,0x0,0x6e,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x72,0x0,0x69,0x0,
0x67,0x0,0x68,0x0,0x74,0x0,0x4d,0x0,
0x61,0x0,0x72,0x0,0x67,0x0,0x69,0x0,
0x6e,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x72,0x0,0x65,0x0,
0x73,0x0,0x69,0x0,0x7a,0x0,0x65,0x0,
0x43,0x0,0x68,0x0,0x69,0x0,0x6c,0x0,
0x64,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x69,0x0,0x6d,0x0,
0x70,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,
0x69,0x0,0x74,0x0,0x57,0x0,0x69,0x0,
0x64,0x0,0x74,0x0,0x68,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x69,0x0,0x6d,0x0,
0x70,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,
0x69,0x0,0x74,0x0,0x48,0x0,0x65,0x0,
0x69,0x0,0x67,0x0,0x68,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x63,0x0,0x68,0x0,
0x69,0x0,0x6c,0x0,0x64,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x62,0x0,0x6f,0x0,
0x72,0x0,0x64,0x0,0x65,0x0,0x72,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x77,0x0,0x69,0x0,
0x64,0x0,0x74,0x0,0x68,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0x5f,0x0,0x5f,0x0,
0x69,0x0,0x6d,0x0,0x70,0x0,0x6c,0x0,
0x69,0x0,0x63,0x0,0x69,0x0,0x74,0x0,
0x57,0x0,0x69,0x0,0x64,0x0,0x74,0x0,
0x68,0x0,0x49,0x0,0x6e,0x0,0x74,0x0,
0x65,0x0,0x72,0x0,0x6e,0x0,0x61,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x26,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x5f,0x0,0x5f,0x0,0x69,0x0,
0x6d,0x0,0x70,0x0,0x6c,0x0,0x69,0x0,
0x63,0x0,0x69,0x0,0x74,0x0,0x57,0x0,
0x69,0x0,0x64,0x0,0x74,0x0,0x68,0x0,
0x49,0x0,0x6e,0x0,0x74,0x0,0x65,0x0,
0x72,0x0,0x6e,0x0,0x61,0x0,0x6c,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x5f,0x0,0x5f,0x0,
0x69,0x0,0x6d,0x0,0x70,0x0,0x6c,0x0,
0x69,0x0,0x63,0x0,0x69,0x0,0x74,0x0,
0x48,0x0,0x65,0x0,0x69,0x0,0x67,0x0,
0x68,0x0,0x74,0x0,0x49,0x0,0x6e,0x0,
0x74,0x0,0x65,0x0,0x72,0x0,0x6e,0x0,
0x61,0x0,0x6c,0x0,0x0,0x0,0x0,0x0,
0x27,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x5f,0x0,0x5f,0x0,0x69,0x0,
0x6d,0x0,0x70,0x0,0x6c,0x0,0x69,0x0,
0x63,0x0,0x69,0x0,0x74,0x0,0x48,0x0,
0x65,0x0,0x69,0x0,0x67,0x0,0x68,0x0,
0x74,0x0,0x49,0x0,0x6e,0x0,0x74,0x0,
0x65,0x0,0x72,0x0,0x6e,0x0,0x61,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x4d,0x0,0x61,0x0,
0x72,0x0,0x67,0x0,0x69,0x0,0x6e,0x0,
0x57,0x0,0x72,0x0,0x61,0x0,0x70,0x0,
0x70,0x0,0x65,0x0,0x72,0x0,0x4d,0x0,
0x61,0x0,0x6e,0x0,0x61,0x0,0x67,0x0,
0x65,0x0,0x72,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x63,0x0,0x6f,0x0,
0x6e,0x0,0x74,0x0,0x65,0x0,0x6e,0x0,
0x74,0x0,0x49,0x0,0x74,0x0,0x65,0x0,
0x6d,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x63,0x0,0x6f,0x0,
0x6e,0x0,0x74,0x0,0x65,0x0,0x6e,0x0,
0x74,0x0,0x49,0x0,0x6e,0x0,0x73,0x0,
0x69,0x0,0x64,0x0,0x65,0x0,0x42,0x0,
0x6f,0x0,0x72,0x0,0x64,0x0,0x65,0x0,
0x72,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x24,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x30,0x0,0x0,0x0,
0xb0,0x1,0x0,0x0,0x20,0x2,0x0,0x0,
0x2,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x1c,0x1,0x0,0x0,
0x1c,0x1,0x0,0x0,0x0,0x0,0x4,0x0,
0x1c,0x1,0x0,0x0,0x0,0x0,0x0,0x0,
0x7c,0x1,0x0,0x0,0xe,0x0,0x10,0x0,
0xf,0x0,0x20,0x0,0x7c,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x7c,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x13,0x0,0x20,0x0,0x13,0x0,0x10,0x2,
0x6,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x18,0x0,0x20,0x0,
0x18,0x0,0x60,0x2,0x7,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x1c,0x0,0x20,0x0,0x1c,0x0,0x40,0x2,
0x8,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x20,0x0,0x20,0x0,
0x20,0x0,0x70,0x2,0x9,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0x24,0x0,0x20,0x0,0x24,0x0,0x50,0x2,
0xa,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x28,0x0,0x20,0x0,
0x28,0x0,0x60,0x2,0xb,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0xb,0x0,0x0,0x0,
0x2b,0x0,0x20,0x0,0x2b,0x0,0x60,0x2,
0xc,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x30,0x0,0x20,0x0,
0x30,0x0,0x80,0x2,0xd,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0xd,0x0,0x0,0x0,
0x35,0x0,0x20,0x0,0x35,0x0,0x90,0x2,
0xe,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x37,0x0,0x20,0x0,
0x37,0x0,0x80,0x1,0x13,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x3c,0x0,0x20,0x0,
0x3c,0x0,0xc0,0x1,0x11,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x3b,0x0,0x20,0x0,
0x3b,0x0,0xb0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x8,0x0,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x3e,0x0,0x20,0x0,
0x3e,0x0,0x20,0x0,0xf,0x0,0x0,0x0,
0x0,0x0,0xa,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x39,0x0,0x20,0x0,
0x39,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x39,0x0,0x20,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x0,0x0,0x2,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x39,0x0,0x90,0x0,
0x39,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x3e,0x0,0x20,0x0,
0x3e,0x0,0x90,0x1,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0
};
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = {
{ 0, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for __implicitWidthInternal at line 59, column 2
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
    aotContext->mark(v2_14, markStack);
    aotContext->mark(v2_16, markStack);
    aotContext->mark(v2_2, markStack);
    aotContext->mark(v2_8, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QObject *v2_14 = nullptr;
QObject *v2_2 = nullptr;
QObject *v2_8 = nullptr;
QVariant v2_16;
bool v2_10;
double c2_29;
double v2_18;
double v2_22;
double v2_24;
double v2_28;
double v2_29;
double v2_4;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(0, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(1, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(1, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
{
QVariant retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->getObjectLookup(2, s.v2_2, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initGetObjectLookupAsVariant(2, s.v2_2);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
s.v2_4 = aotContext->engine->fromVariant<double>(std::move(retrieved));
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!aotContext->loadContextIdLookup(3, &s.v2_8)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
aotContext->initLoadContextIdLookup(3);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(12);
#endif
while (!aotContext->getObjectLookup(4, s.v2_8, &s.v2_10)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(12);
#endif
aotContext->initGetObjectLookup(4, s.v2_8);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_JumpFalse
if (!s.v2_10) {
    goto label_0;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
while (!aotContext->loadContextIdLookup(5, &s.v2_14)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
aotContext->initLoadContextIdLookup(5);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
s.v2_16 = QVariant(aotContext->lookupResultMetaType(6));
while (!aotContext->getObjectLookup(6, s.v2_14, s.v2_16.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
aotContext->initGetObjectLookup(6, s.v2_14);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
s.v2_16 = QVariant(aotContext->lookupResultMetaType(6));
}
{
}
// generate_GetLookup
{
int retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(20);
#endif
while (!aotContext->getValueLookup(7, s.v2_16.data(), &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(20);
#endif
aotContext->initGetValueLookup(7, []() { static const auto t = QMetaType::fromName("ClippingRectangleBorder"); return t; }().metaObject());
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
s.v2_18 = double(std::move(retrieved));
}
{
}
// generate_StoreReg
{
}
// generate_LoadInt
s.v2_22 = double(2);
{
}
// generate_Mul
s.v2_24 = (s.v2_18 * s.v2_22);
{
}
// generate_Jump
{
s.c2_29 = s.v2_24;
    goto label_1;
}
label_0:;
// generate_LoadZero
s.v2_28 = double(0);
{
s.c2_29 = s.v2_28;
}
label_1:;
// generate_Add
s.v2_29 = (s.v2_4 + s.c2_29);
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.v2_29;
}
return;
}
 },{ 1, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for __implicitHeightInternal at line 60, column 2
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
    aotContext->mark(v2_14, markStack);
    aotContext->mark(v2_16, markStack);
    aotContext->mark(v2_2, markStack);
    aotContext->mark(v2_8, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QObject *v2_14 = nullptr;
QObject *v2_2 = nullptr;
QObject *v2_8 = nullptr;
QVariant v2_16;
bool v2_10;
double c2_29;
double v2_18;
double v2_22;
double v2_24;
double v2_28;
double v2_29;
double v2_4;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(8, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(8);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(9, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(9, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
{
QVariant retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->getObjectLookup(10, s.v2_2, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initGetObjectLookupAsVariant(10, s.v2_2);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
s.v2_4 = aotContext->engine->fromVariant<double>(std::move(retrieved));
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!aotContext->loadContextIdLookup(11, &s.v2_8)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
aotContext->initLoadContextIdLookup(11);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(12);
#endif
while (!aotContext->getObjectLookup(12, s.v2_8, &s.v2_10)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(12);
#endif
aotContext->initGetObjectLookup(12, s.v2_8);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_JumpFalse
if (!s.v2_10) {
    goto label_0;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
while (!aotContext->loadContextIdLookup(13, &s.v2_14)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
aotContext->initLoadContextIdLookup(13);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
s.v2_16 = QVariant(aotContext->lookupResultMetaType(14));
while (!aotContext->getObjectLookup(14, s.v2_14, s.v2_16.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
aotContext->initGetObjectLookup(14, s.v2_14);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
s.v2_16 = QVariant(aotContext->lookupResultMetaType(14));
}
{
}
// generate_GetLookup
{
int retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(20);
#endif
while (!aotContext->getValueLookup(15, s.v2_16.data(), &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(20);
#endif
aotContext->initGetValueLookup(15, []() { static const auto t = QMetaType::fromName("ClippingRectangleBorder"); return t; }().metaObject());
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
s.v2_18 = double(std::move(retrieved));
}
{
}
// generate_StoreReg
{
}
// generate_LoadInt
s.v2_22 = double(2);
{
}
// generate_Mul
s.v2_24 = (s.v2_18 * s.v2_22);
{
}
// generate_Jump
{
s.c2_29 = s.v2_24;
    goto label_1;
}
label_0:;
// generate_LoadZero
s.v2_28 = double(0);
{
s.c2_29 = s.v2_28;
}
label_1:;
// generate_Add
s.v2_29 = (s.v2_4 + s.c2_29);
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.v2_29;
}
return;
}
 },{ 0, 0, nullptr, nullptr }};
}
}
