/****************************************************************************
** Meta object code from reading C++ file 'qml.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../src/wayland/hyprland/ipc/qml.hpp"
#include <QtCore/qmetatype.h>
#include <QtCore/QProperty>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qml.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2qs8hyprland3ipc14HyprlandIpcQmlE_t {};
} // unnamed namespace

template <> constexpr inline auto qs::hyprland::ipc::HyprlandIpcQml::qt_create_metaobjectdata<qt_meta_tag_ZN2qs8hyprland3ipc14HyprlandIpcQmlE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qs::hyprland::ipc::HyprlandIpcQml",
        "QML.Element",
        "Hyprland",
        "QML.Singleton",
        "true",
        "rawEvent",
        "",
        "qs::hyprland::ipc::HyprlandIpcEvent*",
        "event",
        "usingLuaChanged",
        "focusedMonitorChanged",
        "focusedWorkspaceChanged",
        "activeToplevelChanged",
        "dispatch",
        "request",
        "monitorFor",
        "HyprlandMonitor*",
        "QuickshellScreenInfo*",
        "screen",
        "refreshMonitors",
        "refreshWorkspaces",
        "refreshToplevels",
        "usingLua",
        "requestSocketPath",
        "eventSocketPath",
        "focusedMonitor",
        "qs::hyprland::ipc::HyprlandMonitor*",
        "focusedWorkspace",
        "qs::hyprland::ipc::HyprlandWorkspace*",
        "activeToplevel",
        "qs::hyprland::ipc::HyprlandToplevel*",
        "monitors",
        "UntypedObjectModel*",
        "workspaces",
        "toplevels"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'rawEvent'
        QtMocHelpers::SignalData<void(qs::hyprland::ipc::HyprlandIpcEvent *)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'usingLuaChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusedMonitorChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusedWorkspaceChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeToplevelChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'dispatch'
        QtMocHelpers::MethodData<void(const QString &)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Method 'monitorFor'
        QtMocHelpers::MethodData<HyprlandMonitor *(QuickshellScreenInfo *)>(15, 6, QMC::AccessPublic, 0x80000000 | 16, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Method 'refreshMonitors'
        QtMocHelpers::MethodData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'refreshWorkspaces'
        QtMocHelpers::MethodData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'refreshToplevels'
        QtMocHelpers::MethodData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'usingLua'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 1),
        // property 'requestSocketPath'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'eventSocketPath'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'focusedMonitor'
        QtMocHelpers::PropertyData<qs::hyprland::ipc::HyprlandMonitor*>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Bindable, 2),
        // property 'focusedWorkspace'
        QtMocHelpers::PropertyData<qs::hyprland::ipc::HyprlandWorkspace*>(27, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Bindable, 3),
        // property 'activeToplevel'
        QtMocHelpers::PropertyData<qs::hyprland::ipc::HyprlandToplevel*>(29, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Bindable, 4),
        // property 'monitors'
        QtMocHelpers::PropertyData<UntypedObjectModel*>(31, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'workspaces'
        QtMocHelpers::PropertyData<UntypedObjectModel*>(33, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'toplevels'
        QtMocHelpers::PropertyData<UntypedObjectModel*>(34, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<HyprlandIpcQml, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject qs::hyprland::ipc::HyprlandIpcQml::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs8hyprland3ipc14HyprlandIpcQmlE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs8hyprland3ipc14HyprlandIpcQmlE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2qs8hyprland3ipc14HyprlandIpcQmlE_t>.metaTypes,
    nullptr
} };

void qs::hyprland::ipc::HyprlandIpcQml::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HyprlandIpcQml *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->rawEvent((*reinterpret_cast<std::add_pointer_t<qs::hyprland::ipc::HyprlandIpcEvent*>>(_a[1]))); break;
        case 1: _t->usingLuaChanged(); break;
        case 2: _t->focusedMonitorChanged(); break;
        case 3: _t->focusedWorkspaceChanged(); break;
        case 4: _t->activeToplevelChanged(); break;
        case 5: _t->dispatch((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: { HyprlandMonitor* _r = _t->monitorFor((*reinterpret_cast<std::add_pointer_t<QuickshellScreenInfo*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<HyprlandMonitor**>(_a[0]) = std::move(_r); }  break;
        case 7: _t->refreshMonitors(); break;
        case 8: _t->refreshWorkspaces(); break;
        case 9: _t->refreshToplevels(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< qs::hyprland::ipc::HyprlandIpcEvent* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QuickshellScreenInfo* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (HyprlandIpcQml::*)(qs::hyprland::ipc::HyprlandIpcEvent * )>(_a, &HyprlandIpcQml::rawEvent, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (HyprlandIpcQml::*)()>(_a, &HyprlandIpcQml::usingLuaChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (HyprlandIpcQml::*)()>(_a, &HyprlandIpcQml::focusedMonitorChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (HyprlandIpcQml::*)()>(_a, &HyprlandIpcQml::focusedWorkspaceChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (HyprlandIpcQml::*)()>(_a, &HyprlandIpcQml::activeToplevelChanged, 4))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 8:
        case 7:
        case 6:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< UntypedObjectModel* >(); break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< qs::hyprland::ipc::HyprlandMonitor* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->bindableUsingLua().value(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->requestSocketPath(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->eventSocketPath(); break;
        case 3: *reinterpret_cast<qs::hyprland::ipc::HyprlandMonitor**>(_v) = _t->bindableFocusedMonitor().value(); break;
        case 4: *reinterpret_cast<qs::hyprland::ipc::HyprlandWorkspace**>(_v) = _t->bindableFocusedWorkspace().value(); break;
        case 5: *reinterpret_cast<qs::hyprland::ipc::HyprlandToplevel**>(_v) = _t->bindableActiveToplevel().value(); break;
        case 6: *reinterpret_cast<UntypedObjectModel**>(_v) = _t->monitors(); break;
        case 7: *reinterpret_cast<UntypedObjectModel**>(_v) = _t->workspaces(); break;
        case 8: *reinterpret_cast<UntypedObjectModel**>(_v) = _t->toplevels(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::BindableProperty) {
        switch (_id) {
        case 0: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableUsingLua(); break;
        case 3: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableFocusedMonitor(); break;
        case 4: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableFocusedWorkspace(); break;
        case 5: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableActiveToplevel(); break;
        default: break;
        }
    }
}

const QMetaObject *qs::hyprland::ipc::HyprlandIpcQml::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qs::hyprland::ipc::HyprlandIpcQml::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2qs8hyprland3ipc14HyprlandIpcQmlE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int qs::hyprland::ipc::HyprlandIpcQml::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void qs::hyprland::ipc::HyprlandIpcQml::rawEvent(qs::hyprland::ipc::HyprlandIpcEvent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void qs::hyprland::ipc::HyprlandIpcQml::usingLuaChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void qs::hyprland::ipc::HyprlandIpcQml::focusedMonitorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void qs::hyprland::ipc::HyprlandIpcQml::focusedWorkspaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void qs::hyprland::ipc::HyprlandIpcQml::activeToplevelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
